(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     53377,       1088]*)
(*NotebookOutlinePosition[     54496,       1123]*)
(*  CellTagsIndexPosition[     54452,       1119]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["The field from a magnetic dipole or current element", "Section",
  Evaluatable->False,
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Preliminaries", "Subsection",
  Evaluatable->False,
  InitializationCell->True,
  AspectRatioFixed->True],

Cell["Needs[\"Calculus`VectorAnalysis`\"];", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell["Needs[\"Graphics`PlotField`\"];", "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Fix the funny output  from when ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "  doesn't know that a square root is of a positive number"
}], "Subsubsection",
  Evaluatable->False,
  InitializationCell->True,
  AspectRatioFixed->True],

Cell["\<\
powerfix = {
\t(x_^2)^Rational[n_,2]:>x^n,
\t(x_^-2)^Rational[n_,2]:>x^-n
};\
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell["\<\
Recurse[sublist_List] := 
\tsublist//.(x_->y_):>(x->(y/.sublist))\
\>", "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The position of the source dipole or current element", "Subsection",
  Evaluatable->False,
  InitializationCell->True,
  AspectRatioFixed->True],

Cell["sourcepos = {dx, dy, dz};", "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["The magnitude of the source dipole", "Subsection",
  Evaluatable->False,
  InitializationCell->True,
  AspectRatioFixed->True],

Cell["sourcedipole = {m1x, m1y, m1z};", "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["The magnitude of the source current element", "Subsection",
  Evaluatable->False,
  InitializationCell->True,
  AspectRatioFixed->True],

Cell["sourcecurrent = {j1x, j1y, j1z};", "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["The vector from the dipole to an arbitrary test point", "Subsection",
  Evaluatable->False,
  InitializationCell->True,
  AspectRatioFixed->True],

Cell["sourcefieldvec = Coordinates[]-sourcepos;", "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["The distance to the test point", "Subsection",
  Evaluatable->False,
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["rsf = Sqrt[DotProduct[sourcefieldvec,sourcefieldvec]]", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\@\(\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Given the B of a bar magnet, work back to the dipole moment, \
assuming perfect dipole field pattern.\
\>", "Subsection",
  Evaluatable->False,
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Formula from Plonus, \"Applied Electromagnetics\", p336", \
"Subsubsection",
  Evaluatable->False,
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
Baxialint = (mu0 M/2) (
\t\t(1-2z/l)
\t\t/Sqrt[(2a/l)^2+(2z/l-1)^2]
\t\t+(1+2z/l)
\t\t/Sqrt[(2a/l)^2+(2z/l+1)^2]
\t)\
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[
    \(1\/2\ M\ mu0\ \((\(1 - \(2\ z\)\/l\)\/\@\(\(4\ a\^2\)\/l\^2 + \((\(-1\) \
+ \(2\ z\)\/l)\)\^2\) + \(1 + \(2\ z\)\/l\)\/\@\(\(4\ a\^2\)\/l\^2 + \((1 + \
\(2\ z\)\/l)\)\^2\))\)\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["The velocity of the test point", "Subsection",
  Evaluatable->False,
  InitializationCell->True,
  AspectRatioFixed->True],

Cell["velocity = {vx, vy, vz};", "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A dipole source", "Section",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["The magnetic scalar potential from the dipole", "Subsection",
  Evaluatable->False,
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["dipolepot = -1/(4 Pi) DotProduct[sourcedipole, Grad[1/rsf]]", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(-\(\(1\/\(4\ \[Pi]\)\)\((\(-\(\(m1x\ \((\(-dx\) + 
                      Xx)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + \
Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(3/2\)\)\) - \(m1y\ \((\(-dy\) + \
Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(3/2\) - \(m1z\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 \
+ \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\)\)\)\)], \
"Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["The magnetic field from the dipole", "Subsection",
  Evaluatable->False,
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
{dipoleBx, dipoleBy, dipoleBz} \\
= dipoleB \\
= -mu0 Grad[dipolepot];\
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[
    \({\(\(1\/\(4\ \[Pi]\)\)\((mu0\ \((\(3\ m1x\ \((\(-dx\) + Xx)\)\^2\)\/\((\
\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1y\ \((\(-dx\) + Xx)\)\ \((\(-dy\) + \
Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1z\ \((\(-dx\) + Xx)\)\ \((\(-dz\) + \
Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) - 
              m1x\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\))\)\), \(\(1\/\(4\ \[Pi]\)\)\((mu0\ \
\((\(3\ m1x\ \((\(-dx\) + Xx)\)\ \((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ \
m1y\ \((\(-dy\) + Yy)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + \
Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ m1z\ \((\(-dy\) + Yy)\)\ \
\((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) - 
              m1y\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\))\)\), \(\(1\/\(4\ \[Pi]\)\)\((mu0\ \
\((\(3\ m1x\ \((\(-dx\) + Xx)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ \
m1y\ \((\(-dy\) + Yy)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\
\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ m1z\ \((\(-dz\) \
+ Zz)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) - 
              m1z\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\))\)\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The potential of a dipole in the magnetic field", "Subsection",
  Evaluatable->False,
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["dipole2pot = dipoleB.{m2x,m2y,m2z}", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(1\/\(4\ \[Pi]\)\)\((m2x\ mu0\ \((\(3\ m1x\ \((\(-dx\) + \
Xx)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1y\ \((\(-dx\) + Xx)\)\ \((\(-dy\) + \
Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1z\ \((\(-dx\) + Xx)\)\ \((\(-dz\) + \
Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) - 
              m1x\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\))\)\) + \(\(1\/\(4\ \[Pi]\)\)\((m2y\ mu0\ \
\((\(3\ m1x\ \((\(-dx\) + Xx)\)\ \((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ \
m1y\ \((\(-dy\) + Yy)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + \
Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ m1z\ \((\(-dy\) + Yy)\)\ \
\((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) - 
              m1y\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\))\)\) + \(\(1\/\(4\ \[Pi]\)\)\((m2z\ mu0\ \
\((\(3\ m1x\ \((\(-dx\) + Xx)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ \
m1y\ \((\(-dy\) + Yy)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\
\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ m1z\ \((\(-dz\) \
+ Zz)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) - 
              m1z\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\))\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The force of a dipole in the magnetic field", "Subsection",
  Evaluatable->False,
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["dipoleforce = -Grad[dipole2pot]", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[
    \({\(-\(\(1\/\(4\ \[Pi]\)\)\((m2y\ mu0\ \((\(-\(\(15\ m1x\ \((\(-dx\) + \
Xx)\)\^2\ \((\(-dy\) + 
                              Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) \
+ Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\)\)\) - \(15\ m1y\ \((\(-dx\) + \
Xx)\)\ \((\(-dy\) + Yy)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\
\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) - \(15\ m1z\ \((\(-dx\) + Xx)\)\ \
\((\(-dy\) + Yy)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\
\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) + \(3\ m1y\ \((\(-dx\) + \
Xx)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1x\ \((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\))\))\)\)\) - \(\(1\/\(4\ \[Pi]\)\)\((m2z\ mu0\ \
\((\(-\(\(15\ m1x\ \((\(-dx\) + Xx)\)\^2\ \((\(-dz\) + 
                            Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + \
Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\)\)\) - \(15\ m1y\ \((\(-dx\) + \
Xx)\)\ \((\(-dy\) + Yy)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \
\((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) - \(15\ m1z\ \
\((\(-dx\) + Xx)\)\ \((\(-dz\) + Zz)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \
\((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) + \(3\ m1z\ \
\((\(-dx\) + Xx)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ m1x\ \((\(-dz\) + \
Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\))\))\)\) - \(\(1\/\(4\ \[Pi]\)\)\((m2x\ mu0\ \((\(-\(\(15\
\ m1x\ \((\(-dx\) + Xx)\)\^3\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\
\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\)\)\) - \(15\ m1y\ \((\(-dx\) + \
Xx)\)\^2\ \((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\
\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) - \(15\ m1z\ \((\(-dx\) + Xx)\)\^2\ \
\((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) + \(9\ m1x\ \((\(-dx\) + \
Xx)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1y\ \((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ \
m1z\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(5/2\))\))\)\), \(-\(\(1\/\(4\ \[Pi]\)\)\((m2x\ \
mu0\ \((\(-\(\(15\ m1x\ \((\(-dx\) + Xx)\)\^2\ \((\(-dy\) + 
                              Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) \
+ Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\)\)\) - \(15\ m1y\ \((\(-dx\) + \
Xx)\)\ \((\(-dy\) + Yy)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\
\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) - \(15\ m1z\ \((\(-dx\) + Xx)\)\ \
\((\(-dy\) + Yy)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\
\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) + \(3\ m1y\ \((\(-dx\) + \
Xx)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1x\ \((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\))\))\)\)\) - \(\(1\/\(4\ \[Pi]\)\)\((m2z\ mu0\ \
\((\(-\(\(15\ m1x\ \((\(-dx\) + Xx)\)\ \((\(-dy\) + Yy)\)\ \((\(-dz\) + 
                            Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + \
Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\)\)\) - \(15\ m1y\ \((\(-dy\) + \
Yy)\)\^2\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\
\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) - \(15\ m1z\ \((\(-dy\) + Yy)\)\ \
\((\(-dz\) + Zz)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) + \(3\ m1z\ \((\(-dy\) + \
Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1y\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\))\))\)\) \
- \(\(1\/\(4\ \[Pi]\)\)\((m2y\ mu0\ \((\(-\(\(15\ m1x\ \((\(-dx\) + 
                            Xx)\)\ \((\(-dy\) + Yy)\)\^2\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\)\)\) - \
\(15\ m1y\ \((\(-dy\) + Yy)\)\^3\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + \
Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) - \(15\ m1z\ \((\(-dy\) + \
Yy)\)\^2\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\
\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) + \(3\ m1x\ \((\(-dx\) + Xx)\)\)\/\((\
\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(9\ m1y\ \((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ \
m1z\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(5/2\))\))\)\), \(-\(\(1\/\(4\ \[Pi]\)\)\((m2x\ \
mu0\ \((\(-\(\(15\ m1x\ \((\(-dx\) + Xx)\)\^2\ \((\(-dz\) + 
                              Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) \
+ Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\)\)\) - \(15\ m1y\ \((\(-dx\) + \
Xx)\)\ \((\(-dy\) + Yy)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \
\((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) - \(15\ m1z\ \
\((\(-dx\) + Xx)\)\ \((\(-dz\) + Zz)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \
\((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) + \(3\ m1z\ \
\((\(-dx\) + Xx)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ m1x\ \((\(-dz\) + \
Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\))\))\)\)\) - \(\(1\/\(4\ \[Pi]\)\)\((m2y\ mu0\ \
\((\(-\(\(15\ m1x\ \((\(-dx\) + Xx)\)\ \((\(-dy\) + Yy)\)\ \((\(-dz\) + 
                            Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + \
Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\)\)\) - \(15\ m1y\ \((\(-dy\) + \
Yy)\)\^2\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\
\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) - \(15\ m1z\ \((\(-dy\) + Yy)\)\ \
\((\(-dz\) + Zz)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) + \(3\ m1z\ \((\(-dy\) + \
Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1y\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\))\))\)\) \
- \(\(1\/\(4\ \[Pi]\)\)\((m2z\ mu0\ \((\(-\(\(15\ m1x\ \((\(-dx\) + 
                            Xx)\)\ \((\(-dz\) + Zz)\)\^2\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\)\)\) - \
\(15\ m1y\ \((\(-dy\) + Yy)\)\ \((\(-dz\) + Zz)\)\^2\)\/\((\((\(-dx\) + Xx)\)\
\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) - \(15\ m1z\ \
\((\(-dz\) + Zz)\)\^3\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) + \(3\ m1x\ \((\(-dx\) + \
Xx)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1y\ \((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(9\ \
m1z\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(5/2\))\))\)\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The potential of the dipole induced in a small bit of magnetic \
material in the magnetic field\
\>", "Subsection",
  Evaluatable->False,
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["dipole2potinduced = mm*dipoleB.dipoleB", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[
    \(mm\ \((\(\(1\/\(16\ \[Pi]\^2\)\)\((mu0\^2\ \((\(3\ m1x\ \((\(-dx\) + \
Xx)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1y\ \((\(-dx\) + Xx)\)\ \((\(-dy\) + \
Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1z\ \((\(-dx\) + Xx)\)\ \((\(-dz\) + \
Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) - 
                    m1x\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\)^2)\)\) + \(\(1\/\(16\ \[Pi]\^2\)\)\((mu0\
\^2\ \((\(3\ m1x\ \((\(-dx\) + Xx)\)\ \((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ \
m1y\ \((\(-dy\) + Yy)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + \
Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ m1z\ \((\(-dy\) + Yy)\)\ \
\((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) - 
                    m1y\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\)^2)\)\) + \(\(1\/\(16\ \[Pi]\^2\)\)\((mu0\
\^2\ \((\(3\ m1x\ \((\(-dx\) + Xx)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ \
m1y\ \((\(-dy\) + Yy)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\
\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ m1z\ \((\(-dz\) \
+ Zz)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) - 
                    m1z\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\)^2)\)\))\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The force on the dipole induced in a small bit of magnetic material \
in the magnetic field\
\>", "Subsection",
  Evaluatable->False,
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["dipoleforceinduced = -Grad[dipole2potinduced]", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[
    \({\(-mm\)\ \((\(\(1\/\(8\ \[Pi]\^2\)\)\((mu0\^2\ \((\(-\(\(15\ m1x\ \
\((\(-dx\) + Xx)\)\^3\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(7/2\)\)\) - \(15\ m1y\ \((\(-dx\) + Xx)\)\^2\ \((\
\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) - \(15\ m1z\ \((\(-dx\) + Xx)\)\^2\ \
\((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) + \(9\ m1x\ \((\(-dx\) + \
Xx)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1y\ \((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ \
m1z\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(5/2\))\)\ \((\(3\ m1x\ \((\(-dx\) + \
Xx)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1y\ \((\(-dx\) + Xx)\)\ \((\(-dy\) + \
Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1z\ \((\(-dx\) + Xx)\)\ \((\(-dz\) + \
Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) - 
                    m1x\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\))\)\) + \(\(1\/\(8\ \[Pi]\^2\)\)\((mu0\^2\
\ \((\(-\(\(15\ m1x\ \((\(-dx\) + Xx)\)\^2\ \((\(-dy\) + 
                                Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \
\((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\)\)\) - \(15\ m1y\ \
\((\(-dx\) + Xx)\)\ \((\(-dy\) + Yy)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \
\((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) - \(15\ m1z\ \
\((\(-dx\) + Xx)\)\ \((\(-dy\) + Yy)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) + \(3\ \
m1y\ \((\(-dx\) + Xx)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ m1x\ \((\(-dy\) + \
Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\))\)\ \((\(3\ m1x\ \((\(-dx\) + Xx)\)\ \((\(-dy\) + \
Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1y\ \((\(-dy\) + Yy)\)\^2\)\/\((\((\(-dx\) + Xx)\
\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ m1z\ \
\((\(-dy\) + Yy)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\
\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) - 
                    m1y\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\))\)\) + \(\(1\/\(8\ \[Pi]\^2\)\)\((mu0\^2\
\ \((\(-\(\(15\ m1x\ \((\(-dx\) + Xx)\)\^2\ \((\(-dz\) + 
                                Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \
\((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\)\)\) - \(15\ m1y\ \
\((\(-dx\) + Xx)\)\ \((\(-dy\) + Yy)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) - \(15\ \
m1z\ \((\(-dx\) + Xx)\)\ \((\(-dz\) + Zz)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \
\((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) + \(3\ m1z\ \
\((\(-dx\) + Xx)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ m1x\ \((\(-dz\) + \
Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\))\)\ \((\(3\ m1x\ \((\(-dx\) + Xx)\)\ \((\(-dz\) + \
Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1y\ \((\(-dy\) + Yy)\)\ \((\(-dz\) + \
Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1z\ \((\(-dz\) + Zz)\)\^2\)\/\((\((\(-dx\) + Xx)\
\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) - 
                    
                    m1z\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\))\)\))\), \(-mm\)\ \((\(\(1\/\(8\ \
\[Pi]\^2\)\)\((mu0\^2\ \((\(-\(\(15\ m1x\ \((\(-dx\) + Xx)\)\^2\ \((\(-dy\) + 
                                Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \
\((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\)\)\) - \(15\ m1y\ \
\((\(-dx\) + Xx)\)\ \((\(-dy\) + Yy)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \
\((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) - \(15\ m1z\ \
\((\(-dx\) + Xx)\)\ \((\(-dy\) + Yy)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) + \(3\ \
m1y\ \((\(-dx\) + Xx)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ m1x\ \((\(-dy\) + \
Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\))\)\ \((\(3\ m1x\ \((\(-dx\) + Xx)\)\^2\)\/\((\((\(-dx\) \
+ Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ \
m1y\ \((\(-dx\) + Xx)\)\ \((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\
\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ m1z\ \((\(-dx\) \
+ Xx)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + \
Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) - 
                    m1x\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\))\)\) + \(\(1\/\(8\ \[Pi]\^2\)\)\((mu0\^2\
\ \((\(-\(\(15\ m1x\ \((\(-dx\) + 
                                Xx)\)\ \((\(-dy\) + Yy)\)\^2\)\/\((\((\(-dx\) \
+ Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\)\)\) - \
\(15\ m1y\ \((\(-dy\) + Yy)\)\^3\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + \
Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) - \(15\ m1z\ \((\(-dy\) + \
Yy)\)\^2\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\
\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) + \(3\ m1x\ \((\(-dx\) + Xx)\)\)\/\((\
\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(9\ m1y\ \((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ \
m1z\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(5/2\))\)\ \((\(3\ m1x\ \((\(-dx\) + Xx)\)\ \
\((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ m1y\ \((\(-dy\) + Yy)\)\^2\)\/\((\((\
\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1z\ \((\(-dy\) + Yy)\)\ \((\(-dz\) + \
Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) - 
                    m1y\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\))\)\) + \(\(1\/\(8\ \[Pi]\^2\)\)\((mu0\^2\
\ \((\(-\(\(15\ m1x\ \((\(-dx\) + Xx)\)\ \((\(-dy\) + Yy)\)\ \((\(-dz\) + 
                                Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \
\((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\)\)\) - \(15\ m1y\ \
\((\(-dy\) + Yy)\)\^2\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \
\((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) - \(15\ m1z\ \
\((\(-dy\) + Yy)\)\ \((\(-dz\) + Zz)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \
\((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) + \(3\ m1z\ \
\((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ m1y\ \((\(-dz\) + \
Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\))\)\ \((\(3\ m1x\ \((\(-dx\) + Xx)\)\ \((\(-dz\) + \
Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1y\ \((\(-dy\) + Yy)\)\ \((\(-dz\) + \
Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1z\ \((\(-dz\) + Zz)\)\^2\)\/\((\((\(-dx\) + Xx)\
\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) - 
                    m1z\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\))\)\))\), \(-mm\)\ \((\(\(1\/\(8\ \
\[Pi]\^2\)\)\((mu0\^2\ \((\(-\(\(15\ m1x\ \((\(-dx\) + Xx)\)\^2\ \((\(-dz\) + 
                                Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \
\((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\)\)\) - \(15\ m1y\ \
\((\(-dx\) + Xx)\)\ \((\(-dy\) + Yy)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) - \(15\ \
m1z\ \((\(-dx\) + Xx)\)\ \((\(-dz\) + Zz)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \
\((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) + \(3\ m1z\ \
\((\(-dx\) + Xx)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ m1x\ \((\(-dz\) + \
Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\))\)\ \((\(3\ m1x\ \((\(-dx\) + Xx)\)\^2\)\/\((\((\(-dx\) \
+ Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ \
m1y\ \((\(-dx\) + Xx)\)\ \((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\
\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ m1z\ \((\(-dx\) \
+ Xx)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + \
Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) - 
                    m1x\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\))\)\) + \(\(1\/\(8\ \[Pi]\^2\)\)\((mu0\^2\
\ \((\(-\(\(15\ m1x\ \((\(-dx\) + Xx)\)\ \((\(-dy\) + Yy)\)\ \((\(-dz\) + 
                                Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \
\((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\)\)\) - \(15\ m1y\ \
\((\(-dy\) + Yy)\)\^2\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \
\((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) - \(15\ m1z\ \
\((\(-dy\) + Yy)\)\ \((\(-dz\) + Zz)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \
\((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) + \(3\ m1z\ \
\((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ m1y\ \((\(-dz\) + \
Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\))\)\ \((\(3\ m1x\ \((\(-dx\) + Xx)\)\ \((\(-dy\) + \
Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1y\ \((\(-dy\) + Yy)\)\^2\)\/\((\((\(-dx\) + Xx)\
\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ m1z\ \
\((\(-dy\) + Yy)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\
\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) - 
                    m1y\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\))\)\) + \(\(1\/\(8\ \[Pi]\^2\)\)\((mu0\^2\
\ \((\(-\(\(15\ m1x\ \((\(-dx\) + 
                                Xx)\)\ \((\(-dz\) + Zz)\)\^2\)\/\((\((\(-dx\) \
+ Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\)\)\) - \
\(15\ m1y\ \((\(-dy\) + Yy)\)\ \((\(-dz\) + Zz)\)\^2\)\/\((\((\(-dx\) + Xx)\)\
\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) - \(15\ m1z\ \
\((\(-dz\) + Zz)\)\^3\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) + \(3\ m1x\ \((\(-dx\) + \
Xx)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1y\ \((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(9\ \
m1z\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(5/2\))\)\ \((\(3\ m1x\ \((\(-dx\) + Xx)\)\ \
\((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ m1y\ \((\(-dy\) + Yy)\)\ \((\(-dz\) \
+ Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1z\ \((\(-dz\) + Zz)\)\^2\)\/\((\((\(-dx\) + Xx)\
\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) - 
                    m1z\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\))\)\))\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The magnetic field gradient tensor", "Subsection",
  Evaluatable->False,
  InitializationCell->True,
  AspectRatioFixed->True],

Cell["dipolegradB = Grad[dipoleB];", "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["The rate of change of B seen by the test point as it moves", \
"Subsection",
  Evaluatable->False,
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
{dipoleBdotx, dipoleBdoty, dipoleBdotz} \\
\t= dipoleBdot = dipolegradB.velocity;\
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[
    \({\(\(1\/\(4\ \[Pi]\)\)\((mu0\ vy\ \((\(-\(\(15\ m1x\ \((\(-dx\) + Xx)\)\
\^2\ \((\(-dy\) + 
                            Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + \
Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\)\)\) - \(15\ m1y\ \((\(-dx\) + \
Xx)\)\ \((\(-dy\) + Yy)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\
\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) - \(15\ m1z\ \((\(-dx\) + Xx)\)\ \
\((\(-dy\) + Yy)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\
\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) + \(3\ m1y\ \((\(-dx\) + \
Xx)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1x\ \((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\))\))\)\) \
+ \(\(1\/\(4\ \[Pi]\)\)\((mu0\ vz\ \((\(-\(\(15\ m1x\ \((\(-dx\) + Xx)\)\^2\ \
\((\(-dz\) + 
                            Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + \
Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\)\)\) - \(15\ m1y\ \((\(-dx\) + \
Xx)\)\ \((\(-dy\) + Yy)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \
\((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) - \(15\ m1z\ \
\((\(-dx\) + Xx)\)\ \((\(-dz\) + Zz)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \
\((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) + \(3\ m1z\ \
\((\(-dx\) + Xx)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ m1x\ \((\(-dz\) + \
Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\))\))\)\) + \(\(1\/\(4\ \[Pi]\)\)\((mu0\ vx\ \((\(-\(\(15\ \
m1x\ \((\(-dx\) + Xx)\)\^3\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + \
Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\)\)\) - \(15\ m1y\ \((\(-dx\) + \
Xx)\)\^2\ \((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\
\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) - \(15\ m1z\ \((\(-dx\) + Xx)\)\^2\ \
\((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) + \(9\ m1x\ \((\(-dx\) + \
Xx)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1y\ \((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ \
m1z\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(5/2\))\))\)\), \(\(1\/\(4\ \[Pi]\)\)\((mu0\ vx\ \
\((\(-\(\(15\ m1x\ \((\(-dx\) + Xx)\)\^2\ \((\(-dy\) + 
                            Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + \
Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\)\)\) - \(15\ m1y\ \((\(-dx\) + \
Xx)\)\ \((\(-dy\) + Yy)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\
\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) - \(15\ m1z\ \((\(-dx\) + Xx)\)\ \
\((\(-dy\) + Yy)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\
\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) + \(3\ m1y\ \((\(-dx\) + \
Xx)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1x\ \((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\))\))\)\) \
+ \(\(1\/\(4\ \[Pi]\)\)\((mu0\ vz\ \((\(-\(\(15\ m1x\ \((\(-dx\) + 
                            Xx)\)\ \((\(-dy\) + Yy)\)\ \((\(-dz\) + 
                            Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + \
Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\)\)\) - \(15\ m1y\ \((\(-dy\) + \
Yy)\)\^2\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\
\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) - \(15\ m1z\ \((\(-dy\) + Yy)\)\ \
\((\(-dz\) + Zz)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) + \(3\ m1z\ \((\(-dy\) + \
Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1y\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\))\))\)\) \
+ \(\(1\/\(4\ \[Pi]\)\)\((mu0\ vy\ \((\(-\(\(15\ m1x\ \((\(-dx\) + 
                            Xx)\)\ \((\(-dy\) + Yy)\)\^2\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\)\)\) - \
\(15\ m1y\ \((\(-dy\) + Yy)\)\^3\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + \
Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) - \(15\ m1z\ \((\(-dy\) + \
Yy)\)\^2\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\
\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) + \(3\ m1x\ \((\(-dx\) + Xx)\)\)\/\((\
\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(9\ m1y\ \((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ \
m1z\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(5/2\))\))\)\), \(\(1\/\(4\ \[Pi]\)\)\((mu0\ vx\ \
\((\(-\(\(15\ m1x\ \((\(-dx\) + Xx)\)\^2\ \((\(-dz\) + 
                            Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + \
Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\)\)\) - \(15\ m1y\ \((\(-dx\) + \
Xx)\)\ \((\(-dy\) + Yy)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \
\((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) - \(15\ m1z\ \
\((\(-dx\) + Xx)\)\ \((\(-dz\) + Zz)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \
\((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) + \(3\ m1z\ \
\((\(-dx\) + Xx)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(3\ m1x\ \((\(-dz\) + \
Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\))\))\)\) + \(\(1\/\(4\ \[Pi]\)\)\((mu0\ vy\ \((\(-\(\(15\ \
m1x\ \((\(-dx\) + Xx)\)\ \((\(-dy\) + Yy)\)\ \((\(-dz\) + 
                            Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + \
Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\)\)\) - \(15\ m1y\ \((\(-dy\) + \
Yy)\)\^2\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\
\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) - \(15\ m1z\ \((\(-dy\) + Yy)\)\ \
\((\(-dz\) + Zz)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) + \(3\ m1z\ \((\(-dy\) + \
Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1y\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\))\))\)\) \
+ \(\(1\/\(4\ \[Pi]\)\)\((mu0\ vz\ \((\(-\(\(15\ m1x\ \((\(-dx\) + 
                            Xx)\)\ \((\(-dz\) + Zz)\)\^2\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\)\)\) - \
\(15\ m1y\ \((\(-dy\) + Yy)\)\ \((\(-dz\) + Zz)\)\^2\)\/\((\((\(-dx\) + Xx)\)\
\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) - \(15\ m1z\ \
\((\(-dz\) + Zz)\)\^3\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(7/2\) + \(3\ m1x\ \((\(-dx\) + \
Xx)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) + \(3\ m1y\ \((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + \(9\ \
m1z\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(5/2\))\))\)\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Test plots", "Subsection",
  InitializationCell->True],

Cell["testplot = False; (* whether to do test plots *)", "Input",
  InitializationCell->True],

Cell["\<\
testval1 = Recurse[{dx->0, dy->0, dz->0, Xx->0, mz->1, mu0->1, \
Pi->N[Pi],m1y->0,m1x->0,m2x->0,m1z->mz,m2z->1,m2y->0}];\
\>", "Input",
  InitializationCell->True],

Cell[BoxData[
    \(If[testplot, \
\[IndentingNewLine]PlotVectorField[\[IndentingNewLine]{dipoleforce[\([3]\)] \
/. \[InvisibleSpace]testval1, 
          dipoleforce[\([2]\)] /. \[InvisibleSpace]testval1}, \
\[IndentingNewLine]{Zz, \(-1\), 1}, \[IndentingNewLine]{Yy, \(-1\), 
          1}\[IndentingNewLine]]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(If[testplot, \[IndentingNewLine]PlotVectorField[{dipoleBz \
/. \[InvisibleSpace]testval1, 
          dipoleBy /. \[InvisibleSpace]testval1}, {Zz, \(-1\), 
          1}, {Yy, \(-1\), 1}]]\)], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A current element source", "Section",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["The magnetic vector potential from the current element", "Subsection",
  Evaluatable->False,
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["currentA = mu0/(4 Pi) sourcecurrent/rsf", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[
    \({\(j1x\ mu0\)\/\(4\ \[Pi]\ \@\(\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\
\)\^2 + \((\(-dz\) + Zz)\)\^2\)\), \(j1y\ mu0\)\/\(4\ \[Pi]\ \@\(\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2\)\), \(j1z\ \
mu0\)\/\(4\ \[Pi]\ \@\(\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2\)\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The magnet field from the current element", "Subsection",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["currentB = mu0/(4 Pi) Curl[sourcecurrent/rsf]", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[
    \({\(mu0\ \((\(-\(\(j1z\ \((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \
\((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(3/2\)\)\) + \(j1y\ \
\((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\)\)\/\(4\ \[Pi]\), \(mu0\ \((\(j1z\ \
\((\(-dx\) + Xx)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\) - \(j1x\ \((\(-dz\) + \
Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(3/2\))\)\)\/\(4\ \[Pi]\), \(mu0\ \((\(-\(\(j1y\ \((\(-dx\) + \
Xx)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(3/2\)\)\) + \(j1x\ \((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + Xx)\)\
\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\)\)\/\(4\ \
\[Pi]\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The magnetic field gradient tensor", "Subsection",
  Evaluatable->False,
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["currentgradB = Grad[currentB]", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[
    \({{\(mu0\ \((\(3\ j1z\ \((\(-dx\) + Xx)\)\ \((\(-dy\) + \
Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) - \(3\ j1y\ \((\(-dx\) + Xx)\)\ \((\(-dz\) + \
Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\))\)\)\/\(4\ \[Pi]\), \(\(1\/\(4\ \[Pi]\)\)\((mu0\ \((\(3\ \
j1z\ \((\(-dy\) + Yy)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + \
Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) - \(3\ j1y\ \((\(-dy\) + Yy)\)\ \
\((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) - 
                j1z\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\))\)\), \(\(1\/\(4\ \[Pi]\)\)\((mu0\ \
\((\(3\ j1z\ \((\(-dy\) + Yy)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) - \(3\ \
j1y\ \((\(-dz\) + Zz)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + \
Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + 
                j1y\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\))\)\)}, {\(\(1\/\(4\ \[Pi]\)\)\((mu0\ \((\
\(-\(\(3\ j1z\ \((\(-dx\) + Xx)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) \
+ Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\)\)\) + \(3\ j1x\ \((\(-dx\) + \
Xx)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 \
+ \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + 
                j1z\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\))\)\), \(mu0\ \((\(-\(\(3\ j1z\ \
\((\(-dx\) + Xx)\)\ \((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\
\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\)\)\) + \(3\ j1x\ \((\(-dy\) \
+ Yy)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + \
Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\))\)\)\/\(4\ \[Pi]\), \(\(1\/\(4\ \
\[Pi]\)\)\((mu0\ \((\(-\(\(3\ j1z\ \((\(-dx\) + Xx)\)\ \((\(-dz\) + 
                            
                            Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + \
Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\)\)\) + \(3\ j1x\ \((\(-dz\) + Zz)\
\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) - 
                j1x\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\))\)\)}, {\(\(1\/\(4\ \[Pi]\)\)\((mu0\ \((\
\(3\ j1y\ \((\(-dx\) + Xx)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + \
Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) - \(3\ j1x\ \((\(-dx\) + Xx)\)\ \
\((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) - 
                j1y\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\))\)\), \(\(1\/\(4\ \[Pi]\)\)\((mu0\ \
\((\(3\ j1y\ \((\(-dx\) + Xx)\)\ \((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) - \(3\ \
j1x\ \((\(-dy\) + Yy)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + \
Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + 
                j1x\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\))\)\), \(mu0\ \((\(3\ j1y\ \((\(-dx\) + \
Xx)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 \
+ \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) - \(3\ j1x\ \((\(-dy\) + Yy)\)\ \
\((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(5/2\))\)\)\/\(4\ \[Pi]\)}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The potential of a dipole in the magnetic field", "Subsection",
  Evaluatable->False,
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["currentdipolepot = currentB.{m2x,m2y,m2z}", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(m2z\ mu0\ \((\(-\(\(j1y\ \((\(-dx\) + Xx)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(3/2\)\)\) + \
\(j1x\ \((\(-dy\) + Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 \
+ \((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\)\)\/\(4\ \[Pi]\) + \(m2y\ mu0\ \((\(j1z\
\ \((\(-dx\) + Xx)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\) - \(j1x\ \((\(-dz\) + \
Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(3/2\))\)\)\/\(4\ \[Pi]\) + \(m2x\ mu0\ \((\(-\(\(j1z\ \((\(-dy\
\) + Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(3/2\)\)\) + \(j1y\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\
\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\)\)\/\(4\ \
\[Pi]\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The force of a dipole in the magnetic field", "Subsection",
  Evaluatable->False,
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["currentdipoleforce = -Grad[currentB.{m2x,m2y,m2z}]", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[
    \({\(-\(\(m2x\ mu0\ \((\(3\ j1z\ \((\(-dx\) + Xx)\)\ \((\(-dy\) + Yy)\)\)\
\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\
\^\(5/2\) - \(3\ j1y\ \((\(-dx\) + Xx)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) \
+ Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\))\)\)\/\
\(4\ \[Pi]\)\)\) - \(\(1\/\(4\ \[Pi]\)\)\((m2z\ mu0\ \((\(3\ j1y\ \((\(-dx\) \
+ Xx)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) - \(3\ j1x\ \((\(-dx\) + Xx)\)\ \((\(-dy\) + \
Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) - 
                j1y\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\))\)\) - \(\(1\/\(4\ \[Pi]\)\)\((m2y\ mu0\ \
\((\(-\(\(3\ j1z\ \((\(-dx\) + Xx)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \
\((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\)\)\) + \(3\ j1x\ \((\
\(-dx\) + Xx)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) \
+ Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + 
                j1z\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\))\)\), \(-\(\(m2y\ mu0\ \((\(-\(\(3\ j1z\ \
\((\(-dx\) + Xx)\)\ \((\(-dy\) + 
                                Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \
\((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\)\)\) + \(3\ j1x\ \((\
\(-dy\) + Yy)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) \
+ Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\))\)\)\/\(4\ \[Pi]\)\)\) - \(\(1\
\/\(4\ \[Pi]\)\)\((m2z\ mu0\ \((\(3\ j1y\ \((\(-dx\) + Xx)\)\ \((\(-dy\) + \
Yy)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) - \(3\ j1x\ \((\(-dy\) + Yy)\)\^2\)\/\((\((\(-dx\) + Xx)\
\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + 
                j1x\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\))\)\) - \(\(1\/\(4\ \[Pi]\)\)\((m2x\ mu0\ \
\((\(3\ j1z\ \((\(-dy\) + Yy)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + \
Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) - \(3\ j1y\ \((\(-dy\) + Yy)\)\ \
\((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) - 
                j1z\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\))\)\), \(-\(\(m2z\ mu0\ \((\(3\ j1y\ \
\((\(-dx\) + Xx)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\
\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) - \(3\ j1x\ \((\(-dy\) + \
Yy)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 \
+ \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\))\)\)\/\(4\ \[Pi]\)\)\) - \(\(1\/\(4\ \
\[Pi]\)\)\((m2y\ mu0\ \((\(-\(\(3\ j1z\ \((\(-dx\) + Xx)\)\ \((\(-dz\) + 
                            Zz)\)\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + \
Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\)\)\) + \(3\ j1x\ \((\(-dz\) + Zz)\
\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + \
Zz)\)\^2)\)\^\(5/2\) - 
                j1x\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\))\)\) - \(\(1\/\(4\ \[Pi]\)\)\((m2x\ mu0\ \
\((\(3\ j1z\ \((\(-dy\) + Yy)\)\ \((\(-dz\) + Zz)\)\)\/\((\((\(-dx\) + \
Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) - \(3\ \
j1y\ \((\(-dz\) + Zz)\)\^2\)\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + \
Yy)\)\^2 + \((\(-dz\) + Zz)\)\^2)\)\^\(5/2\) + 
                j1y\/\((\((\(-dx\) + Xx)\)\^2 + \((\(-dy\) + Yy)\)\^2 + \
\((\(-dz\) + Zz)\)\^2)\)\^\(3/2\))\))\)\)}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["End stuff", "Section",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["\<\
Sacrificial calculation with throw-away result to stop .m file \
returning junk\
\>", "Subsection",
  InitializationCell->True],

Cell["0;", "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 746}},
AutoGeneratedPackage->Automatic,
WindowToolbars->{},
WindowSize->{654, 651},
WindowMargins->{{Automatic, 41}, {Automatic, 24}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 146, 3, 50, "Section",
  Evaluatable->False,
  InitializationCell->True],

Cell[CellGroupData[{
Cell[1910, 58, 111, 3, 46, "Subsection",
  Evaluatable->False,
  InitializationCell->True],
Cell[2024, 63, 107, 2, 27, "Input",
  InitializationCell->True],
Cell[2134, 67, 76, 1, 27, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2235, 72, 264, 8, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->True],
Cell[2502, 82, 155, 7, 72, "Input",
  InitializationCell->True],
Cell[2660, 91, 118, 4, 42, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2827, 101, 150, 3, 46, "Subsection",
  Evaluatable->False,
  InitializationCell->True],
Cell[2980, 106, 96, 2, 27, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[3113, 113, 132, 3, 46, "Subsection",
  Evaluatable->False,
  InitializationCell->True],
Cell[3248, 118, 102, 2, 27, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[3387, 125, 141, 3, 46, "Subsection",
  Evaluatable->False,
  InitializationCell->True],
Cell[3531, 130, 103, 2, 27, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[3671, 137, 151, 3, 46, "Subsection",
  Evaluatable->False,
  InitializationCell->True],
Cell[3825, 142, 112, 2, 27, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[3974, 149, 128, 3, 46, "Subsection",
  Evaluatable->False,
  InitializationCell->True],

Cell[CellGroupData[{
Cell[4127, 156, 124, 2, 27, "Input",
  InitializationCell->True],
Cell[4254, 160, 111, 2, 35, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4414, 168, 207, 6, 64, "Subsection",
  Evaluatable->False,
  InitializationCell->True],

Cell[CellGroupData[{
Cell[4646, 178, 158, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->True],

Cell[CellGroupData[{
Cell[4829, 186, 195, 9, 102, "Input",
  InitializationCell->True],
Cell[5027, 197, 208, 3, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[5296, 207, 128, 3, 30, "Subsection",
  Evaluatable->False,
  InitializationCell->True],
Cell[5427, 212, 95, 2, 27, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5571, 220, 62, 1, 50, "Section",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[5658, 225, 143, 3, 46, "Subsection",
  Evaluatable->False,
  InitializationCell->True],

Cell[CellGroupData[{
Cell[5826, 232, 130, 2, 27, "Input",
  InitializationCell->True],
Cell[5959, 236, 455, 7, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[6463, 249, 132, 3, 30, "Subsection",
  Evaluatable->False,
  InitializationCell->True],

Cell[CellGroupData[{
Cell[6620, 256, 149, 6, 57, "Input",
  InitializationCell->True],
Cell[6772, 264, 1714, 25, 477, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8535, 295, 145, 3, 46, "Subsection",
  Evaluatable->False,
  InitializationCell->True],

Cell[CellGroupData[{
Cell[8705, 302, 105, 2, 27, "Input",
  InitializationCell->True],
Cell[8813, 306, 1729, 25, 477, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10591, 337, 141, 3, 46, "Subsection",
  Evaluatable->False,
  InitializationCell->True],

Cell[CellGroupData[{
Cell[10757, 344, 102, 2, 27, "Input",
  InitializationCell->True],
Cell[10862, 348, 7354, 100, 1905, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[18265, 454, 201, 6, 46, "Subsection",
  Evaluatable->False,
  InitializationCell->True],

Cell[CellGroupData[{
Cell[18491, 464, 109, 2, 27, "Input",
  InitializationCell->True],
Cell[18603, 468, 1769, 25, 477, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[20421, 499, 197, 6, 46, "Subsection",
  Evaluatable->False,
  InitializationCell->True],

Cell[CellGroupData[{
Cell[20643, 509, 116, 2, 27, "Input",
  InitializationCell->True],
Cell[20762, 513, 12218, 168, 3315, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[33029, 687, 132, 3, 46, "Subsection",
  Evaluatable->False,
  InitializationCell->True],
Cell[33164, 692, 99, 2, 27, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[33300, 699, 158, 4, 46, "Subsection",
  Evaluatable->False,
  InitializationCell->True],

Cell[CellGroupData[{
Cell[33483, 707, 160, 5, 42, "Input",
  InitializationCell->True],
Cell[33646, 714, 7351, 100, 1905, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[41046, 820, 60, 1, 46, "Subsection",
  InitializationCell->True],
Cell[41109, 823, 93, 1, 27, "Input",
  InitializationCell->True],
Cell[41205, 826, 173, 4, 42, "Input",
  InitializationCell->True],
Cell[41381, 832, 370, 7, 123, "Input",
  InitializationCell->True],
Cell[41754, 841, 247, 5, 59, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[42050, 852, 71, 1, 50, "Section",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[42146, 857, 152, 3, 46, "Subsection",
  Evaluatable->False,
  InitializationCell->True],

Cell[CellGroupData[{
Cell[42323, 864, 110, 2, 27, "Input",
  InitializationCell->True],
Cell[42436, 868, 357, 5, 129, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[42842, 879, 91, 1, 46, "Subsection",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[42958, 884, 116, 2, 27, "Input",
  InitializationCell->True],
Cell[43077, 888, 854, 12, 155, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[43980, 906, 132, 3, 46, "Subsection",
  Evaluatable->False,
  InitializationCell->True],

Cell[CellGroupData[{
Cell[44137, 913, 100, 2, 27, "Input",
  InitializationCell->True],
Cell[44240, 917, 3581, 51, 901, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[47870, 974, 145, 3, 46, "Subsection",
  Evaluatable->False,
  InitializationCell->True],

Cell[CellGroupData[{
Cell[48040, 981, 112, 2, 27, "Input",
  InitializationCell->True],
Cell[48155, 985, 869, 12, 155, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[49073, 1003, 141, 3, 46, "Subsection",
  Evaluatable->False,
  InitializationCell->True],

Cell[CellGroupData[{
Cell[49239, 1010, 121, 2, 27, "Input",
  InitializationCell->True],
Cell[49363, 1014, 3657, 51, 867, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[53081, 1072, 56, 1, 50, "Section",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[53162, 1077, 137, 4, 46, "Subsection",
  InitializationCell->True],
Cell[53302, 1083, 47, 1, 27, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

