(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   2374349,      51700]
NotebookOptionsPosition[   2351509,      50948]
NotebookOutlinePosition[   2352010,      50968]
CellTagsIndexPosition[   2351967,      50965]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Analysis of the sweet spot for the coil", "Title"],

Cell[BoxData[
 RowBox[{
  RowBox[{"useprecomputed", " ", "=", " ", "True"}], ";", " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "whether", " ", "to", " ", "use", " ", "old", " ", "values", " ", "for", 
     " ", "certain", " ", "time"}], "-", 
    RowBox[{"consuming", " ", "calculations"}]}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.480244231326439*^9, 3.48024423792516*^9}, {
  3.480703939177309*^9, 3.48070394080156*^9}, {3.481941928523884*^9, 
  3.481941957601687*^9}}],

Cell[CellGroupData[{

Cell["Instructions", "Section"],

Cell["\<\
1. Make sure that the notebook of utility functions for magnetic dipoles, \
MagDipole.nb, and the associated autosave file, MagDipole.m, are in the same \
directory as this notebook.
2. Edit the path setting statement in the Preliminaries section below to make \
it add this directory to the path. The directory name has to be specified in \
the correct format and the correct branch of the Switch[] statement for your \
system. Check the value of $System and add new branches if necessary.
3. Evaluate the Preliminaries section.
4. Evaluate the rest of the notebook and/or hack around to your heart's \
content.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Preliminaries", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Dependencies", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
The path in which the model definition and model-specific support files are \
installed. 
**** EDIT THE PATHS AND/OR ADD CLAUSES FOR NEW SYSTEMS AS APPROPRIATE ****\
\>", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Switch", "[", "\[IndentingNewLine]", "\t", 
   RowBox[{
   "$System", ",", "\[IndentingNewLine]", "\t", "\"\<Power Macintosh\>\"", 
    ",", 
    RowBox[{"$Path", " ", "=", " ", 
     RowBox[{"Append", "[", 
      RowBox[{
      "$Path", ",", 
       "\"\<Boadicea:Users:mbarton:Work:LIGO:analysis:magnets:bigmagnets\>\""}\
], "]"}]}], ",", "\[IndentingNewLine]", "\t", "\"\<Mac OS X\>\"", ",", 
    RowBox[{"$Path", " ", "=", " ", 
     RowBox[{"Append", "[", 
      RowBox[{
      "$Path", ",", 
       "\"\</Users/mbarton/Work/LIGO/analysis/magnets/bigmagnets\>\""}], 
      "]"}]}], ",", "\[IndentingNewLine]", "\t", 
    "\"\<Mac OS X x86 (32-bit)\>\"", ",", 
    RowBox[{"$Path", " ", "=", " ", 
     RowBox[{"Append", "[", 
      RowBox[{
      "$Path", ",", 
       "\"\</Users/mbarton/Work/LIGO/analysis/magnets/bigmagnets\>\""}], 
      "]"}]}], ",", "\[IndentingNewLine]", "\t", 
    "\"\<Mac OS X x86 (64-bit)\>\"", ",", 
    RowBox[{"$Path", " ", "=", " ", 
     RowBox[{"Append", "[", 
      RowBox[{
      "$Path", ",", 
       "\"\</Users/mbarton/Work/LIGO/analysis/magnets/bigmagnets\>\""}], 
      "]"}]}], ",", "\[IndentingNewLine]", "\t", "\"\<Solaris\>\"", ",", 
    RowBox[{"$Path", " ", "=", " ", 
     RowBox[{"Append", "[", 
      RowBox[{
      "$Path", ",", "\"\</home/mbarton/analysis/magnets/bigmagnets\>\""}], 
      "]"}]}], ",", "\[IndentingNewLine]", "\t", "\"\<Microsoft Windows\>\"", 
    ",", 
    RowBox[{"$Path", " ", "=", " ", 
     RowBox[{"Append", "[", 
      RowBox[{"$Path", ",", "\"\<c:\\EDIT ME\>\""}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.453747804876116*^9, 3.4537478086805983`*^9}}],

Cell["<<\"MagDipole.m\"", "Input"]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<NumericalCalculus`\>\"", "]"}]], "Input"],

Cell[CellGroupData[{

Cell["Disable spell-checking", "Subsection"],

Cell[BoxData[
 RowBox[{"Off", "[", 
  RowBox[{
   RowBox[{"General", "::", "spell"}], ",", 
   RowBox[{"General", "::", "spell1"}]}], "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Functions for manipulating lists of substitutions", "Subsection"],

Cell[CellGroupData[{

Cell["Replace a single substitution", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Override", "[", 
   RowBox[{"oldsubs_", ",", "newsubs_"}], "]"}], " ", ":=", " ", 
  RowBox[{"oldsubs", "/.", 
   RowBox[{"(", 
    RowBox[{"newsubs", "/.", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"param_", "\[Rule]", "newval_"}], ")"}], "\[RuleDelayed]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"param", "\[Rule]", "oldval_"}], ")"}], "\[RuleDelayed]", 
        RowBox[{"(", 
         RowBox[{"param", "\[Rule]", "newval"}], ")"}]}], ")"}]}]}], 
    ")"}]}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
A function to reduce a substitution list to fully numerical form by applying \
it repeatedly to itself:\
\>", "Subsubsection",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Recurse[sublist_List] := 
\tsublist//.(x_->y_):>(x->(y/.sublist))\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["A function to scale a substitution list:", "Subsubsection",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
scale[sublist_List, factor_] := 
\tsublist/.(x_->y_):>(x->factor*y)\
\>", "Input",
 CellChangeTimes->{3.453749631833597*^9},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Derive the axial and radial components of B", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
Baxial = Simplify[
\tTogether[
\t\tdipoleB[[3]]
\t\t/.dx->0
\t\t/.dy->0
\t\t/.dz->0
\t\t/.Xx->r
\t\t/.Yy->0
\t\t/.Zz->z
\t]
]
\
\>", "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"mu0", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "m1z"}], " ", 
      SuperscriptBox["r", "2"]}], "+", 
     RowBox[{"3", " ", "m1x", " ", "r", " ", "z"}], "+", 
     RowBox[{"2", " ", "m1z", " ", 
      SuperscriptBox["z", "2"]}]}], ")"}]}], 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["r", "2"], "+", 
      SuperscriptBox["z", "2"]}], ")"}], 
    RowBox[{"5", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{
  3.453747965547722*^9, 3.453749599994955*^9, 3.4638444535242777`*^9, {
   3.478894405842181*^9, 3.478894421027747*^9}, 3.478960340825461*^9, 
   3.479485741071822*^9, 3.479486052836144*^9, 3.4796583821237583`*^9, 
   3.480082564582583*^9, 3.4802436759582167`*^9, 3.4806922469034033`*^9, 
   3.481566005895687*^9, {3.4819409141959743`*^9, 3.48194093732237*^9}, 
   3.48194192328915*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Baxial", "/.", 
  RowBox[{"r", "\[Rule]", "0"}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"m1z", " ", "mu0"}], 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["z", "2"], ")"}], 
    RowBox[{"3", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{
  3.4537479655831127`*^9, 3.453749600034116*^9, 3.4638444538148317`*^9, {
   3.478894405888887*^9, 3.478894421080052*^9}, 3.47896034086206*^9, 
   3.4794857411376143`*^9, 3.4794860528885927`*^9, 3.479658382192664*^9, 
   3.480082564654179*^9, 3.480243676115644*^9, 3.480692246945731*^9, 
   3.4815660059479713`*^9, {3.4819409142460823`*^9, 3.4819409373890877`*^9}, 
   3.4819419233788652`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Btransverse = Simplify[
\tTogether[
\t\tdipoleB[[1]]
\t\t/.dx->0
\t\t/.dy->0
\t\t/.dz->0
\t\t/.Xx->r
\t\t/.Yy->0
\t\t/.Zz->z
\t]
]\
\>", "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"mu0", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "m1x", " ", 
      SuperscriptBox["r", "2"]}], "+", 
     RowBox[{"3", " ", "m1z", " ", "r", " ", "z"}], "-", 
     RowBox[{"m1x", " ", 
      SuperscriptBox["z", "2"]}]}], ")"}]}], 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["r", "2"], "+", 
      SuperscriptBox["z", "2"]}], ")"}], 
    RowBox[{"5", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{
  3.453747965615678*^9, 3.453749600077715*^9, 3.463844455487849*^9, {
   3.478894405942997*^9, 3.4788944211302834`*^9}, 3.478960340942863*^9, 
   3.479485741189885*^9, 3.4794860529295588`*^9, 3.4796583822416077`*^9, 
   3.480082564700638*^9, 3.48024367617673*^9, 3.480692246987156*^9, 
   3.481566005979335*^9, {3.481940914277701*^9, 3.481940937448995*^9}, 
   3.481941923414253*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
force[Zz_] = Simplify[-mz \
D[dipoleBz,Zz]/.dx->0/.dy->0/.dz->0/.Xx->0/.Yy->0]/.powerfix\
\>", "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"3", " ", "m1z", " ", "mu0", " ", "mz"}], 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SuperscriptBox["Zz", "4"]}]]], "Output",
 CellChangeTimes->{
  3.453747965823358*^9, 3.4537496001121492`*^9, 3.46384446080796*^9, {
   3.4788944059930553`*^9, 3.478894421180645*^9}, 3.47896034097888*^9, 
   3.4794857412398157`*^9, 3.479486052963105*^9, 3.479658382309431*^9, 
   3.4800825649222116`*^9, 3.480243676306188*^9, 3.48069224701851*^9, 
   3.4815660060302887`*^9, {3.481940914334242*^9, 3.481940937496923*^9}, 
   3.481941923466711*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"force", "[", "1", "]"}], "/.", 
     RowBox[{"mz", "\[Rule]", "1."}]}], "/.", 
    RowBox[{"m1z", "\[Rule]", "1."}]}], "/.", 
   RowBox[{"Zz", "\[Rule]", "1."}]}], "/.", 
  RowBox[{"mu0", "\[Rule]", "1", " ", 
   RowBox[{"(*", 
    RowBox[{"4", " ", "Pi", " ", 
     RowBox[{"10", "^", 
      RowBox[{"-", "7"}]}]}], "*)"}]}]}]], "Input"],

Cell[BoxData["0.477464829275686`"], "Output",
 CellChangeTimes->{
  3.4537479659442177`*^9, 3.4537496001816998`*^9, 3.463844461260048*^9, {
   3.478894406093301*^9, 3.4788944212800493`*^9}, 3.478960341011427*^9, 
   3.4794857412898493`*^9, 3.47948605300837*^9, 3.4796583823753366`*^9, 
   3.4800825649736032`*^9, 3.480243676359799*^9, 3.480692247054192*^9, 
   3.4815660060631313`*^9, {3.481940914365226*^9, 3.481940937547433*^9}, 
   3.4819419235105124`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Basic constants", "Subsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
basicvals = Recurse[{
\tkB->1.38 10^-23,
\tT->295,
\tg->9.8,
\tmu0->4 N[Pi] 10^-7,
\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\tmassM->rhomM l N[Pi] a^2,
\tBresid->1.25,\t\t\t\t(* Residual field *)
\tPi->N[Pi],
\tl->0.003175,\t\t\t\t(* Length of magnets *)
\ta->0.0009525,\t\t\t\t(* Radius of magnets *)
\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\tmasspullapart->0.060\t\t(* Force (in kgf) to separate magnets *)
}];\
\>", "Input",
 AspectRatioFixed->True],

Cell["\<\
SOSvals = Recurse[{
\tdpend->0.248,\t(* SOS final design *)
\troptic->0.0762/2,\t(* SOS final design *)
\tdyaw->0.0157,\t(* SOS final design *)
\tmassoptic->0.25,
\tw0->2 N[Pi] 1.0
}];\
\>", "Input"],

Cell["\<\
LOSvals = Recurse[{
\tw0->2 N[Pi] 0.743,
\trwire->0.0031/2,
\tawire->N[Pi] rwire^2,
\tdpend->0.450,\t(* LOS final design *)
\tdyaw->0.0333,\t(* LOS final design *)
\tmassoptic->10.7,
\tloptic->0.1,
\troptic->0.125,
\tIoptic->0.25 massoptic*roptic^2 + (1/12) massoptic loptic^2,
\twpitch->2 N[Pi] 0.6,
\twpend->2 N[Pi] 0.744,
\twyaw->2 N[Pi] 0.5,
\tkpitch->wpitch^2 Ioptic, (* Angular restoring force *)
\tkyaw->wyaw^2 Ioptic, (* Angular restoring force *)\t
\tpitchlever->0.0808,\t(* lever arm, pitch direction, per magnet *)
\tyawlever->0.0808,\t(* lever arm, pitch direction, per magnet *)
\tkxpitch->kpitch/pitchlever
}];\
\>", "Input",
 CellChangeTimes->{3.478894781983313*^9}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["New coil theory analytic part", "Section",
 CellChangeTimes->{{3.453751003114501*^9, 3.4537510253033*^9}}],

Cell["\<\
useprecomputed=True; (* set to True to save a few time-consuming integrals *)\
\
\>", "Input"],

Cell[CellGroupData[{

Cell["Force off the axis in both r and z", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
Element of force due to element of volume in coil and element of volume in \
magnet as function of r1, r2, theta1, theta2, z1, z2\
\>", "Text"],

Cell["\<\
fdr1dr2dtheta1dtheta2dz1dz2 = (
   -r1*r2*currentdipoleforce 
   /. dx -> r1*Cos[theta1] 
   /. dy -> r1*Sin[theta1] 
   /. dz -> z1 
   /. j1x -> coilsigma*Sin[theta1] 
   /. j1y -> -coilsigma*Cos[theta1] 
   /. j1z -> 0 
   /. Xx -> r2*Cos[theta2] 
   /.  Yy -> r2*Sin[theta2] 
   /. Zz -> z2 
   /. m2x -> 0 
   /. m2y -> 0 
   /. m2z -> mz
); \
\>", "Input",
 CellChangeTimes->{{3.478888754037179*^9, 3.478888798683169*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Do z1 integral analytically", "Text"],

Cell[CellGroupData[{

Cell["Precomputed result", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fdr1dr2dtheta1dtheta2dz2pre", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"4", "*", "Pi"}], ")"}]}], "*", "mu0", "*", "mz", "*", "r1", 
     "*", "r2", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], "*", "coilsigma", "*", 
             RowBox[{"coilz1", "^", "3"}], "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
            RowBox[{"4", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "4"}], "*", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
            RowBox[{"5", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
            RowBox[{"coilsigma", "*", "coilz1", "*", 
             RowBox[{"r2", "^", "4"}], "*", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
            RowBox[{"6", "*", "coilsigma", "*", 
             RowBox[{"coilz1", "^", "2"}], "*", 
             RowBox[{"r1", "^", "2"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
            RowBox[{"4", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "4"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
            RowBox[{"5", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
            RowBox[{"coilsigma", "*", 
             RowBox[{"r2", "^", "4"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
            RowBox[{"6", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"z2", "^", "2"}], "*", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
            RowBox[{"2", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"z2", "^", "3"}], "*", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
            RowBox[{"2", "*", "coilsigma", "*", 
             RowBox[{"coilz1", "^", "3"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
            RowBox[{"3", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
            RowBox[{"3", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r2", "^", "4"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"6", "*", "coilsigma", "*", 
             RowBox[{"coilz1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"3", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"3", "*", "coilsigma", "*", 
             RowBox[{"r2", "^", "4"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
            RowBox[{"6", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r2", "^", "2"}], "*", 
             RowBox[{"z2", "^", "2"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"2", "*", "coilsigma", "*", 
             RowBox[{"r2", "^", "2"}], "*", 
             RowBox[{"z2", "^", "3"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"8", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "3"}], "*", "r2", "*", 
             RowBox[{"Cos", "[", "theta1", "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}]}], "+", 
            RowBox[{"2", "*", "coilsigma", "*", "coilz1", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", 
             RowBox[{"Cos", "[", "theta1", "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}]}], "-", 
            RowBox[{"8", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "3"}], "*", "r2", "*", "z2", "*", 
             RowBox[{"Cos", "[", "theta1", "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}]}], "-", 
            RowBox[{"2", "*", "coilsigma", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", "theta1", "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}]}], "+", 
            RowBox[{"6", "*", "coilsigma", "*", "coilz1", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}]}], "-", 
            RowBox[{"6", "*", "coilsigma", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}]}], "+", 
            RowBox[{"coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "3"}], "*", "r2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
            RowBox[{"coilsigma", "*", "coilz1", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
            RowBox[{"coilsigma", "*", 
             RowBox[{"r1", "^", "3"}], "*", "r2", "*", "z2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
            RowBox[{"coilsigma", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
            RowBox[{"2", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
            RowBox[{"2", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
            RowBox[{"4", "*", "coilsigma", "*", 
             RowBox[{"coilz1", "^", "3"}], "*", "r1", "*", "r2", "*", 
             RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
            RowBox[{"7", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "3"}], "*", "r2", "*", 
             RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
            RowBox[{"7", "*", "coilsigma", "*", "coilz1", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", 
             RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
            RowBox[{"12", "*", "coilsigma", "*", 
             RowBox[{"coilz1", "^", "2"}], "*", "r1", "*", "r2", "*", "z2", 
             "*", 
             RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
            RowBox[{"7", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "3"}], "*", "r2", "*", "z2", "*", 
             RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
            RowBox[{"7", "*", "coilsigma", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
            RowBox[{
            "12", "*", "coilsigma", "*", "coilz1", "*", "r1", "*", "r2", "*", 
             
             RowBox[{"z2", "^", "2"}], "*", 
             RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
            RowBox[{"4", "*", "coilsigma", "*", "r1", "*", "r2", "*", 
             RowBox[{"z2", "^", "3"}], "*", 
             RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
            RowBox[{"14", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
             RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
            RowBox[{"14", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
             RowBox[{"Cos", "[", "theta2", "]"}]}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"2", "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"r1", "^", "2"}], "+", 
               RowBox[{"r2", "^", "2"}], "-", 
               RowBox[{"2", "*", "r1", "*", "r2", "*", 
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "^", 
             "2"}], "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"coilz1", "^", "2"}], "+", 
               RowBox[{"r1", "^", "2"}], "+", 
               RowBox[{"r2", "^", "2"}], "-", 
               RowBox[{"2", "*", "coilz1", "*", "z2"}], "+", 
               RowBox[{"z2", "^", "2"}], "-", 
               RowBox[{"2", "*", "r1", "*", "r2", "*", 
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "^", 
             RowBox[{"(", 
              RowBox[{"3", "/", "2"}], ")"}]}]}], ")"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], "*", "coilsigma", "*", 
           RowBox[{"coilz2", "^", "3"}], "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
          RowBox[{"4", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "4"}], "*", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
          RowBox[{"5", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
          RowBox[{"coilsigma", "*", "coilz2", "*", 
           RowBox[{"r2", "^", "4"}], "*", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
          RowBox[{"6", "*", "coilsigma", "*", 
           RowBox[{"coilz2", "^", "2"}], "*", 
           RowBox[{"r1", "^", "2"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
          RowBox[{"4", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "4"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
          RowBox[{"5", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
          RowBox[{"coilsigma", "*", 
           RowBox[{"r2", "^", "4"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
          RowBox[{"6", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"z2", "^", "2"}], "*", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
          RowBox[{"2", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"z2", "^", "3"}], "*", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
          RowBox[{"2", "*", "coilsigma", "*", 
           RowBox[{"coilz2", "^", "3"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"3", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"3", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r2", "^", "4"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"6", "*", "coilsigma", "*", 
           RowBox[{"coilz2", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"3", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"3", "*", "coilsigma", "*", 
           RowBox[{"r2", "^", "4"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"6", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r2", "^", "2"}], "*", 
           RowBox[{"z2", "^", "2"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"2", "*", "coilsigma", "*", 
           RowBox[{"r2", "^", "2"}], "*", 
           RowBox[{"z2", "^", "3"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"8", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "3"}], "*", "r2", "*", 
           RowBox[{"Cos", "[", "theta1", "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"2", "*", "coilsigma", "*", "coilz2", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", 
           RowBox[{"Cos", "[", "theta1", "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"8", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "3"}], "*", "r2", "*", "z2", "*", 
           RowBox[{"Cos", "[", "theta1", "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"2", "*", "coilsigma", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", "theta1", "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"6", "*", "coilsigma", "*", "coilz2", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"6", "*", "coilsigma", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "3"}], "*", "r2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"coilsigma", "*", "coilz2", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"coilsigma", "*", 
           RowBox[{"r1", "^", "3"}], "*", "r2", "*", "z2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"coilsigma", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"2", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"2", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"4", "*", "coilsigma", "*", 
           RowBox[{"coilz2", "^", "3"}], "*", "r1", "*", "r2", "*", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
          RowBox[{"7", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "3"}], "*", "r2", "*", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
          RowBox[{"7", "*", "coilsigma", "*", "coilz2", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
          RowBox[{"12", "*", "coilsigma", "*", 
           RowBox[{"coilz2", "^", "2"}], "*", "r1", "*", "r2", "*", "z2", "*", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
          RowBox[{"7", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "3"}], "*", "r2", "*", "z2", "*", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
          RowBox[{"7", "*", "coilsigma", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
          RowBox[{
          "12", "*", "coilsigma", "*", "coilz2", "*", "r1", "*", "r2", "*", 
           RowBox[{"z2", "^", "2"}], "*", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
          RowBox[{"4", "*", "coilsigma", "*", "r1", "*", "r2", "*", 
           RowBox[{"z2", "^", "3"}], "*", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
          RowBox[{"14", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
          RowBox[{"14", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
           RowBox[{"Cos", "[", "theta2", "]"}]}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"r1", "^", "2"}], "+", 
             RowBox[{"r2", "^", "2"}], "-", 
             RowBox[{"2", "*", "r1", "*", "r2", "*", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "^", 
           "2"}], "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"coilz2", "^", "2"}], "+", 
             RowBox[{"r1", "^", "2"}], "+", 
             RowBox[{"r2", "^", "2"}], "-", 
             RowBox[{"2", "*", "coilz2", "*", "z2"}], "+", 
             RowBox[{"z2", "^", "2"}], "-", 
             RowBox[{"2", "*", "r1", "*", "r2", "*", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "^", 
           RowBox[{"(", 
            RowBox[{"3", "/", "2"}], ")"}]}]}], ")"}]}]}], ")"}]}], ",", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"4", "*", "Pi"}], ")"}]}], "*", "mu0", "*", "mz", "*", "r1", 
     "*", "r2", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], "*", "coilsigma", "*", 
             RowBox[{"coilz1", "^", "3"}], "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
            RowBox[{"4", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "4"}], "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
            RowBox[{"5", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
            RowBox[{"coilsigma", "*", "coilz1", "*", 
             RowBox[{"r2", "^", "4"}], "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
            RowBox[{"6", "*", "coilsigma", "*", 
             RowBox[{"coilz1", "^", "2"}], "*", 
             RowBox[{"r1", "^", "2"}], "*", "z2", "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
            RowBox[{"4", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "4"}], "*", "z2", "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
            RowBox[{"5", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
            RowBox[{"coilsigma", "*", 
             RowBox[{"r2", "^", "4"}], "*", "z2", "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
            RowBox[{"6", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"z2", "^", "2"}], "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
            RowBox[{"2", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"z2", "^", "3"}], "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
            RowBox[{"8", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "3"}], "*", "r2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
            RowBox[{"2", "*", "coilsigma", "*", "coilz1", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
            RowBox[{"8", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "3"}], "*", "r2", "*", "z2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
            RowBox[{"2", "*", "coilsigma", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
            RowBox[{"2", "*", "coilsigma", "*", 
             RowBox[{"coilz1", "^", "3"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"3", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"3", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r2", "^", "4"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
            RowBox[{"6", "*", "coilsigma", "*", 
             RowBox[{"coilz1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
            RowBox[{"3", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
            RowBox[{"3", "*", "coilsigma", "*", 
             RowBox[{"r2", "^", "4"}], "*", "z2", "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"6", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r2", "^", "2"}], "*", 
             RowBox[{"z2", "^", "2"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
            RowBox[{"2", "*", "coilsigma", "*", 
             RowBox[{"r2", "^", "2"}], "*", 
             RowBox[{"z2", "^", "3"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
            RowBox[{"6", "*", "coilsigma", "*", "coilz1", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"6", "*", "coilsigma", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "3"}], "*", "r2", "*", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
            RowBox[{"coilsigma", "*", "coilz1", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
            RowBox[{"coilsigma", "*", 
             RowBox[{"r1", "^", "3"}], "*", "r2", "*", "z2", "*", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
            RowBox[{"coilsigma", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
            RowBox[{"2", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
            RowBox[{"2", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
            RowBox[{"4", "*", "coilsigma", "*", 
             RowBox[{"coilz1", "^", "3"}], "*", "r1", "*", "r2", "*", 
             RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
            RowBox[{"7", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "3"}], "*", "r2", "*", 
             RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
            RowBox[{"7", "*", "coilsigma", "*", "coilz1", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", 
             RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
            RowBox[{"12", "*", "coilsigma", "*", 
             RowBox[{"coilz1", "^", "2"}], "*", "r1", "*", "r2", "*", "z2", 
             "*", 
             RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
            RowBox[{"7", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "3"}], "*", "r2", "*", "z2", "*", 
             RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
            RowBox[{"7", "*", "coilsigma", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
             RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
            RowBox[{
            "12", "*", "coilsigma", "*", "coilz1", "*", "r1", "*", "r2", "*", 
             
             RowBox[{"z2", "^", "2"}], "*", 
             RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
            RowBox[{"4", "*", "coilsigma", "*", "r1", "*", "r2", "*", 
             RowBox[{"z2", "^", "3"}], "*", 
             RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
            RowBox[{"14", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
             RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
            RowBox[{"14", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
             RowBox[{"Sin", "[", "theta2", "]"}]}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"2", "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"r1", "^", "2"}], "+", 
               RowBox[{"r2", "^", "2"}], "-", 
               RowBox[{"2", "*", "r1", "*", "r2", "*", 
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "^", 
             "2"}], "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"coilz1", "^", "2"}], "+", 
               RowBox[{"r1", "^", "2"}], "+", 
               RowBox[{"r2", "^", "2"}], "-", 
               RowBox[{"2", "*", "coilz1", "*", "z2"}], "+", 
               RowBox[{"z2", "^", "2"}], "-", 
               RowBox[{"2", "*", "r1", "*", "r2", "*", 
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "^", 
             RowBox[{"(", 
              RowBox[{"3", "/", "2"}], ")"}]}]}], ")"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], "*", "coilsigma", "*", 
           RowBox[{"coilz2", "^", "3"}], "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
          RowBox[{"4", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "4"}], "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
          RowBox[{"5", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
          RowBox[{"coilsigma", "*", "coilz2", "*", 
           RowBox[{"r2", "^", "4"}], "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"6", "*", "coilsigma", "*", 
           RowBox[{"coilz2", "^", "2"}], "*", 
           RowBox[{"r1", "^", "2"}], "*", "z2", "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"4", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "4"}], "*", "z2", "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"5", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"coilsigma", "*", 
           RowBox[{"r2", "^", "4"}], "*", "z2", "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
          RowBox[{"6", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"z2", "^", "2"}], "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"2", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"z2", "^", "3"}], "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"8", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "3"}], "*", "r2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"2", "*", "coilsigma", "*", "coilz2", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
          RowBox[{"8", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "3"}], "*", "r2", "*", "z2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
          RowBox[{"2", "*", "coilsigma", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"2", "*", "coilsigma", "*", 
           RowBox[{"coilz2", "^", "3"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"3", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"3", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r2", "^", "4"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"6", "*", "coilsigma", "*", 
           RowBox[{"coilz2", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"3", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"3", "*", "coilsigma", "*", 
           RowBox[{"r2", "^", "4"}], "*", "z2", "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"6", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r2", "^", "2"}], "*", 
           RowBox[{"z2", "^", "2"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"2", "*", "coilsigma", "*", 
           RowBox[{"r2", "^", "2"}], "*", 
           RowBox[{"z2", "^", "3"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"6", "*", "coilsigma", "*", "coilz2", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"6", "*", "coilsigma", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "3"}], "*", "r2", "*", 
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"coilsigma", "*", "coilz2", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"coilsigma", "*", 
           RowBox[{"r1", "^", "3"}], "*", "r2", "*", "z2", "*", 
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"coilsigma", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"2", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"2", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"4", "*", "coilsigma", "*", 
           RowBox[{"coilz2", "^", "3"}], "*", "r1", "*", "r2", "*", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
          RowBox[{"7", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "3"}], "*", "r2", "*", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
          RowBox[{"7", "*", "coilsigma", "*", "coilz2", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
          RowBox[{"12", "*", "coilsigma", "*", 
           RowBox[{"coilz2", "^", "2"}], "*", "r1", "*", "r2", "*", "z2", "*", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
          RowBox[{"7", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "3"}], "*", "r2", "*", "z2", "*", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
          RowBox[{"7", "*", "coilsigma", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
          RowBox[{
          "12", "*", "coilsigma", "*", "coilz2", "*", "r1", "*", "r2", "*", 
           RowBox[{"z2", "^", "2"}], "*", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
          RowBox[{"4", "*", "coilsigma", "*", "r1", "*", "r2", "*", 
           RowBox[{"z2", "^", "3"}], "*", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
          RowBox[{"14", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
          RowBox[{"14", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
           RowBox[{"Sin", "[", "theta2", "]"}]}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"r1", "^", "2"}], "+", 
             RowBox[{"r2", "^", "2"}], "-", 
             RowBox[{"2", "*", "r1", "*", "r2", "*", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "^", 
           "2"}], "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"coilz2", "^", "2"}], "+", 
             RowBox[{"r1", "^", "2"}], "+", 
             RowBox[{"r2", "^", "2"}], "-", 
             RowBox[{"2", "*", "coilz2", "*", "z2"}], "+", 
             RowBox[{"z2", "^", "2"}], "-", 
             RowBox[{"2", "*", "r1", "*", "r2", "*", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "^", 
           RowBox[{"(", 
            RowBox[{"3", "/", "2"}], ")"}]}]}], ")"}]}]}], ")"}]}], ",", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"4", "*", "Pi"}], ")"}]}], "*", "mu0", "*", "mz", "*", "r1", 
     "*", "r2", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"coilsigma", "*", 
            RowBox[{"(", 
             RowBox[{"r1", "-", 
              RowBox[{"r2", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}]}], ")"}], 
          "/", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"coilz1", "^", "2"}], "+", 
             RowBox[{"r1", "^", "2"}], "+", 
             RowBox[{"r2", "^", "2"}], "-", 
             RowBox[{"2", "*", "coilz1", "*", "z2"}], "+", 
             RowBox[{"z2", "^", "2"}], "-", 
             RowBox[{"2", "*", "r1", "*", "r2", "*", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "^", 
           RowBox[{"(", 
            RowBox[{"3", "/", "2"}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"coilsigma", "*", 
          RowBox[{"(", 
           RowBox[{"r1", "-", 
            RowBox[{"r2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}]}], ")"}], 
        "/", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"coilz2", "^", "2"}], "+", 
           RowBox[{"r1", "^", "2"}], "+", 
           RowBox[{"r2", "^", "2"}], "-", 
           RowBox[{"2", "*", "coilz2", "*", "z2"}], "+", 
           RowBox[{"z2", "^", "2"}], "-", 
           RowBox[{"2", "*", "r1", "*", "r2", "*", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"3", "/", "2"}], ")"}]}]}]}], ")"}]}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"4", " ", "\[Pi]"}]], 
    RowBox[{"mu0", " ", "mz", " ", "r1", " ", "r2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "coilsigma", " ", 
            SuperscriptBox["coilz1", "3"], " ", 
            SuperscriptBox["r1", "2"], " ", 
            RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
           RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
            SuperscriptBox["r1", "4"], " ", 
            RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
           RowBox[{"5", " ", "coilsigma", " ", "coilz1", " ", 
            SuperscriptBox["r1", "2"], " ", 
            SuperscriptBox["r2", "2"], " ", 
            RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
           RowBox[{"coilsigma", " ", "coilz1", " ", 
            SuperscriptBox["r2", "4"], " ", 
            RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
           RowBox[{"6", " ", "coilsigma", " ", 
            SuperscriptBox["coilz1", "2"], " ", 
            SuperscriptBox["r1", "2"], " ", "z2", " ", 
            RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
           RowBox[{"4", " ", "coilsigma", " ", 
            SuperscriptBox["r1", "4"], " ", "z2", " ", 
            RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
           RowBox[{"5", " ", "coilsigma", " ", 
            SuperscriptBox["r1", "2"], " ", 
            SuperscriptBox["r2", "2"], " ", "z2", " ", 
            RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
           RowBox[{"coilsigma", " ", 
            SuperscriptBox["r2", "4"], " ", "z2", " ", 
            RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
           RowBox[{"6", " ", "coilsigma", " ", "coilz1", " ", 
            SuperscriptBox["r1", "2"], " ", 
            SuperscriptBox["z2", "2"], " ", 
            RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
           RowBox[{"2", " ", "coilsigma", " ", 
            SuperscriptBox["r1", "2"], " ", 
            SuperscriptBox["z2", "3"], " ", 
            RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
           RowBox[{"2", " ", "coilsigma", " ", 
            SuperscriptBox["coilz1", "3"], " ", 
            SuperscriptBox["r2", "2"], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", 
              RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
           RowBox[{"3", " ", "coilsigma", " ", "coilz1", " ", 
            SuperscriptBox["r1", "2"], " ", 
            SuperscriptBox["r2", "2"], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", 
              RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
           RowBox[{"3", " ", "coilsigma", " ", "coilz1", " ", 
            SuperscriptBox["r2", "4"], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", 
              RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
           RowBox[{"6", " ", "coilsigma", " ", 
            SuperscriptBox["coilz1", "2"], " ", 
            SuperscriptBox["r2", "2"], " ", "z2", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", 
              RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
           RowBox[{"3", " ", "coilsigma", " ", 
            SuperscriptBox["r1", "2"], " ", 
            SuperscriptBox["r2", "2"], " ", "z2", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", 
              RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
           RowBox[{"3", " ", "coilsigma", " ", 
            SuperscriptBox["r2", "4"], " ", "z2", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", 
              RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
           RowBox[{"6", " ", "coilsigma", " ", "coilz1", " ", 
            SuperscriptBox["r2", "2"], " ", 
            SuperscriptBox["z2", "2"], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", 
              RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
           RowBox[{"2", " ", "coilsigma", " ", 
            SuperscriptBox["r2", "2"], " ", 
            SuperscriptBox["z2", "3"], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", 
              RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
           RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", 
            SuperscriptBox["r1", "3"], " ", "r2", " ", 
            RowBox[{"Cos", "[", "theta1", "]"}], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", "theta2"}], "]"}]}], "+", 
           RowBox[{"2", " ", "coilsigma", " ", "coilz1", " ", "r1", " ", 
            SuperscriptBox["r2", "3"], " ", 
            RowBox[{"Cos", "[", "theta1", "]"}], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", "theta2"}], "]"}]}], "-", 
           RowBox[{"8", " ", "coilsigma", " ", 
            SuperscriptBox["r1", "3"], " ", "r2", " ", "z2", " ", 
            RowBox[{"Cos", "[", "theta1", "]"}], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", "theta2"}], "]"}]}], "-", 
           RowBox[{"2", " ", "coilsigma", " ", "r1", " ", 
            SuperscriptBox["r2", "3"], " ", "z2", " ", 
            RowBox[{"Cos", "[", "theta1", "]"}], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", "theta2"}], "]"}]}], "+", 
           RowBox[{"6", " ", "coilsigma", " ", "coilz1", " ", "r1", " ", 
            SuperscriptBox["r2", "3"], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", 
              RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", "theta2"}], "]"}]}], "-", 
           RowBox[{"6", " ", "coilsigma", " ", "r1", " ", 
            SuperscriptBox["r2", "3"], " ", "z2", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", 
              RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", "theta2"}], "]"}]}], "+", 
           RowBox[{"coilsigma", " ", "coilz1", " ", 
            SuperscriptBox["r1", "3"], " ", "r2", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{
              RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
           RowBox[{"coilsigma", " ", "coilz1", " ", "r1", " ", 
            SuperscriptBox["r2", "3"], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{
              RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
           RowBox[{"coilsigma", " ", 
            SuperscriptBox["r1", "3"], " ", "r2", " ", "z2", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{
              RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
           RowBox[{"coilsigma", " ", "r1", " ", 
            SuperscriptBox["r2", "3"], " ", "z2", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{
              RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
           RowBox[{"2", " ", "coilsigma", " ", "coilz1", " ", 
            SuperscriptBox["r1", "2"], " ", 
            SuperscriptBox["r2", "2"], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{
              RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
           RowBox[{"2", " ", "coilsigma", " ", 
            SuperscriptBox["r1", "2"], " ", 
            SuperscriptBox["r2", "2"], " ", "z2", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{
              RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
           RowBox[{"4", " ", "coilsigma", " ", 
            SuperscriptBox["coilz1", "3"], " ", "r1", " ", "r2", " ", 
            RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
           RowBox[{"7", " ", "coilsigma", " ", "coilz1", " ", 
            SuperscriptBox["r1", "3"], " ", "r2", " ", 
            RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
           RowBox[{"7", " ", "coilsigma", " ", "coilz1", " ", "r1", " ", 
            SuperscriptBox["r2", "3"], " ", 
            RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
           RowBox[{"12", " ", "coilsigma", " ", 
            SuperscriptBox["coilz1", "2"], " ", "r1", " ", "r2", " ", "z2", 
            " ", 
            RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
           RowBox[{"7", " ", "coilsigma", " ", 
            SuperscriptBox["r1", "3"], " ", "r2", " ", "z2", " ", 
            RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
           RowBox[{"7", " ", "coilsigma", " ", "r1", " ", 
            SuperscriptBox["r2", "3"], " ", "z2", " ", 
            RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
           RowBox[{
           "12", " ", "coilsigma", " ", "coilz1", " ", "r1", " ", "r2", " ", 
            SuperscriptBox["z2", "2"], " ", 
            RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
           RowBox[{"4", " ", "coilsigma", " ", "r1", " ", "r2", " ", 
            SuperscriptBox["z2", "3"], " ", 
            RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
           RowBox[{"14", " ", "coilsigma", " ", "coilz1", " ", 
            SuperscriptBox["r1", "2"], " ", 
            SuperscriptBox["r2", "2"], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
            RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
           RowBox[{"14", " ", "coilsigma", " ", 
            SuperscriptBox["r1", "2"], " ", 
            SuperscriptBox["r2", "2"], " ", "z2", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
            RowBox[{"Cos", "[", "theta2", "]"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["r1", "2"], "+", 
              SuperscriptBox["r2", "2"], "-", 
              RowBox[{"2", " ", "r1", " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "2"], 
           " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["coilz1", "2"], "+", 
              SuperscriptBox["r1", "2"], "+", 
              SuperscriptBox["r2", "2"], "-", 
              RowBox[{"2", " ", "coilz1", " ", "z2"}], "+", 
              SuperscriptBox["z2", "2"], "-", 
              RowBox[{"2", " ", "r1", " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], 
            RowBox[{"3", "/", "2"}]]}], ")"}]}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", "coilsigma", " ", 
           SuperscriptBox["coilz2", "3"], " ", 
           SuperscriptBox["r1", "2"], " ", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
          RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "4"], " ", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
          RowBox[{"5", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
          RowBox[{"coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r2", "4"], " ", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
          RowBox[{"6", " ", "coilsigma", " ", 
           SuperscriptBox["coilz2", "2"], " ", 
           SuperscriptBox["r1", "2"], " ", "z2", " ", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
          RowBox[{"4", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "4"], " ", "z2", " ", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
          RowBox[{"5", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", "z2", " ", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
          RowBox[{"coilsigma", " ", 
           SuperscriptBox["r2", "4"], " ", "z2", " ", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
          RowBox[{"6", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["z2", "2"], " ", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
          RowBox[{"2", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["z2", "3"], " ", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
          RowBox[{"2", " ", "coilsigma", " ", 
           SuperscriptBox["coilz2", "3"], " ", 
           SuperscriptBox["r2", "2"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"3", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"3", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r2", "4"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"6", " ", "coilsigma", " ", 
           SuperscriptBox["coilz2", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", "z2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"3", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", "z2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"3", " ", "coilsigma", " ", 
           SuperscriptBox["r2", "4"], " ", "z2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"6", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r2", "2"], " ", 
           SuperscriptBox["z2", "2"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"2", " ", "coilsigma", " ", 
           SuperscriptBox["r2", "2"], " ", 
           SuperscriptBox["z2", "3"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "3"], " ", "r2", " ", 
           RowBox[{"Cos", "[", "theta1", "]"}], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"2", " ", "coilsigma", " ", "coilz2", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", 
           RowBox[{"Cos", "[", "theta1", "]"}], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"8", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "3"], " ", "r2", " ", "z2", " ", 
           RowBox[{"Cos", "[", "theta1", "]"}], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"2", " ", "coilsigma", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", "z2", " ", 
           RowBox[{"Cos", "[", "theta1", "]"}], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"6", " ", "coilsigma", " ", "coilz2", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"6", " ", "coilsigma", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", "z2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "3"], " ", "r2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"coilsigma", " ", "coilz2", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"coilsigma", " ", 
           SuperscriptBox["r1", "3"], " ", "r2", " ", "z2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"coilsigma", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", "z2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"2", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"2", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", "z2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"4", " ", "coilsigma", " ", 
           SuperscriptBox["coilz2", "3"], " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
          RowBox[{"7", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "3"], " ", "r2", " ", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
          RowBox[{"7", " ", "coilsigma", " ", "coilz2", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
          RowBox[{"12", " ", "coilsigma", " ", 
           SuperscriptBox["coilz2", "2"], " ", "r1", " ", "r2", " ", "z2", 
           " ", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
          RowBox[{"7", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "3"], " ", "r2", " ", "z2", " ", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
          RowBox[{"7", " ", "coilsigma", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", "z2", " ", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
          RowBox[{
          "12", " ", "coilsigma", " ", "coilz2", " ", "r1", " ", "r2", " ", 
           SuperscriptBox["z2", "2"], " ", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
          RowBox[{"4", " ", "coilsigma", " ", "r1", " ", "r2", " ", 
           SuperscriptBox["z2", "3"], " ", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
          RowBox[{"14", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
          RowBox[{"14", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", "z2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
           RowBox[{"Cos", "[", "theta2", "]"}]}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["r1", "2"], "+", 
             SuperscriptBox["r2", "2"], "-", 
             RowBox[{"2", " ", "r1", " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["coilz2", "2"], "+", 
             SuperscriptBox["r1", "2"], "+", 
             SuperscriptBox["r2", "2"], "-", 
             RowBox[{"2", " ", "coilz2", " ", "z2"}], "+", 
             SuperscriptBox["z2", "2"], "-", 
             RowBox[{"2", " ", "r1", " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], 
           RowBox[{"3", "/", "2"}]]}], ")"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"4", " ", "\[Pi]"}]], 
    RowBox[{"mu0", " ", "mz", " ", "r1", " ", "r2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "coilsigma", " ", 
            SuperscriptBox["coilz1", "3"], " ", 
            SuperscriptBox["r1", "2"], " ", 
            RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
           RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
            SuperscriptBox["r1", "4"], " ", 
            RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
           RowBox[{"5", " ", "coilsigma", " ", "coilz1", " ", 
            SuperscriptBox["r1", "2"], " ", 
            SuperscriptBox["r2", "2"], " ", 
            RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
           RowBox[{"coilsigma", " ", "coilz1", " ", 
            SuperscriptBox["r2", "4"], " ", 
            RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
           RowBox[{"6", " ", "coilsigma", " ", 
            SuperscriptBox["coilz1", "2"], " ", 
            SuperscriptBox["r1", "2"], " ", "z2", " ", 
            RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
           RowBox[{"4", " ", "coilsigma", " ", 
            SuperscriptBox["r1", "4"], " ", "z2", " ", 
            RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
           RowBox[{"5", " ", "coilsigma", " ", 
            SuperscriptBox["r1", "2"], " ", 
            SuperscriptBox["r2", "2"], " ", "z2", " ", 
            RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
           RowBox[{"coilsigma", " ", 
            SuperscriptBox["r2", "4"], " ", "z2", " ", 
            RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
           RowBox[{"6", " ", "coilsigma", " ", "coilz1", " ", 
            SuperscriptBox["r1", "2"], " ", 
            SuperscriptBox["z2", "2"], " ", 
            RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
           RowBox[{"2", " ", "coilsigma", " ", 
            SuperscriptBox["r1", "2"], " ", 
            SuperscriptBox["z2", "3"], " ", 
            RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
           RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", 
            SuperscriptBox["r1", "3"], " ", "r2", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
            RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
           RowBox[{"2", " ", "coilsigma", " ", "coilz1", " ", "r1", " ", 
            SuperscriptBox["r2", "3"], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
            RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
           RowBox[{"8", " ", "coilsigma", " ", 
            SuperscriptBox["r1", "3"], " ", "r2", " ", "z2", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
            RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
           RowBox[{"2", " ", "coilsigma", " ", "r1", " ", 
            SuperscriptBox["r2", "3"], " ", "z2", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
            RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
           RowBox[{"2", " ", "coilsigma", " ", 
            SuperscriptBox["coilz1", "3"], " ", 
            SuperscriptBox["r2", "2"], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"theta1", "-", 
              RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
           RowBox[{"3", " ", "coilsigma", " ", "coilz1", " ", 
            SuperscriptBox["r1", "2"], " ", 
            SuperscriptBox["r2", "2"], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"theta1", "-", 
              RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
           RowBox[{"3", " ", "coilsigma", " ", "coilz1", " ", 
            SuperscriptBox["r2", "4"], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"theta1", "-", 
              RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
           RowBox[{"6", " ", "coilsigma", " ", 
            SuperscriptBox["coilz1", "2"], " ", 
            SuperscriptBox["r2", "2"], " ", "z2", " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"theta1", "-", 
              RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
           RowBox[{"3", " ", "coilsigma", " ", 
            SuperscriptBox["r1", "2"], " ", 
            SuperscriptBox["r2", "2"], " ", "z2", " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"theta1", "-", 
              RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
           RowBox[{"3", " ", "coilsigma", " ", 
            SuperscriptBox["r2", "4"], " ", "z2", " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"theta1", "-", 
              RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
           RowBox[{"6", " ", "coilsigma", " ", "coilz1", " ", 
            SuperscriptBox["r2", "2"], " ", 
            SuperscriptBox["z2", "2"], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"theta1", "-", 
              RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
           RowBox[{"2", " ", "coilsigma", " ", 
            SuperscriptBox["r2", "2"], " ", 
            SuperscriptBox["z2", "3"], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"theta1", "-", 
              RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
           RowBox[{"6", " ", "coilsigma", " ", "coilz1", " ", "r1", " ", 
            SuperscriptBox["r2", "3"], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"theta1", "-", 
              RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
           RowBox[{"6", " ", "coilsigma", " ", "r1", " ", 
            SuperscriptBox["r2", "3"], " ", "z2", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"theta1", "-", 
              RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
           RowBox[{"coilsigma", " ", "coilz1", " ", 
            SuperscriptBox["r1", "3"], " ", "r2", " ", 
            RowBox[{"Sin", "[", 
             RowBox[{
              RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
           RowBox[{"coilsigma", " ", "coilz1", " ", "r1", " ", 
            SuperscriptBox["r2", "3"], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{
              RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
           RowBox[{"coilsigma", " ", 
            SuperscriptBox["r1", "3"], " ", "r2", " ", "z2", " ", 
            RowBox[{"Sin", "[", 
             RowBox[{
              RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
           RowBox[{"coilsigma", " ", "r1", " ", 
            SuperscriptBox["r2", "3"], " ", "z2", " ", 
            RowBox[{"Sin", "[", 
             RowBox[{
              RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
           RowBox[{"2", " ", "coilsigma", " ", "coilz1", " ", 
            SuperscriptBox["r1", "2"], " ", 
            SuperscriptBox["r2", "2"], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{
              RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
           RowBox[{"2", " ", "coilsigma", " ", 
            SuperscriptBox["r1", "2"], " ", 
            SuperscriptBox["r2", "2"], " ", "z2", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{
              RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
           RowBox[{"4", " ", "coilsigma", " ", 
            SuperscriptBox["coilz1", "3"], " ", "r1", " ", "r2", " ", 
            RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
           RowBox[{"7", " ", "coilsigma", " ", "coilz1", " ", 
            SuperscriptBox["r1", "3"], " ", "r2", " ", 
            RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
           RowBox[{"7", " ", "coilsigma", " ", "coilz1", " ", "r1", " ", 
            SuperscriptBox["r2", "3"], " ", 
            RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
           RowBox[{"12", " ", "coilsigma", " ", 
            SuperscriptBox["coilz1", "2"], " ", "r1", " ", "r2", " ", "z2", 
            " ", 
            RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
           RowBox[{"7", " ", "coilsigma", " ", 
            SuperscriptBox["r1", "3"], " ", "r2", " ", "z2", " ", 
            RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
           RowBox[{"7", " ", "coilsigma", " ", "r1", " ", 
            SuperscriptBox["r2", "3"], " ", "z2", " ", 
            RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
           RowBox[{
           "12", " ", "coilsigma", " ", "coilz1", " ", "r1", " ", "r2", " ", 
            SuperscriptBox["z2", "2"], " ", 
            RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
           RowBox[{"4", " ", "coilsigma", " ", "r1", " ", "r2", " ", 
            SuperscriptBox["z2", "3"], " ", 
            RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
           RowBox[{"14", " ", "coilsigma", " ", "coilz1", " ", 
            SuperscriptBox["r1", "2"], " ", 
            SuperscriptBox["r2", "2"], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
            RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
           RowBox[{"14", " ", "coilsigma", " ", 
            SuperscriptBox["r1", "2"], " ", 
            SuperscriptBox["r2", "2"], " ", "z2", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
            RowBox[{"Sin", "[", "theta2", "]"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["r1", "2"], "+", 
              SuperscriptBox["r2", "2"], "-", 
              RowBox[{"2", " ", "r1", " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "2"], 
           " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["coilz1", "2"], "+", 
              SuperscriptBox["r1", "2"], "+", 
              SuperscriptBox["r2", "2"], "-", 
              RowBox[{"2", " ", "coilz1", " ", "z2"}], "+", 
              SuperscriptBox["z2", "2"], "-", 
              RowBox[{"2", " ", "r1", " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], 
            RowBox[{"3", "/", "2"}]]}], ")"}]}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", "coilsigma", " ", 
           SuperscriptBox["coilz2", "3"], " ", 
           SuperscriptBox["r1", "2"], " ", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
          RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "4"], " ", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
          RowBox[{"5", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
          RowBox[{"coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r2", "4"], " ", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"6", " ", "coilsigma", " ", 
           SuperscriptBox["coilz2", "2"], " ", 
           SuperscriptBox["r1", "2"], " ", "z2", " ", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"4", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "4"], " ", "z2", " ", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"5", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", "z2", " ", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"coilsigma", " ", 
           SuperscriptBox["r2", "4"], " ", "z2", " ", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
          RowBox[{"6", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["z2", "2"], " ", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"2", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["z2", "3"], " ", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "3"], " ", "r2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"2", " ", "coilsigma", " ", "coilz2", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
          RowBox[{"8", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "3"], " ", "r2", " ", "z2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
          RowBox[{"2", " ", "coilsigma", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", "z2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"2", " ", "coilsigma", " ", 
           SuperscriptBox["coilz2", "3"], " ", 
           SuperscriptBox["r2", "2"], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"3", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"3", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r2", "4"], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"6", " ", "coilsigma", " ", 
           SuperscriptBox["coilz2", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", "z2", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"3", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", "z2", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"3", " ", "coilsigma", " ", 
           SuperscriptBox["r2", "4"], " ", "z2", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"6", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r2", "2"], " ", 
           SuperscriptBox["z2", "2"], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"2", " ", "coilsigma", " ", 
           SuperscriptBox["r2", "2"], " ", 
           SuperscriptBox["z2", "3"], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"6", " ", "coilsigma", " ", "coilz2", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"6", " ", "coilsigma", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", "z2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "3"], " ", "r2", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"coilsigma", " ", "coilz2", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"coilsigma", " ", 
           SuperscriptBox["r1", "3"], " ", "r2", " ", "z2", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"coilsigma", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", "z2", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"2", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"2", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", "z2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"4", " ", "coilsigma", " ", 
           SuperscriptBox["coilz2", "3"], " ", "r1", " ", "r2", " ", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
          RowBox[{"7", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "3"], " ", "r2", " ", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
          RowBox[{"7", " ", "coilsigma", " ", "coilz2", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
          RowBox[{"12", " ", "coilsigma", " ", 
           SuperscriptBox["coilz2", "2"], " ", "r1", " ", "r2", " ", "z2", 
           " ", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
          RowBox[{"7", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "3"], " ", "r2", " ", "z2", " ", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
          RowBox[{"7", " ", "coilsigma", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", "z2", " ", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
          RowBox[{
          "12", " ", "coilsigma", " ", "coilz2", " ", "r1", " ", "r2", " ", 
           SuperscriptBox["z2", "2"], " ", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
          RowBox[{"4", " ", "coilsigma", " ", "r1", " ", "r2", " ", 
           SuperscriptBox["z2", "3"], " ", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
          RowBox[{"14", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
          RowBox[{"14", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", "z2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
           RowBox[{"Sin", "[", "theta2", "]"}]}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["r1", "2"], "+", 
             SuperscriptBox["r2", "2"], "-", 
             RowBox[{"2", " ", "r1", " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["coilz2", "2"], "+", 
             SuperscriptBox["r1", "2"], "+", 
             SuperscriptBox["r2", "2"], "-", 
             RowBox[{"2", " ", "coilz2", " ", "z2"}], "+", 
             SuperscriptBox["z2", "2"], "-", 
             RowBox[{"2", " ", "r1", " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], 
           RowBox[{"3", "/", "2"}]]}], ")"}]}]}], ")"}]}]}], ",", 
   FractionBox[
    RowBox[{"mu0", " ", "mz", " ", "r1", " ", "r2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"coilsigma", " ", 
          RowBox[{"(", 
           RowBox[{"r1", "-", 
            RowBox[{"r2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["coilz1", "2"], "+", 
            SuperscriptBox["r1", "2"], "+", 
            SuperscriptBox["r2", "2"], "-", 
            RowBox[{"2", " ", "coilz1", " ", "z2"}], "+", 
            SuperscriptBox["z2", "2"], "-", 
            RowBox[{"2", " ", "r1", " ", "r2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], 
          RowBox[{"3", "/", "2"}]]]}], "+", 
       FractionBox[
        RowBox[{"coilsigma", " ", 
         RowBox[{"(", 
          RowBox[{"r1", "-", 
           RowBox[{"r2", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["coilz2", "2"], "+", 
           SuperscriptBox["r1", "2"], "+", 
           SuperscriptBox["r2", "2"], "-", 
           RowBox[{"2", " ", "coilz2", " ", "z2"}], "+", 
           SuperscriptBox["z2", "2"], "-", 
           RowBox[{"2", " ", "r1", " ", "r2", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], 
         RowBox[{"3", "/", "2"}]]]}], ")"}]}], 
    RowBox[{"4", " ", "\[Pi]"}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.4537496006556683`*^9, 3.453749665383189*^9, 3.4638444826352386`*^9, {
   3.47889440630746*^9, 3.478894421499799*^9}, 3.47896034120792*^9, 
   3.479485741522573*^9, 3.479486053209323*^9, 3.479658382577471*^9, 
   3.48008256522371*^9, 3.480243676559482*^9, 3.480692247239079*^9, 
   3.481566006301805*^9, 3.481940914621936*^9, 3.481941021808659*^9, 
   3.481941923682448*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Actual calculation", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fdr1dr2dtheta1dtheta2dz2", " ", "=", " ", 
   RowBox[{"If", "[", "\[InvisibleSpace]", 
    RowBox[{
     RowBox[{"!", "useprecomputed"}], ",", 
     RowBox[{"Integrate", "[", 
      RowBox[{"fdr1dr2dtheta1dtheta2dz1dz2", ",", 
       RowBox[{"{", 
        RowBox[{"z1", ",", "coilz1", ",", "coilz2"}], "}"}]}], "]"}], ",", 
     "fdr1dr2dtheta1dtheta2dz2pre"}], "]"}]}], ";"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Do z2 integral analytically", "Text"],

Cell[CellGroupData[{

Cell["Precomputed result (HUGE!!!)", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fdr1dr2dtheta1dtheta2pre", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", " ", "\[Pi]"}]], 
      RowBox[{"(", 
       RowBox[{"mu0", " ", "mz", " ", "r1", " ", "r2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "16"}], " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"coilsigma", " ", 
               SuperscriptBox["l", "4"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
               
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
               " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["l", "3"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "4"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r2", "6"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"coilsigma", " ", 
               SuperscriptBox["l", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
               
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
               " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["l", "3"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"6", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"6", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r2", "6"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"12", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "48", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"coilsigma", " ", 
               SuperscriptBox["l", "4"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
               
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
               " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["l", "3"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "4"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r2", "6"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"coilsigma", " ", 
               SuperscriptBox["l", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
               
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
               " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["l", "3"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"6", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"6", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r2", "6"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"12", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "48", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "5"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{
              "8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
               
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{
              "8", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "5"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{
              "8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
               
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{
              "8", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
               "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "4"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"64", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
               "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "pos", " ", "r1", " ", 
               "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", "r1",
                " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l",
                " ", "pos", " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", "r1",
                " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["l", "3"], " ", "pos", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"96", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"96", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"64", " ", "coilsigma", " ", "l", " ", 
               SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "4"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"10", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"40", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"40", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "5"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
               
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"10", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "40", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"40", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"64", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"20", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"128", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"80", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"80", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
               "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "4"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"64", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
               "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "pos", " ", "r1", " ", 
               "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", "r1",
                " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l",
                " ", "pos", " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", "r1",
                " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["l", "3"], " ", "pos", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"96", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"96", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"64", " ", "coilsigma", " ", "l", " ", 
               SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "4"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"10", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"40", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"40", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "5"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
               
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"10", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "40", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"40", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"64", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"20", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"128", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"80", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"80", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"4", " ", 
                 SuperscriptBox["coilz1", "2"]}], "+", 
                RowBox[{"4", " ", "coilz1", " ", "l"}], "+", 
                SuperscriptBox["l", "2"], "-", 
                RowBox[{"8", " ", "coilz1", " ", "pos"}], "-", 
                RowBox[{"4", " ", "l", " ", "pos"}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["pos", "2"]}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["r1", "2"]}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["r2", "2"]}], "-", 
                RowBox[{"8", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"4", " ", 
                 SuperscriptBox["coilz2", "2"]}], "+", 
                RowBox[{"4", " ", "coilz2", " ", "l"}], "+", 
                SuperscriptBox["l", "2"], "-", 
                RowBox[{"8", " ", "coilz2", " ", "pos"}], "-", 
                RowBox[{"4", " ", "l", " ", "pos"}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["pos", "2"]}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["r1", "2"]}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["r2", "2"]}], "-", 
                RowBox[{"8", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], 
               "2"]}], ")"}]}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "16"}], " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"coilsigma", " ", 
              SuperscriptBox["l", "4"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
              " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["l", "3"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "4"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r2", "6"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"coilsigma", " ", 
              SuperscriptBox["l", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
              " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["l", "3"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"6", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"6", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r2", "6"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{
             "16", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"12", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{
             "48", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"coilsigma", " ", 
              SuperscriptBox["l", "4"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
              " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["l", "3"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "4"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r2", "6"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"coilsigma", " ", 
              SuperscriptBox["l", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
              " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["l", "3"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"6", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"6", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r2", "6"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{
             "16", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"12", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{
             "48", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "5"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{
             "8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{
             "8", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "5"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{
             "8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{
             "8", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
              "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "r1", " ", "r2", 
              " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "4"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
              "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "pos", " ", "r1", " ", "r2",
               " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", "r1", 
              " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
              " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", "r1", 
              " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["l", "3"], " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"96", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"96", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", "l", " ", 
              SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "4"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"10", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"40", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"40", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "5"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"10", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "40", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"40", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"20", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "128", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"80", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"80", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
              "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "r1", " ", "r2", 
              " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "4"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
              "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "pos", " ", "r1", " ", "r2",
               " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", "r1", 
              " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
              " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", "r1", 
              " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["l", "3"], " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"96", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"96", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", "l", " ", 
              SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "4"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"10", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"40", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"40", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "5"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"10", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "40", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"40", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"20", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "128", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"80", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"80", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["coilz1", "2"]}], "-", 
               RowBox[{"4", " ", "coilz1", " ", "l"}], "+", 
               SuperscriptBox["l", "2"], "-", 
               RowBox[{"8", " ", "coilz1", " ", "pos"}], "+", 
               RowBox[{"4", " ", "l", " ", "pos"}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["pos", "2"]}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["r1", "2"]}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["r2", "2"]}], "-", 
               RowBox[{"8", " ", "r1", " ", "r2", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["coilz2", "2"]}], "-", 
               RowBox[{"4", " ", "coilz2", " ", "l"}], "+", 
               SuperscriptBox["l", "2"], "-", 
               RowBox[{"8", " ", "coilz2", " ", "pos"}], "+", 
               RowBox[{"4", " ", "l", " ", "pos"}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["pos", "2"]}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["r1", "2"]}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["r2", "2"]}], "-", 
               RowBox[{"8", " ", "r1", " ", "r2", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "2"]}],
             ")"}]}]}], ")"}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", " ", "\[Pi]"}]], 
      RowBox[{"(", 
       RowBox[{"mu0", " ", "mz", " ", "r1", " ", "r2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "16"}], " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"coilsigma", " ", 
               SuperscriptBox["l", "4"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
               
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
               " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["l", "3"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "4"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r2", "6"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"coilsigma", " ", 
               SuperscriptBox["l", "4"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
               
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
               " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["l", "3"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "4"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r2", "6"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"coilsigma", " ", 
               SuperscriptBox["l", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
               
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
               " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["l", "3"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"6", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"6", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r2", "6"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"12", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{
              "48", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"coilsigma", " ", 
               SuperscriptBox["l", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
               
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
               " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["l", "3"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"6", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"6", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r2", "6"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"12", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{
              "48", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "5"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{
              "8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
               
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{
              "8", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "5"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{
              "8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
               
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{
              "8", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
               "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "4"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"64", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
               "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "pos", " ", "r1", " ", 
               "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", "r1",
                " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l",
                " ", "pos", " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", "r1",
                " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["l", "3"], " ", "pos", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"96", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"96", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"64", " ", "coilsigma", " ", "l", " ", 
               SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "4"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"10", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"40", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"40", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "5"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
               
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"10", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "40", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"40", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"64", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"20", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"128", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"80", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"80", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
               "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "4"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"64", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
               "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "pos", " ", "r1", " ", 
               "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", "r1",
                " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l",
                " ", "pos", " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", "r1",
                " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["l", "3"], " ", "pos", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"96", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"96", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"64", " ", "coilsigma", " ", "l", " ", 
               SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "4"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"10", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"40", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"40", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "5"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
               
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"10", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "40", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"40", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"64", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"20", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"128", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"80", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"80", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"4", " ", 
                 SuperscriptBox["coilz1", "2"]}], "+", 
                RowBox[{"4", " ", "coilz1", " ", "l"}], "+", 
                SuperscriptBox["l", "2"], "-", 
                RowBox[{"8", " ", "coilz1", " ", "pos"}], "-", 
                RowBox[{"4", " ", "l", " ", "pos"}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["pos", "2"]}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["r1", "2"]}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["r2", "2"]}], "-", 
                RowBox[{"8", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"4", " ", 
                 SuperscriptBox["coilz2", "2"]}], "+", 
                RowBox[{"4", " ", "coilz2", " ", "l"}], "+", 
                SuperscriptBox["l", "2"], "-", 
                RowBox[{"8", " ", "coilz2", " ", "pos"}], "-", 
                RowBox[{"4", " ", "l", " ", "pos"}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["pos", "2"]}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["r1", "2"]}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["r2", "2"]}], "-", 
                RowBox[{"8", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], 
               "2"]}], ")"}]}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "16"}], " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"coilsigma", " ", 
              SuperscriptBox["l", "4"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
              " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["l", "3"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "4"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r2", "6"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{
             "16", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"coilsigma", " ", 
              SuperscriptBox["l", "4"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
              " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["l", "3"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "4"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r2", "6"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{
             "16", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"coilsigma", " ", 
              SuperscriptBox["l", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
              " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["l", "3"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"6", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"6", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r2", "6"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"12", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{
             "48", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"coilsigma", " ", 
              SuperscriptBox["l", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
              " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["l", "3"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"6", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"6", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r2", "6"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"12", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{
             "48", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "5"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{
             "8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{
             "8", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "5"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{
             "8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{
             "8", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
              "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "r1", " ", "r2", 
              " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "4"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
              "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "pos", " ", "r1", " ", "r2",
               " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", "r1", 
              " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
              " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", "r1", 
              " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["l", "3"], " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"96", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"96", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", "l", " ", 
              SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "4"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"10", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"40", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"40", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "5"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"10", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "40", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"40", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"20", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "128", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"80", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"80", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
              "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "r1", " ", "r2", 
              " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "4"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
              "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "pos", " ", "r1", " ", "r2",
               " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", "r1", 
              " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
              " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", "r1", 
              " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["l", "3"], " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"96", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"96", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", "l", " ", 
              SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "4"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"10", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"40", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"40", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "5"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"10", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "40", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"40", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"20", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "128", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"80", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"80", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["coilz1", "2"]}], "-", 
               RowBox[{"4", " ", "coilz1", " ", "l"}], "+", 
               SuperscriptBox["l", "2"], "-", 
               RowBox[{"8", " ", "coilz1", " ", "pos"}], "+", 
               RowBox[{"4", " ", "l", " ", "pos"}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["pos", "2"]}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["r1", "2"]}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["r2", "2"]}], "-", 
               RowBox[{"8", " ", "r1", " ", "r2", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["coilz2", "2"]}], "-", 
               RowBox[{"4", " ", "coilz2", " ", "l"}], "+", 
               SuperscriptBox["l", "2"], "-", 
               RowBox[{"8", " ", "coilz2", " ", "pos"}], "+", 
               RowBox[{"4", " ", "l", " ", "pos"}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["pos", "2"]}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["r1", "2"]}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["r2", "2"]}], "-", 
               RowBox[{"8", " ", "r1", " ", "r2", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "2"]}],
             ")"}]}]}], ")"}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", " ", "\[Pi]"}]], 
      RowBox[{"(", 
       RowBox[{"mu0", " ", "mz", " ", "r1", " ", "r2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "coilsigma", " ", "coilz2", " ", "r1",
                " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"coilsigma", " ", "l", " ", "r1", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r1", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"2", " ", "coilsigma", " ", "coilz2", " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"coilsigma", " ", "l", " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"2", " ", "coilsigma", " ", "coilz1", " ", "r1", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"coilsigma", " ", "l", " ", "r1", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r1", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"2", " ", "coilsigma", " ", "coilz1", " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"coilsigma", " ", "l", " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}]}], ")"}], 
            "/", 
            RowBox[{"(", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], ")"}]}]}], 
          "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", "coilsigma", " ", "coilz2", " ", "r1", 
              " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"coilsigma", " ", "l", " ", "r1", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r1", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"2", " ", "coilsigma", " ", "coilz2", " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"coilsigma", " ", "l", " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"2", " ", "coilsigma", " ", "coilz1", " ", "r1", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"coilsigma", " ", "l", " ", "r1", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r1", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"2", " ", "coilsigma", " ", "coilz1", " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"coilsigma", " ", "l", " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}]}], ")"}], 
           "/", 
           RowBox[{"(", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["r1", "2"], "+", 
               SuperscriptBox["r2", "2"], "-", 
               RowBox[{"2", " ", "r1", " ", "r2", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], " ", 
             SqrtBox[
              RowBox[{
               SuperscriptBox["coilz1", "2"], "-", 
               RowBox[{"2", " ", "coilz1", " ", 
                RowBox[{"(", 
                 RowBox[{
                  FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
               SuperscriptBox["r1", "2"], "+", 
               SuperscriptBox["r2", "2"], "-", 
               RowBox[{"2", " ", "r1", " ", "r2", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
             SqrtBox[
              RowBox[{
               SuperscriptBox["coilz2", "2"], "-", 
               RowBox[{"2", " ", "coilz2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
               SuperscriptBox["r1", "2"], "+", 
               SuperscriptBox["r2", "2"], "-", 
               RowBox[{"2", " ", "r1", " ", "r2", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], ")"}]}]}], 
         ")"}]}], ")"}]}]}], "}"}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Actual calculation", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fdr1dr2dtheta1dtheta2", " ", "=", " ", 
   RowBox[{"If", "[", "\[InvisibleSpace]", 
    RowBox[{
     RowBox[{"!", "useprecomputed"}], ",", 
     RowBox[{"Integrate", "[", 
      RowBox[{"fdr1dr2dtheta1dtheta2dz2", ",", 
       RowBox[{"{", 
        RowBox[{"z2", ",", 
         RowBox[{"pos", "-", 
          RowBox[{"l", "/", "2"}]}], ",", 
         RowBox[{"pos", "+", 
          RowBox[{"l", "/", "2"}]}]}], "}"}]}], "]"}], ",", 
     "fdr1dr2dtheta1dtheta2pre"}], "]"}]}], ";"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Use symmetry to combine theta1 and theta2 integrals into an integral over \
deltatheta (and multiplication by 2 Pi) for longitudinal (z) component\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fdr1dr2ddeltatheta", "=", 
  RowBox[{
   RowBox[{"2", " ", "Pi", " ", 
    RowBox[{"fdr1dr2dtheta1dtheta2", "[", 
     RowBox[{"[", "3", "]"}], "]"}]}], "/.", 
   RowBox[{
    RowBox[{"theta1", "-", "theta2"}], "\[Rule]", "deltatheta"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", "mu0", " ", "mz", " ", "r1", " ", "r2", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "coilsigma", " ", "coilz2", " ", "r1", " ", 
         
         SqrtBox[
          RowBox[{
           SuperscriptBox["coilz1", "2"], "-", 
           RowBox[{"2", " ", "coilz1", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
           SuperscriptBox["r1", "2"], "+", 
           SuperscriptBox["r2", "2"], "-", 
           RowBox[{"2", " ", "r1", " ", "r2", " ", 
            RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "-", 
        RowBox[{"coilsigma", " ", "l", " ", "r1", " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["coilz1", "2"], "-", 
           RowBox[{"2", " ", "coilz1", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
           SuperscriptBox["r1", "2"], "+", 
           SuperscriptBox["r2", "2"], "-", 
           RowBox[{"2", " ", "r1", " ", "r2", " ", 
            RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "+", 
        RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r1", " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["coilz1", "2"], "-", 
           RowBox[{"2", " ", "coilz1", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
           SuperscriptBox["r1", "2"], "+", 
           SuperscriptBox["r2", "2"], "-", 
           RowBox[{"2", " ", "r1", " ", "r2", " ", 
            RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "+", 
        RowBox[{"2", " ", "coilsigma", " ", "coilz2", " ", "r2", " ", 
         RowBox[{"Cos", "[", "deltatheta", "]"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["coilz1", "2"], "-", 
           RowBox[{"2", " ", "coilz1", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
           SuperscriptBox["r1", "2"], "+", 
           SuperscriptBox["r2", "2"], "-", 
           RowBox[{"2", " ", "r1", " ", "r2", " ", 
            RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "+", 
        RowBox[{"coilsigma", " ", "l", " ", "r2", " ", 
         RowBox[{"Cos", "[", "deltatheta", "]"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["coilz1", "2"], "-", 
           RowBox[{"2", " ", "coilz1", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
           SuperscriptBox["r1", "2"], "+", 
           SuperscriptBox["r2", "2"], "-", 
           RowBox[{"2", " ", "r1", " ", "r2", " ", 
            RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "-", 
        RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r2", " ", 
         RowBox[{"Cos", "[", "deltatheta", "]"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["coilz1", "2"], "-", 
           RowBox[{"2", " ", "coilz1", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
           SuperscriptBox["r1", "2"], "+", 
           SuperscriptBox["r2", "2"], "-", 
           RowBox[{"2", " ", "r1", " ", "r2", " ", 
            RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "+", 
        RowBox[{"2", " ", "coilsigma", " ", "coilz1", " ", "r1", " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["coilz2", "2"], "-", 
           RowBox[{"2", " ", "coilz2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
           SuperscriptBox["r1", "2"], "+", 
           SuperscriptBox["r2", "2"], "-", 
           RowBox[{"2", " ", "r1", " ", "r2", " ", 
            RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "+", 
        RowBox[{"coilsigma", " ", "l", " ", "r1", " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["coilz2", "2"], "-", 
           RowBox[{"2", " ", "coilz2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
           SuperscriptBox["r1", "2"], "+", 
           SuperscriptBox["r2", "2"], "-", 
           RowBox[{"2", " ", "r1", " ", "r2", " ", 
            RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "-", 
        RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r1", " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["coilz2", "2"], "-", 
           RowBox[{"2", " ", "coilz2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
           SuperscriptBox["r1", "2"], "+", 
           SuperscriptBox["r2", "2"], "-", 
           RowBox[{"2", " ", "r1", " ", "r2", " ", 
            RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "-", 
        RowBox[{"2", " ", "coilsigma", " ", "coilz1", " ", "r2", " ", 
         RowBox[{"Cos", "[", "deltatheta", "]"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["coilz2", "2"], "-", 
           RowBox[{"2", " ", "coilz2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
           SuperscriptBox["r1", "2"], "+", 
           SuperscriptBox["r2", "2"], "-", 
           RowBox[{"2", " ", "r1", " ", "r2", " ", 
            RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "-", 
        RowBox[{"coilsigma", " ", "l", " ", "r2", " ", 
         RowBox[{"Cos", "[", "deltatheta", "]"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["coilz2", "2"], "-", 
           RowBox[{"2", " ", "coilz2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
           SuperscriptBox["r1", "2"], "+", 
           SuperscriptBox["r2", "2"], "-", 
           RowBox[{"2", " ", "r1", " ", "r2", " ", 
            RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "+", 
        RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r2", " ", 
         RowBox[{"Cos", "[", "deltatheta", "]"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["coilz2", "2"], "-", 
           RowBox[{"2", " ", "coilz2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
           SuperscriptBox["r1", "2"], "+", 
           SuperscriptBox["r2", "2"], "-", 
           RowBox[{"2", " ", "r1", " ", "r2", " ", 
            RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r1", "2"], "+", 
          SuperscriptBox["r2", "2"], "-", 
          RowBox[{"2", " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "deltatheta", "]"}]}]}], ")"}], " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["coilz1", "2"], "-", 
          RowBox[{"2", " ", "coilz1", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
          SuperscriptBox["r1", "2"], "+", 
          SuperscriptBox["r2", "2"], "-", 
          RowBox[{"2", " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]], " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["coilz2", "2"], "-", 
          RowBox[{"2", " ", "coilz2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
          SuperscriptBox["r1", "2"], "+", 
          SuperscriptBox["r2", "2"], "-", 
          RowBox[{"2", " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], ")"}]}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "coilsigma", " ", "coilz2", " ", "r1", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["coilz1", "2"], "-", 
          RowBox[{"2", " ", "coilz1", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
          SuperscriptBox["r1", "2"], "+", 
          SuperscriptBox["r2", "2"], "-", 
          RowBox[{"2", " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "+", 
       RowBox[{"coilsigma", " ", "l", " ", "r1", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["coilz1", "2"], "-", 
          RowBox[{"2", " ", "coilz1", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
          SuperscriptBox["r1", "2"], "+", 
          SuperscriptBox["r2", "2"], "-", 
          RowBox[{"2", " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "+", 
       RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r1", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["coilz1", "2"], "-", 
          RowBox[{"2", " ", "coilz1", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
          SuperscriptBox["r1", "2"], "+", 
          SuperscriptBox["r2", "2"], "-", 
          RowBox[{"2", " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "+", 
       RowBox[{"2", " ", "coilsigma", " ", "coilz2", " ", "r2", " ", 
        RowBox[{"Cos", "[", "deltatheta", "]"}], " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["coilz1", "2"], "-", 
          RowBox[{"2", " ", "coilz1", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
          SuperscriptBox["r1", "2"], "+", 
          SuperscriptBox["r2", "2"], "-", 
          RowBox[{"2", " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "-", 
       RowBox[{"coilsigma", " ", "l", " ", "r2", " ", 
        RowBox[{"Cos", "[", "deltatheta", "]"}], " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["coilz1", "2"], "-", 
          RowBox[{"2", " ", "coilz1", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
          SuperscriptBox["r1", "2"], "+", 
          SuperscriptBox["r2", "2"], "-", 
          RowBox[{"2", " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "-", 
       RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r2", " ", 
        RowBox[{"Cos", "[", "deltatheta", "]"}], " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["coilz1", "2"], "-", 
          RowBox[{"2", " ", "coilz1", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
          SuperscriptBox["r1", "2"], "+", 
          SuperscriptBox["r2", "2"], "-", 
          RowBox[{"2", " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "+", 
       RowBox[{"2", " ", "coilsigma", " ", "coilz1", " ", "r1", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["coilz2", "2"], "-", 
          RowBox[{"2", " ", "coilz2", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
          SuperscriptBox["r1", "2"], "+", 
          SuperscriptBox["r2", "2"], "-", 
          RowBox[{"2", " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "-", 
       RowBox[{"coilsigma", " ", "l", " ", "r1", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["coilz2", "2"], "-", 
          RowBox[{"2", " ", "coilz2", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
          SuperscriptBox["r1", "2"], "+", 
          SuperscriptBox["r2", "2"], "-", 
          RowBox[{"2", " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "-", 
       RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r1", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["coilz2", "2"], "-", 
          RowBox[{"2", " ", "coilz2", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
          SuperscriptBox["r1", "2"], "+", 
          SuperscriptBox["r2", "2"], "-", 
          RowBox[{"2", " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "-", 
       RowBox[{"2", " ", "coilsigma", " ", "coilz1", " ", "r2", " ", 
        RowBox[{"Cos", "[", "deltatheta", "]"}], " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["coilz2", "2"], "-", 
          RowBox[{"2", " ", "coilz2", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
          SuperscriptBox["r1", "2"], "+", 
          SuperscriptBox["r2", "2"], "-", 
          RowBox[{"2", " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "+", 
       RowBox[{"coilsigma", " ", "l", " ", "r2", " ", 
        RowBox[{"Cos", "[", "deltatheta", "]"}], " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["coilz2", "2"], "-", 
          RowBox[{"2", " ", "coilz2", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
          SuperscriptBox["r1", "2"], "+", 
          SuperscriptBox["r2", "2"], "-", 
          RowBox[{"2", " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "+", 
       RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r2", " ", 
        RowBox[{"Cos", "[", "deltatheta", "]"}], " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["coilz2", "2"], "-", 
          RowBox[{"2", " ", "coilz2", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
          SuperscriptBox["r1", "2"], "+", 
          SuperscriptBox["r2", "2"], "-", 
          RowBox[{"2", " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["r1", "2"], "+", 
         SuperscriptBox["r2", "2"], "-", 
         RowBox[{"2", " ", "r1", " ", "r2", " ", 
          RowBox[{"Cos", "[", "deltatheta", "]"}]}]}], ")"}], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["coilz1", "2"], "-", 
         RowBox[{"2", " ", "coilz1", " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
         SuperscriptBox["r1", "2"], "+", 
         SuperscriptBox["r2", "2"], "-", 
         RowBox[{"2", " ", "r1", " ", "r2", " ", 
          RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["coilz2", "2"], "-", 
         RowBox[{"2", " ", "coilz2", " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
         SuperscriptBox["r1", "2"], "+", 
         SuperscriptBox["r2", "2"], "-", 
         RowBox[{"2", " ", "r1", " ", "r2", " ", 
          RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{
  3.453749602489585*^9, 3.453749666250413*^9, 3.46384466353118*^9, {
   3.478894407013402*^9, 3.4788944222059526`*^9}, 3.478960342737445*^9, 
   3.479485743183877*^9, 3.4794860539930687`*^9, 3.4796583835628853`*^9, 
   3.4800825686169987`*^9, 3.4802436780596313`*^9, 3.480692248023052*^9, 
   3.4815660071019783`*^9, 3.481940916508472*^9, 3.481941022615478*^9, 
   3.481941924564169*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["A function to do the last three integrals numerically", "Text",
 CellChangeTimes->{{3.453752791124783*^9, 3.453752795898744*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"tag_", ",", "p_"}], "]"}], " ", ":=", 
   RowBox[{
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"fdr1dr2ddeltathetaN", "=", 
        RowBox[{"fdr1dr2ddeltatheta", "/.", 
         RowBox[{"vals", "[", "tag", "]"}]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"NIntegrate", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"fdr1dr2ddeltathetaN", "/.", 
         RowBox[{"pos", "\[Rule]", "p"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"r1", ",", 
          RowBox[{"coilrad1", "/.", 
           RowBox[{"vals", "[", "tag", "]"}]}], ",", 
          RowBox[{"coilrad2", "/.", 
           RowBox[{"vals", "[", "tag", "]"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"r2", ",", "0", ",", 
          RowBox[{"a", "/.", 
           RowBox[{"vals", "[", "tag", "]"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"deltatheta", ",", "0", ",", 
          RowBox[{"2", "Pi"}]}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
     "]"}], "/;", 
    RowBox[{"NumericQ", "[", "p", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.453750837572444*^9, 3.453750866946459*^9}, {
  3.453752644867671*^9, 3.45375269653437*^9}, {3.45382373167922*^9, 
  3.453823755073104*^9}, {3.453839497459736*^9, 3.4538395070562553`*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{3.4819409205240507`*^9},
 FormatType->"InputForm"],

Cell[CellGroupData[{

Cell["New coil calc for bigmagnetvals", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}}],

Cell[CellGroupData[{

Cell["\<\
bigmagnetvals = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->0.010,\t\t\t\t(* length of big magnets *)
\t\ta->0.005,\t\t\t\t(* radius of big magnets *)
\t\t(* coil length *)
\t\tcoillen->0.16*0.0254,
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.35*0.0254,
\t\tcoilrad2->0.55*0.0254,
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.453837228357688*^9, 3.453837230833909*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.005811946409141117`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.007999999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.01`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.005`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.004064`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.002032`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.002032`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.008889999999999999`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.01397`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.9375038750077497`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.463844663941598*^9, 3.479667628840351*^9, 
  3.480245057580022*^9, 3.48069224815385*^9, 3.4815660167539787`*^9, 
  3.481941596985648*^9, 3.481941924708386*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "BM", "]"}], " ", ":=", " ", "bigmagnetvals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"optdata", "[", "BM", "]"}], " ", "=", " ", 
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.084332204665714`"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", "\[Rule]", "0.006361536563952735`"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"Minimize", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"fz", "[", 
           RowBox[{"BM", ",", "z"}], "]"}]}], ",", " ", 
         RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
        "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.479667008672338*^9, 3.4796670332310963`*^9}, {
   3.479667207329587*^9, 3.479667207950783*^9}, {3.4802442654999228`*^9, 
   3.480244302808629*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"plot", "[", "BM", "]"}], " ", "=", " ", 
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
     GraphicsBox[{{}, {}, 
       {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nc8VW8cB3A/DaIQmSmlKFERFcKHiiT8yMgooSFCGZd7z71klboaGsqI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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      PlotRange->{{0, 0.013}, {0., 1.0843321794484708`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"fz", "[", 
        RowBox[{"BM", ",", "p"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.479666887455168*^9, 
   3.479666888838862*^9}, {3.479667208457279*^9, 3.479667208895832*^9}, {
   3.48024520498495*^9, 3.4802452202413063`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "BM", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "BM", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.479666890574193*^9, 
   3.479666892310862*^9}, {3.4796672094171343`*^9, 3.4796672098856077`*^9}}],

Cell[BoxData["0.006361536563952735`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.4796669544241667`*^9, 
  3.4796682577475853`*^9, 3.4802452914839983`*^9, 3.480692248270643*^9, 
  3.481566016936092*^9, 3.481941597128859*^9, 3.481941924843739*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "BM", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "BM", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.479666893782012*^9, 
   3.479666894910797*^9}, {3.479667219043417*^9, 3.4796672194929113`*^9}}],

Cell[BoxData["1.084332204665714`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.479666954466415*^9, 
  3.479668257772698*^9, 3.48024529160467*^9, 3.480692248321662*^9, 
  3.481566016972385*^9, 3.481941597184218*^9, 3.481941924879663*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{"-", 
   RowBox[{"ND", "[", 
    RowBox[{
     RowBox[{"fz", "[", 
      RowBox[{"BM", ",", "z"}], "]"}], ",", "z", ",", 
     RowBox[{"zmax", "[", "BM", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479666215169937*^9, 3.479666222032254*^9}, {
  3.479666896879272*^9, 3.479666899310975*^9}, {3.479667224959875*^9, 
  3.479667226153213*^9}}],

Cell[BoxData["105.12281621120579`"], "Output",
 CellChangeTimes->{3.479666223290411*^9, 3.479666954528255*^9, 
  3.479668258029018*^9, 3.480245291911537*^9, 3.4806922486198273`*^9, 
  3.4815660172394037`*^9, 3.481941597491042*^9, 3.481941925212204*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{"-", 
   RowBox[{"ND", "[", 
    RowBox[{
     RowBox[{"fz", "[", 
      RowBox[{"BM", ",", "z"}], "]"}], ",", "z", ",", 
     RowBox[{"zmax", "[", "BM", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.479666723517988*^9, 3.479666726638257*^9}, {
   3.4796672347709723`*^9, 3.479667236154491*^9}}],

Cell[BoxData["105.12281621120579`"], "Output",
 CellChangeTimes->{3.4796667275392237`*^9, 3.479666954597271*^9, 
  3.4796682582842197`*^9, 3.4802452922182693`*^9, 3.4806922489010277`*^9, 
  3.48156601747753*^9, 3.481941597800413*^9, 3.481941925642202*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fz", "[", 
  RowBox[{"BM", ",", 
   RowBox[{"-", "0.0064"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.45375087506522*^9, 3.453750875607725*^9}}],

Cell[BoxData[
 RowBox[{"-", "1.0842924602504616`"}]], "Output",
 CellChangeTimes->{3.453749602972189*^9, 3.453749666574046*^9, 
  3.453750876352957*^9, 3.453752731604185*^9, 3.453823764931923*^9, 
  3.453823801509736*^9, 3.4538385837598877`*^9, 3.453838637735564*^9, 
  3.46384467782513*^9, 3.4796682584643373`*^9, 3.4802452924391212`*^9, 
  3.480692249102811*^9, 3.481566017649225*^9, 3.4819415980291986`*^9, 
  3.4819419259636927`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"oldsweetspot", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "0.0254"}], "*", 
    RowBox[{"0.205", "/", "2"}]}], "-", 
   RowBox[{"0.0254", "*", "0.12"}], "-", "0.001115", "+", 
   RowBox[{"0.003175", "/", "2"}]}]}]], "Input",
 CellChangeTimes->{{3.4537508826011543`*^9, 3.453750883775889*^9}, {
  3.4537527418735323`*^9, 3.453752742503742*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.0051790000000000004`"}]], "Output",
 CellChangeTimes->{
  3.4537496030114202`*^9, 3.453749666610465*^9, {3.453750887396463*^9, 
   3.453750909722947*^9}, 3.4537527433073397`*^9, 3.453823764961364*^9, 
   3.463844678344269*^9, 3.479668258488261*^9, 3.480245292474451*^9, 
   3.480692249189704*^9, 3.481566017673868*^9, 3.48194159812962*^9, 
   3.481941926000042*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"fz", "[", 
   RowBox[{"BM", ",", "oldsweetspot"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4537509122631893`*^9, 3.45375094919713*^9}, {
  3.453823813188589*^9, 3.4538238137302923`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.2427809999999999`", ",", 
   RowBox[{"-", "1.0436583953898708`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.453750950353718*^9, 3.453823765066656*^9, 
  3.45382381697288*^9, 3.4638446806023808`*^9, 3.479668258688435*^9, 
  3.480245292720821*^9, 3.480692249415637*^9, 3.481566017911345*^9, 
  3.481941598383407*^9, 3.481941926247629*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Sweet spot of hybrid OSEM with dipole correction (two 10 mm long by 10 mm \
diameter magnets, 5 mm between faces) relative to centre of coil\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"If", "[", "\[IndentingNewLine]", 
  RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk4VG8UB3DZk6SxlSxRRJhCtHsLbUhaaEMimpEsKTH3zpA9ayGkItoo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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{-0.01, 0.5},
    PlotRange->{{-0.01, -0.003}, {0.4602013907859698, 0.9124418225431208}},
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]},
    ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzVWFlPVEsQbpjDjEsQl+u+jbvX5Bo1anzy0Zv7cJP77hMxJvpgNOr/0bjj
clHkQSNuKG4oMuwIyqCyDDOCAgMMW9lVp84yZ7oHPBITTzKc09XVX1VXfV3V
4d/C00cOHys8ffRQYfjvk4Unjhw9dCp84PhJKQrkCCEOyt/usDDkN8hP15+D
IB/7tRxfuTgRIEEAP4Efc5Rrq5g6YCGpZWl4+mWGW4afRlY01wS+PBYMc24Z
vQz3FuxZlVXLQtCzzTyvb44zQd0i+nLi5QqkUMhwlGNOLnI273jHT0gRk3zb
RkGWLYVUnpiR03riN3xTzmkj4g28GiOQZS5jdzPOBk9itQRQsfwXJSA4rVDN
PHWd4hFMh/ihauHlvnDXgwxxSGvEzn9GXeBaN1+xk30sGx+fsGX5LnWCsZTi
8UG4dPEtjebplB4/+gB1dd0ZSh7De1mWTI7CxQtvYXR0XBSY6vTaj9pp6x1e
8FsbgN9SZkAqNU6yZDKF7wJvhEOKMOZNUxb8ibUBDn9NTRc8KW+zfM/wbw9r
j41NSJpUQ1/fsFjgzmA67G6WNdTH4OGD9zRidc8xUbVmsphn27bAkMdFVyKQ
iCfFQsYwoLS0FOyV1rHIUmcstMaGGNy710IjX2gep3exbGJiEoqKTC8X+cEl
WAsNT9v9slYaZUcL2EHzOLbTlborlyMydUPij+yOKXiT6/aqqqoDyh9/oJEF
lZ7WoL3GWW05MjQ0ShwaHEyJxeYiFYd2sOzpkzaorPxEo8VKYxaJPdF0fLCg
vnxJEoOwIC3RhUAVQyMDqvR2I7xrjtNIC6U6mSrCb2dZS0uCgHG09IdBSfQX
j4eHxyjIiUSSe68CSlV1VD3RAi2XFaLylZkKLeiUJ9BCa2/vg+vXapGYZrvN
SCylwkhfLVV6e4ds4D9d+0V2x2IDYoWJ4W4t0bZeCkdra2Ibr7h79x1Uvemg
0Qql+WnUJgkvSyEU/18HFRVRLFFbeFFdbTflcnJyUqz0HSu+r0vCUvO9dbMe
vn4dFpvYSFdXP+0aj9IqP0Y0yW9uitNtQIZLbGBZf/8IXL5UDZ2d/WK1zpYT
GfoK2EGVqpi24uJ62ojsh2HGHRkZgxvXa9GmWDMDe7BUsV28fPERrhbVoM9r
XOZKShqwsoq1vvMSYoXOjm9k4FlFO+5ppcsIxu/Vy08izIunLpCzGBSzjYCY
WUnc5Qw6MJCCs2feILPEOhNLVTdnM0qse4D4cudOM4Z+CasiZbAGytYs1itd
mwbt55IwD8kNjY095CleHyRHuJka1AixbqMxGaYNulhrixBZymdLGJNIdScx
8NHD97g7vqUYEI3KQiIZhDcN2Vw26iw5lFTxxryQBqlP4r0FEZGukUgXnvHZ
7AimFu8OOHVT/uTWxGY/PCLr5qWoAMsWvHjeTvUQiVNW1gKvX3+m/o9tpqmp
hxypeBqFklsNcP5cFZ0jmU2x1Y91z+bNLj6HOIZ1Ge+DSEG0gVUfDxLuuqdn
EBO7zY9Jyuc/LNGdhv9Mcfp/ckTOdwjg3lI=\
\>"]], ",", "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"fz", "[", 
         RowBox[{"BM", ",", "p"}], "]"}], "-", 
        RowBox[{"fz", "[", 
         RowBox[{"BM", ",", 
          RowBox[{"p", "-", "0.015"}]}], "]"}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"p", ",", 
       RowBox[{"-", "0.010"}], ",", 
       RowBox[{"-", "0.003"}]}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.453823411637844*^9, 3.453823415837685*^9}, {
  3.480245301978496*^9, 3.4802453263238277`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk4VG8UB3DZk6SxlSxRRJhCtHsLbUhaaEMimpEsKTH3zpA9ayGkItoo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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{-0.01, 0.5},
  PlotRange->{{-0.01, -0.003}, {0.4602013907859698, 0.9124418225431208}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.453823529739856*^9, 3.463844847582552*^9, 
  3.480245328076311*^9, 3.480692249849388*^9, 3.481566018664538*^9, 
  3.481941598416605*^9, 3.481941926329867*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
If[
useprecomputed,
{-0.912442, {p \[Rule] -0.00680076}},
FindMinimum[fz[BM,p]-fz[BM,p-0.015],{p,-0.007,-0.006}]
]\
\>", "Input",
 CellChangeTimes->{{3.45382342881886*^9, 3.4538234334668007`*^9}, {
  3.4538235413508263`*^9, 3.453823587089514*^9}, {3.480245341853726*^9, 
  3.480245360684174*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.912442`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", 
     RowBox[{"-", "0.00680076`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.453823532157748*^9, 3.4538235906330833`*^9}, 
   3.463844850994608*^9, {3.480245357148303*^9, 3.480245361221218*^9}, 
   3.480692249882522*^9, 3.481566018727625*^9, 3.48194159846943*^9, 
   3.4819419263446903`*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["New coil calc for LIGO-I", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, {
  3.45382361286519*^9, 3.4538236144707003`*^9}}],

Cell[CellGroupData[{

Cell["\<\
OOvals = Recurse[
\tbasicvals~Join~LOSvals~Join~{
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* preferred value of magnet dipole moment per volume *)
\t\tmz->mzpref/(l*N[Pi]*a^2),
\t\t(* nominal distance between PAM and optic magnet centres *)
\t\tz0->0.013,
\t\t(* thread spacing (40 tpi, cf. 32 in original design) *)
\t\tthreadpitch->0.0254/40, \t\t
\t\t(* standard perturbation to (normalised) magnet strength *)
\t\tspert->0.1, 
\t\t(* standard perturbation to magnet position *)
\t\tzpert->threadpitch, 
\t\t(* elasticity of pendulum mode *)
\t\tkpend->massoptic g/dpend,
\t\t(* distance that the magnet sticks out of the OSEM *)
\t\tstandofftoosem->0.00114681,
\t\t(* coil length *)
\t\tcoillen->0.207*0.0254,
\t\t(* the ends of the coil relative to the end of the OSEM *)
\t\tcoilz1OSEM->0.12*0.0254,
\t\tcoilz2OSEM->coilz1OSEM+coillen,
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.302*0.0254,
\t\tcoilrad2->0.498*0.0254,
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.4538264235745993`*^9, 3.45382644840556*^9}, {
   3.453837031795086*^9, 3.453837041528119*^9}, {3.453837099708474*^9, 
   3.453837132901514*^9}, 3.453837267777411*^9, {3.453840139813717*^9, 
   3.453840149255684*^9}, {3.4538402007979527`*^9, 3.453840204355585*^9}, {
   3.4538636089891777`*^9, 3.453863609530529*^9}, {3.453863819107182*^9, 
   3.453863840974169*^9}, {3.45386389080914*^9, 3.4538638933349*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.00006696614374535085`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.014824999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"z0", "\[Rule]", "0.013`"}], ",", 
   RowBox[{"threadpitch", "\[Rule]", "0.000635`"}], ",", 
   RowBox[{"spert", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"zpert", "\[Rule]", "0.000635`"}], ",", 
   RowBox[{"kpend", "\[Rule]", "233.0222222222222`"}], ",", 
   RowBox[{"standofftoosem", "\[Rule]", "0.00114681`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.005257799999999999`"}], ",", 
   RowBox[{"coilz1OSEM", "\[Rule]", "0.003048`"}], ",", 
   RowBox[{"coilz2OSEM", "\[Rule]", "0.008305799999999999`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.0026288999999999996`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.0026288999999999996`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.007670799999999999`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.0126492`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.5281505471815046`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4538636242380333`*^9, 3.4538639022226553`*^9, 
  3.463844851197278*^9, 3.4806922499105587`*^9, 3.481941926405641*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "OO", "]"}], " ", ":=", " ", "OOvals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, {
  3.453823624487136*^9, 3.453823640631469*^9}, {3.453837378474317*^9, 
  3.453837393571328*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fz", "[", 
  RowBox[{"OO", ",", 
   RowBox[{"-", "0.0064"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.45375087506522*^9, 3.453750875607725*^9}, 
   3.453823640650034*^9, 3.453837393601057*^9}],

Cell[BoxData[
 RowBox[{"-", "0.015387096244059595`"}]], "Output",
 CellChangeTimes->{
  3.453749602972189*^9, 3.453749666574046*^9, 3.453750876352957*^9, 
   3.453752731604185*^9, 3.4538236694422503`*^9, 3.4538259483409157`*^9, 
   3.453826469350016*^9, {3.4538373992114477`*^9, 3.4538374256931763`*^9}, 
   3.453837477368595*^9, 3.453838646018355*^9, {3.4538401571878767`*^9, 
   3.453840174075727*^9}, 3.453840210377989*^9, 3.4538636411134653`*^9, 
   3.453863909646071*^9, 3.463844851305705*^9, 3.480692249973194*^9, 
   3.4819419265374804`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"oldsweetspot", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "0.0254"}], "*", 
    RowBox[{"0.205", "/", "2"}]}], "-", 
   RowBox[{"0.0254", "*", "0.12"}], "-", "0.001115", "+", 
   RowBox[{"0.003175", "/", "2"}]}]}]], "Input",
 CellChangeTimes->{{3.4537508826011543`*^9, 3.453750883775889*^9}, {
  3.4537527418735323`*^9, 3.453752742503742*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.0051790000000000004`"}]], "Output",
 CellChangeTimes->{
  3.4537496030114202`*^9, 3.453749666610465*^9, {3.453750887396463*^9, 
   3.453750909722947*^9}, 3.4537527433073397`*^9, 3.4538236694697313`*^9, 
   3.453825948369759*^9, 3.453837425726906*^9, 3.453840157247375*^9, 
   3.4538402104113083`*^9, 3.453863641155484*^9, 3.453863909695507*^9, 
   3.4638448513697023`*^9, 3.4806922500076113`*^9, 3.481941926588934*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"fz", "[", 
   RowBox[{"OO", ",", "oldsweetspot"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4537509122631893`*^9, 3.45375094919713*^9}, {
   3.453823640684885*^9, 3.453823640735626*^9}, {3.453826474859961*^9, 
   3.45382647576938*^9}, 3.4538373936510477`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.03569000000000022`", ",", 
   RowBox[{"-", "0.015851396334673768`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.453750950353718*^9, 3.453823671960964*^9, 
  3.453825948604528*^9, 3.453826476451028*^9, 3.453837425763947*^9, 
  3.453840157347342*^9, 3.453840210506116*^9, 3.453863641201985*^9, 
  3.4538639097501583`*^9, 3.463844851469378*^9, 3.480692250041*^9, 
  3.4819419266883163`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"fz", "[", 
   RowBox[{"OO", ",", 
    RowBox[{"-", "0.010"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.453751088575416*^9, 3.453751089087048*^9}, 
   3.453823640769184*^9, 3.453837393699996*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.019480000000000164`", ",", 
   RowBox[{"-", "0.010507386986391542`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.453749683527301*^9, 3.45375109040812*^9, 
  3.4538236722686167`*^9, 3.453825948821306*^9, 3.45382648659874*^9, 
  3.453837425793631*^9, 3.4538401576313677`*^9, 3.453840210546205*^9, 
  3.453863641238579*^9, 3.453863909799973*^9, 3.4638448515362864`*^9, 
  3.4806922500657587`*^9, 3.481941926915098*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"fz", "[", 
   RowBox[{"OO", ",", 
    RowBox[{"-", "0.003"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.453751094726705*^9, 3.453751095317946*^9}, 
   3.453823640822011*^9, 3.453837393750527*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.05516299999999985`", ",", 
   RowBox[{"-", "0.012824745749794315`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4537496838232193`*^9, 3.4537510967086277`*^9, 
  3.453823672557324*^9, 3.4538259490222588`*^9, 3.4538264890979757`*^9, 
  3.453837425851626*^9, 3.4538401579824533`*^9, 3.453840210608426*^9, 
  3.4538636412980003`*^9, 3.453863909861566*^9, 3.463844851657218*^9, 
  3.480692250121179*^9, 3.481941926976323*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sweet spot relative to centre of coil", "Text",
 CellChangeTimes->{{3.453823657396553*^9, 3.45382366152324*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"OO", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"-", "0.010"}], ",", "0.010"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453750960628242*^9, 3.453750962514122*^9}, 
   3.453823640869858*^9, 3.4538373938007517`*^9, {3.453838657031551*^9, 
   3.453838662984824*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt2Xk0VP//B3CEihJaLElRqSRlSRS9siYk2iRCCyWyzMydsVYyMzSYe0Up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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{-0.01, 0.01}, {-0.01586153120778571, 0.015861531161368958`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.45374974088566*^9, 3.453751021464161*^9, 3.453823734388617*^9, 
   3.45382595105693*^9, 3.453826495876092*^9, 3.453837430614188*^9, {
   3.453838660033111*^9, 3.45383867436195*^9}, 3.453840159929102*^9, 
   3.453840225991082*^9, 3.4538636558574543`*^9, 3.453863924479361*^9, 
   3.4638448686389313`*^9, 3.4806922643363953`*^9, 3.481941942064209*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"OO", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.0", ",", "0.01"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, 
   3.453823640937874*^9, {3.4538265543875103`*^9, 3.453826559178968*^9}, 
   3.453837393850636*^9, {3.453838705965811*^9, 3.453838717842711*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k8VF0YB3DLmxQl+5KQCm1ISkp+2mxtkvASKSIKs92ZIbsZ2ZqZlMpW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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0., 0.01}, {0., 0.0158615313648683}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.4538234640829372`*^9, 3.45382375947115*^9, 
  3.453825952943671*^9, 3.4538265081040163`*^9, 3.453826563804844*^9, 
  3.45383743232346*^9, 3.453838725272155*^9, 3.453840161864758*^9, 
  3.4538402352085543`*^9, 3.4538636649073067`*^9, 3.453863933391049*^9, 
  3.46384487886052*^9, 3.480692273326301*^9, 3.481941951327619*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SSdata", "[", "OO", "]"}], " ", "=", " ", 
  RowBox[{"FindMinimum", "[", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"fz", "[", 
      RowBox[{"OO", ",", "p"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"p", ",", "0.005"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.453823404829797*^9, 3.453823405956604*^9}, {
   3.453823506088236*^9, 3.453823516693254*^9}, 3.453823641011278*^9, {
   3.4538265379087467`*^9, 3.453826543745769*^9}, 3.453837393910678*^9, {
   3.4538387257460747`*^9, 3.453838749683352*^9}, {3.4538387973199577`*^9, 
   3.453838821469616*^9}, {3.453862450307226*^9, 3.45386248039209*^9}, {
   3.453862568949154*^9, 3.453862570115514*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.015861531596904708`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", "0.005325276190772767`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453823468555167*^9, 3.453823535452108*^9, 3.453825954168241*^9, {
   3.453826526324848*^9, 3.453826545225122*^9}, 3.4538374328189507`*^9, {
   3.4538387298936996`*^9, 3.4538387449128933`*^9}, {3.4538387984605837`*^9, 
   3.453838822542676*^9}, 3.453840162093855*^9, 3.4538402359560423`*^9, {
   3.4538624679971113`*^9, 3.4538624812382927`*^9}, 3.453862586264966*^9, 
   3.4538636654918613`*^9, 3.463844880212677*^9, 3.480692273883992*^9, 
   3.4819419518975058`*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SSpos", "[", "OO", "]"}], " ", "=", " ", 
  RowBox[{"p", "/.", 
   RowBox[{
    RowBox[{"SSdata", "[", "OO", "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.453862483701729*^9, 3.4538625105182133`*^9}, {
  3.453862576749049*^9, 3.453862581411574*^9}}],

Cell[BoxData["0.005325276190772767`"], "Output",
 CellChangeTimes->{{3.4538625068641663`*^9, 3.4538625109082727`*^9}, 
   3.4538625864136257`*^9, 3.453863665522478*^9, 3.4638448803345337`*^9, 
   3.480692273901267*^9, 3.48194195198164*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SSpeak", "[", "OO", "]"}], " ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"SSdata", "[", "OO", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.453862473476694*^9, 3.453862474190342*^9}, {
  3.453862598812314*^9, 3.453862615921789*^9}}],

Cell[BoxData["0.015861531596904708`"], "Output",
 CellChangeTimes->{3.453862616387323*^9, 3.4538636655554333`*^9, 
  3.463844880438141*^9, 3.480692273921216*^9, 3.4819419520177402`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["New coil calc for value-engineered LIGO-I", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, {
  3.45382361286519*^9, 3.4538236144707003`*^9}, {3.453838874626217*^9, 
  3.4538388807274017`*^9}}],

Cell[CellGroupData[{

Cell["\<\
VEvals = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->lold,\t\t\t\t(* length *)
\t\ta->aold,\t\t\t(* radius *)
\t\t(* coil length *)
\t\tcoillen->0.347*0.0254, (* increased from 0.16\" for LIGO-I *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\tcoilz1OSEM->0.05*0.0254,
\t\tcoilz2OSEM->coilz1OSEM+coillen,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.334*0.0254, (* 0.334=0.498-0.164, increased from 0.302 *)
\t\tcoilrad2->0.498*0.0254, (* same *)
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.453819143842659*^9, 3.45381916873015*^9}, {
   3.453819205916604*^9, 3.453819229397924*^9}, {3.4538192680904627`*^9, 
   3.453819317992671*^9}, {3.453819379538721*^9, 3.453819381962309*^9}, {
   3.453819414835219*^9, 3.453819449256628*^9}, {3.453823205503562*^9, 
   3.453823222597754*^9}, {3.453826073117807*^9, 3.453826150751071*^9}, 
   3.4538373389188223`*^9, {3.453862135114468*^9, 3.4538622312380953`*^9}, {
   3.4538622812810287`*^9, 3.453862282014607*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.00006696614374535086`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.014824999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.008813799999999998`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.004406899999999999`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.004406899999999999`"}], ",", 
   RowBox[{"coilz1OSEM", "\[Rule]", "0.00127`"}], ",", 
   RowBox[{"coilz2OSEM", "\[Rule]", "0.010083799999999999`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.0084836`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.0126492`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.0894799325270267`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453862217965355*^9, {3.453862264142426*^9, 3.453862285813403*^9}, 
   3.463844880536422*^9, 3.4802620957847557`*^9, 3.48069227394248*^9, 
   3.481941952073387*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "VE", "]"}], " ", ":=", " ", "VEvals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, {
  3.453823624487136*^9, 3.453823640631469*^9}, {3.453837378474317*^9, 
  3.453837393571328*^9}, {3.4538388861923847`*^9, 3.453838889904484*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"optdata", "[", "VE", "]"}], " ", "=", " ", 
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.013119230572857864`"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", "\[Rule]", "0.006315461295902202`"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"Minimize", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"fz", "[", 
           RowBox[{"VE", ",", "z"}], "]"}]}], ",", " ", 
         RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
        "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.479667008672338*^9, 3.4796670332310963`*^9}, {
   3.480244318582687*^9, 3.4802443450940313`*^9}, {3.48026206168556*^9, 
   3.480262062286573*^9}, 3.480262239842697*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"plot", "[", "VE", "]"}], " ", "=", " ", 
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
     GraphicsBox[{{}, {}, 
       {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nk4lOsbB3CHQrYsWVORVhGFUuGLpA3hIJVUKrQgzDDvLPZt3lQqKkRE
RUlKG46QQolkiZDlIJHUEYrE7/n9Ndfnet9rrpn7ee7vfau7+dgfFRQQEBD/
S0Dg/5/Fsl1nbDeNGG+b73zDNGiuyWFeVPH+gjoTubSr+ed7hkwyDvVZbijo
MgmtV4q365kyKW+IF19e8N3klH0LX7tHAg2xQ18XFAhg8eC7JPEeVew7pnRA
uUAaiqc0pwr/1cK13bmKigVqiK4dkI/vNkKZzcQP+QJdvLFTSxX+aIWne7tc
FnuZoUI4pvTB9H7MrRW58V/PdrSW2G+8peOOclbt0CIlO8ivKhk0UPPCg3oq
wvqKI2rOhhw3hB/SJCqlLlfvQfVIuF7OZSbKpJgK/c6uOC4cEzhPmQI1qrWD
43kIeedGT9q7c3He7pSgTNBhaP66Nr/DKRjlskcmskuPwlJqUHNAOxRj5VkD
de0eyMrZkd4UEgadbtGE3cPHUNKllGjyJBxhbsrB3VoncXyoyWrzcASaGthu
ExbeaHTMidz8MxJpDpbmYltOwaBfTmL5ZBT2jrXnbXXzxeCRq51/WqMxT0pV
1eqkH8JF1BfoXYgBTljq157yw3jUHw/5hBgcrzplZcv0g0VuQN3Y5RiUhr3k
OgT54eeA/WReSgy8fnp/dInzQ7D6rgfS2TGo6CpL9Xroh7PnVxUwS2LAyvdQ
Pzflh9uy+w6+H4xBm3P+svpYf7iKLhgf3cTHp911e0XO++OOZkungQkfI05f
zxol+MOwxHUF05QPUcflP2+m+GNATuX9sAUf+nbJlZxcf5hped6steYjdnu4
59I6f9SkiWmZHuDDZOPft1lyDLgOVx7+EsLH9g2nOu4qMqBXdHfXrzA+HAzP
yPbMZ+Bg55IUoUg+jq+rZFsvYcDhl/Z+eT4fl9du2rnYgIFPiVGMpef5+K6p
MVTtxIDQeIvirzQ+rs//ob0oiQFPJ4lfHiV8MDlnPHNTGSjzGKj0LONjW9vy
DOMMBmSXnnzkUc7HtyQXJZccBty/Cg8eqOTDSKVCMPEZA/csFz3b8JaPZqXE
ZtkeBiInddZf7OBDQgGhwlpMXHj/742O33x0Mj8UJegyYfbQODjjDx8PmvzH
lxgw8fviJ477DB97ErJObDZhYurMQOcnQRo358k6hdgysabOwPndHBqmcn2a
kwwmEr68W2etSIMpfbrxazETdf/YPuzVpaF2K7nW4zkT22ZmDDzW0nhjnFPV
XcGEj/edkX49GotP1PzT9JaJien6Bb3raNS9nHujuJuJgBGOWaURjVWceOaZ
2QHQyfT/ZriNRndfioK2NbFdZED1fhqx3FzpW3YBEA97WyF/gIahXImYulMA
4nBsj+tBGmdNu6bnHQhA1OpIy0E3GkbJi/unTgVgi5Lp1q8eNC7b3nryJj4A
Kp+iVdJ8aVgX5TmfbA8AN02nvjCcRsuPfO/ErgAIu64MK4qgcUTrSURFbwDK
1Y4+KoykwU4pzlP7GgBJ95CbD6NpZAW/Fm36E4AjrLiCS6dpCFr0PjVeFAiX
VJUmuYs0nr5RVJ7rFogpMz3OjzQaFrPn6xi5B4J9LkvoZTqNt8YLtxw7HogR
kQKFhOs0PuUu8S33C4T4VNpH3UwacufXvAoMJ8/TrMacbtHwdtxJdWUGonlB
ZNj+uzSWdAR9uN8fiB/fJOocn9JgBc6MGQ4Fwlnmd5NwAY1q6RDZ0u+BiNd2
Wf2Y2G9z6M7aiUCIrq9qnltEozQrvHhQnIXZCTEK94pp7PePSdfQZWFVscPZ
lOc08iTmPLutz4Lrtr979MppzLrJb12zgQXJWwvjqohzWmg5U3MW7H+zRoZe
0Jg0PhPp4sDCqEF9j3oljUuiF44lsFjwFdpaYVRNYzBdNkqVx4Kss2vZU2Lj
TRevZ4SyYOPyRlnvDY1er/i2+zQL67fL9y6uobG24ZJ17VUW3E+bfx6upRF1
UvG4YzoLE9/Hmve/pfFh9pWo9hssdNi9X15NHGKYWDKYy4J3VOxAWh2pb0ry
GpEyFmJnd0wb1pP7t17V5uxLFpwcRSaTiAPqrh6Xf81C5HI4/yZeKJSaodHA
QuN+GzxpoHHSM03etI+Fyn615/ObaIjq3ZhgzaEg87F+6HIzuV/eSmvzJSn0
/umPaCP2yT59/KsMBR0/tcIFLTTeL/JrO6RCYenLtX9SiDMlULxjFQUzSc/h
Mx/Ifdv6YCxChzzvUWdVEIuHL11dokeBudA3/Q+x34T4NT0jCgEKWR88WmmY
fWoJUbWm8POwZ+WqNhoMdasCJzsK4U9POe0hznIp+S/OkcLdptjoSGLphhtu
s10prC5c8e4DsYWUcjLcKJwetRr8q51G4PbYBsqdwvNlpTdXEHeU+FkMe1Ng
8BrF/Ihlf/dxV/hT8PFVyI8n3rJuzyO3QAoWU59nHhHn5GBZczAFp8KwmFHi
rv4HrjIRFIayvryQ+Ujur8ayyztjKBRmrrilTcxOlBAtjaPAjzrgeog4tzHY
dDKewj+iAvoUcffcHyz9RFLPzoK8c8Tzdrrf906h0LOwpTGTeFvUh4GsdArm
lz5feUrMLbNa3HODnId8m0Q18b2pkr0LbpN6TWmvbCf+d73exd25FPSd9Ya/
ECv436w+/4CCoa2xyyTxjlzlWW8eU3i2ItVfpIMGbyDWSLiIwhuzLH054rwl
AkzTEgp+irnXFhD3HvC/yy6nkGQm+GgZsVLyp76HlRSEGD8Zq4mt3u9Z+K2a
wgteV6c+cYhMjdPKOgot26XHNxDnW5meO9xIwbvjwxNj4k/R+ZUpLRTU9sct
NSVWKV8m0NJOoVswGmbENtOJhrLdFNKXywj/32EbJH2t+ijEmIRRIH7MCMmO
GqBwvUk7yYh44N6P7tKvFN4neHgaEqt+cVf5/R+FJvPw3rXEtsta7Q3GKYgU
NUppEUccsj7tM0lh9897/RrET66WlmdPU9AUP+ajQjzYrDfVI8iG1xKHm3OJ
F8rd0l8owobS6ZexQsT2NipezuJshKfLaIyTekbyz9y4MJeNOb2xx/qJh2b8
FUSU2Kg/eFi0gviX734pLVU2ao4dfZ5PLNRrKWynxoaD9ODGNGKVKuXxpBVs
/Lxa5MkkXrZRaLhEi42Q/7IWuhKvzRnq69VlY2XpnvgtxNvjSppWb2AjK3tr
qTSxg2B2zd/GbDIflwb+/z4eZFx4yTJjo2hqzrf3xCzno4+eb2dDtWaZxhXi
m2riCU572ZAQSLohTvzgwmgsx5WNL1SgVx/pl+JZHRFpbmzM2A//KiZu/JzH
GDzOxp3E4oMniIXuOzkEcdgQ0lQ68IT0p5SGqVVGMBvNqw9bRROrJKy0qAon
33ekesaReC01pScby4Y5jAq/kf4+aHZd7uZVUh/b61HziE/mnxavTiPvD7Xc
bSV5EbiUKfQ9k43sy6Up14jPztn2Y8NdNpwvD7csJS5+97W+ppiNiPWtLzVI
/lRtbn49UsYGP/fupq735Pc+Kn2uWMFGccP3oGTiocSLDw7VsiFtvvuIFLGK
24YLYx3kff7Ui75GUu/GxbRKDxu/zlumXiFeYykRhn42Mt6ztuwg3qbZ6cv/
xkbbpU/T2SQfA0ci7BYIcCASIbl8H8nPxrA66S3qHDQ+Hr0UQfI4y3H93BdL
OUh19TRVJeauSJXcrMmBd2tX9AOS5xq1J8TIaITS6MWRVpL3fsois4y3cKCW
+p/5fDIPZPKMf+of4+DfmSidvVWk/8Iyx/K9OHCwjR5qI/PlqaP46Fo/DkwN
3W1ciA/+bvmuy+HgVRFLcE8F6V9LxqDWGQ4UXQUNzcl8svl4++OS+xzUp3/Y
0FhC5kGeTHvGIw4UWu+yTInHw1itiws5CFq98fCdZzRSV1g2q5Vz8KPqjjGP
zMev/t11qk0c9O6n5GTI/IwVU3oxb4IDQbWhzIlHNF6tj7w9y4wLjzvJjHe3
yf/N6XixbgsXfgFjT9WIddUNOz23czFksbXbO5vGFbEvcjV2XFRsDe0UyaLh
+dGWl+DGxaeCjGStGzSEw1Vtl0VwUdgxy93sGsnv2vyxrZVc2PK0apIukH4y
l5RmV3Nx0l3bsvI8yeMn7po5b7l4L9qeOxJH8jdd+YB0CxcZlYW2ludIHvoH
V7V85qKpTKWzi+wroco7k4+J8fBKfiqsh+w7z478a3ramocupSIf9QAaGzcW
HFK054E9u11IiUnyZm5cWIYTDyNNIu6SDJLfhcYvig7wMOF75NIo2adSpRO3
DvnyoFvp+/ChF42gf3bZWF/ioX7T711TR2iYzCveN7eTB7/PAbtz7GmUlF8O
uHgqCI/5mna3NUne1/U6iTGDcF1ynqPrSlKP9jXrQ6kgsM09dsmsIPNsrPqn
d1gQHvVvW8lYSs57mQC1Iz4IZxmZQdpqNAT4npy/ngbBq0NZ3keehrnNhhCf
mSC8u/Zt/hqy375saeXvPBsMjQvjva/Ivty3tsfqqFUIOjWkXa578eEtG5nZ
1x6C7oTvR23GY/BTm8N+dTgU1qXaBa7cGIQtMcTsz6G4PLtWcd9UNOT00xtC
A8OwYt3Dff7HopEZ7Prp0J8wWJa/njBojYJRb2VV2NlwuFjOeZq4IQqNEZEr
RRQisNg6TrX+WiS8BcSonqQItKbMxEUKR0IqYeMVgVWR0LaQOc1wjUDu0RKD
0PuR0BUrmawrDYfDru/XzTdH4UrgypVzFMIxJfd5el99FELMtSbW+4Qhc57+
h5bd0ei90BY63RiKv1drhV/6HA1W1S6BLp1QCEaw7jzxiYHFuG6T5pUQ5D88
/Vx3NAaLfYPy5wuH4Pj0juzBcD526RiI/mgKgnqEq5SoGNkj5zydMCziwfRx
W7+rBI0VhzYv3PuYh4OfncseSZE9UkW9lnOfh1SrvxmH5WhY1tnXld7iQVV+
W+szVXLOvn+52cXzoHBzzU2mDo3nQ3eaYr14EKuaZdLjQPZsSeM6LzUeVk6G
Km7cTSN546KktPk8bNOa+R63h9y7x+I/GhR4iI6byDBxJX3c7mtvJMnDrD3D
c5LIXo9gn9dyk1xMDzQ32bJp7G67/fhjAxcLVB3v3eKSe+DUylMmfWFkUx8z
HUT2mMBnTY6vueA8eLMph+z93Z1ihnWlXPxil6WLnCE5/pb1qvouF4p3TTiu
pG/622WVJbK5WNdZ5PCI9Nnel5qTVplcMDc/Fjl8iUbNiXW+dUlcxDP1uguu
0Bib3isid4mLh7fyCqWTyRxVOKDjdJ6Lhg/a8R4pNArq9g4kxnIxIn7H6xnp
6x2a7gYd0Vz8DxJH8gE=
         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      PlotRange->{{0, 0.013}, {0., 0.013119230033113495`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"fz", "[", 
        RowBox[{"VE", ",", "p"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.479666887455168*^9, 
   3.479666888838862*^9}, {3.480244879780376*^9, 3.480244897499516*^9}, 
   3.4802450058581*^9, {3.48026206307683*^9, 3.4802620637527103`*^9}, 
   3.480262264694813*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "VE", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "VE", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.479666890574193*^9, 
   3.479666892310862*^9}, {3.48026206489049*^9, 3.480262065861014*^9}}],

Cell[BoxData["0.006315461295902202`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.4796669544241667`*^9, 
  3.479667628122774*^9, 3.480244912925961*^9, 3.480262195337325*^9, 
  3.48069227397675*^9, 3.4819419522162*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "VE", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "VE", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.479666893782012*^9, 
   3.479666894910797*^9}, {3.4802620669164543`*^9, 3.480262067600336*^9}}],

Cell[BoxData["0.013119230572857864`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.479666954466415*^9, 
  3.4796676281467333`*^9, 3.480244912993281*^9, 3.480262195361561*^9, 
  3.480692273996217*^9, 3.481941952298916*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "VE", "]"}], " ", "=", " ", 
  RowBox[{"-", 
   RowBox[{"ND", "[", 
    RowBox[{
     RowBox[{"fz", "[", 
      RowBox[{"VE", ",", "z"}], "]"}], ",", "z", ",", 
     RowBox[{"zmax", "[", "VE", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479666215169937*^9, 3.479666222032254*^9}, {
  3.479666896879272*^9, 3.479666899310975*^9}, {3.480262068140703*^9, 
  3.480262069257842*^9}}],

Cell[BoxData["1.2960650474315338`"], "Output",
 CellChangeTimes->{3.479666223290411*^9, 3.479666954528255*^9, 
  3.479667628426712*^9, 3.480244913348442*^9, 3.480262195441539*^9, 
  3.4806922740778437`*^9, 3.481941952399557*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"plot", "[", "VE", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<z (m)\>\"", ",", "\"\<F (N/A)\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, {
   3.453838538440839*^9, 3.453838572806719*^9}, 3.463844247723119*^9, 
   3.478894943196905*^9, 3.4788950132010527`*^9, {3.478961709433363*^9, 
   3.47896175216029*^9}, {3.478961842569364*^9, 3.478961894377494*^9}, {
   3.4789619830038633`*^9, 3.478961984506156*^9}, {3.4789699280628653`*^9, 
   3.478969982243393*^9}, {3.478970021389124*^9, 3.478970165180615*^9}, {
   3.478970224319232*^9, 3.478970261501657*^9}, {3.4789703108875017`*^9, 
   3.478970348344078*^9}, 3.478970398020482*^9, {3.478970871122594*^9, 
   3.47897087265033*^9}, {3.478971414854863*^9, 3.4789714317583723`*^9}, {
   3.4789723334965277`*^9, 3.4789723911200447`*^9}, {3.4794964690726423`*^9, 
   3.4794964944567127`*^9}, {3.479496975356181*^9, 3.479496976183571*^9}, {
   3.47949787094656*^9, 3.479497874578391*^9}, {3.4794981429899273`*^9, 
   3.479498147044504*^9}, {3.479498193967552*^9, 3.479498236581649*^9}, {
   3.479662116006764*^9, 3.479662117075882*^9}, {3.479666955542605*^9, 
   3.479666963425733*^9}, 3.480262070375884*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nk4lOsbB3CHQrYsWVORVhGFUuGLpA3hIJVUKrQgzDDvLPZt3lQqKkRE
RUlKG46QQolkiZDlIJHUEYrE7/n9Ndfnet9rrpn7ee7vfau7+dgfFRQQEBD/
S0Dg/5/Fsl1nbDeNGG+b73zDNGiuyWFeVPH+gjoTubSr+ed7hkwyDvVZbijo
MgmtV4q365kyKW+IF19e8N3klH0LX7tHAg2xQ18XFAhg8eC7JPEeVew7pnRA
uUAaiqc0pwr/1cK13bmKigVqiK4dkI/vNkKZzcQP+QJdvLFTSxX+aIWne7tc
FnuZoUI4pvTB9H7MrRW58V/PdrSW2G+8peOOclbt0CIlO8ivKhk0UPPCg3oq
wvqKI2rOhhw3hB/SJCqlLlfvQfVIuF7OZSbKpJgK/c6uOC4cEzhPmQI1qrWD
43kIeedGT9q7c3He7pSgTNBhaP66Nr/DKRjlskcmskuPwlJqUHNAOxRj5VkD
de0eyMrZkd4UEgadbtGE3cPHUNKllGjyJBxhbsrB3VoncXyoyWrzcASaGthu
ExbeaHTMidz8MxJpDpbmYltOwaBfTmL5ZBT2jrXnbXXzxeCRq51/WqMxT0pV
1eqkH8JF1BfoXYgBTljq157yw3jUHw/5hBgcrzplZcv0g0VuQN3Y5RiUhr3k
OgT54eeA/WReSgy8fnp/dInzQ7D6rgfS2TGo6CpL9Xroh7PnVxUwS2LAyvdQ
Pzflh9uy+w6+H4xBm3P+svpYf7iKLhgf3cTHp911e0XO++OOZkungQkfI05f
zxol+MOwxHUF05QPUcflP2+m+GNATuX9sAUf+nbJlZxcf5hped6steYjdnu4
59I6f9SkiWmZHuDDZOPft1lyDLgOVx7+EsLH9g2nOu4qMqBXdHfXrzA+HAzP
yPbMZ+Bg55IUoUg+jq+rZFsvYcDhl/Z+eT4fl9du2rnYgIFPiVGMpef5+K6p
MVTtxIDQeIvirzQ+rs//ob0oiQFPJ4lfHiV8MDlnPHNTGSjzGKj0LONjW9vy
DOMMBmSXnnzkUc7HtyQXJZccBty/Cg8eqOTDSKVCMPEZA/csFz3b8JaPZqXE
ZtkeBiInddZf7OBDQgGhwlpMXHj/742O33x0Mj8UJegyYfbQODjjDx8PmvzH
lxgw8fviJ477DB97ErJObDZhYurMQOcnQRo358k6hdgysabOwPndHBqmcn2a
kwwmEr68W2etSIMpfbrxazETdf/YPuzVpaF2K7nW4zkT22ZmDDzW0nhjnFPV
XcGEj/edkX49GotP1PzT9JaJien6Bb3raNS9nHujuJuJgBGOWaURjVWceOaZ
2QHQyfT/ZriNRndfioK2NbFdZED1fhqx3FzpW3YBEA97WyF/gIahXImYulMA
4nBsj+tBGmdNu6bnHQhA1OpIy0E3GkbJi/unTgVgi5Lp1q8eNC7b3nryJj4A
Kp+iVdJ8aVgX5TmfbA8AN02nvjCcRsuPfO/ErgAIu64MK4qgcUTrSURFbwDK
1Y4+KoykwU4pzlP7GgBJ95CbD6NpZAW/Fm36E4AjrLiCS6dpCFr0PjVeFAiX
VJUmuYs0nr5RVJ7rFogpMz3OjzQaFrPn6xi5B4J9LkvoZTqNt8YLtxw7HogR
kQKFhOs0PuUu8S33C4T4VNpH3UwacufXvAoMJ8/TrMacbtHwdtxJdWUGonlB
ZNj+uzSWdAR9uN8fiB/fJOocn9JgBc6MGQ4Fwlnmd5NwAY1q6RDZ0u+BiNd2
Wf2Y2G9z6M7aiUCIrq9qnltEozQrvHhQnIXZCTEK94pp7PePSdfQZWFVscPZ
lOc08iTmPLutz4Lrtr979MppzLrJb12zgQXJWwvjqohzWmg5U3MW7H+zRoZe
0Jg0PhPp4sDCqEF9j3oljUuiF44lsFjwFdpaYVRNYzBdNkqVx4Kss2vZU2Lj
TRevZ4SyYOPyRlnvDY1er/i2+zQL67fL9y6uobG24ZJ17VUW3E+bfx6upRF1
UvG4YzoLE9/Hmve/pfFh9pWo9hssdNi9X15NHGKYWDKYy4J3VOxAWh2pb0ry
GpEyFmJnd0wb1pP7t17V5uxLFpwcRSaTiAPqrh6Xf81C5HI4/yZeKJSaodHA
QuN+GzxpoHHSM03etI+Fyn615/ObaIjq3ZhgzaEg87F+6HIzuV/eSmvzJSn0
/umPaCP2yT59/KsMBR0/tcIFLTTeL/JrO6RCYenLtX9SiDMlULxjFQUzSc/h
Mx/Ifdv6YCxChzzvUWdVEIuHL11dokeBudA3/Q+x34T4NT0jCgEKWR88WmmY
fWoJUbWm8POwZ+WqNhoMdasCJzsK4U9POe0hznIp+S/OkcLdptjoSGLphhtu
s10prC5c8e4DsYWUcjLcKJwetRr8q51G4PbYBsqdwvNlpTdXEHeU+FkMe1Ng
8BrF/Ihlf/dxV/hT8PFVyI8n3rJuzyO3QAoWU59nHhHn5GBZczAFp8KwmFHi
rv4HrjIRFIayvryQ+Ujur8ayyztjKBRmrrilTcxOlBAtjaPAjzrgeog4tzHY
dDKewj+iAvoUcffcHyz9RFLPzoK8c8Tzdrrf906h0LOwpTGTeFvUh4GsdArm
lz5feUrMLbNa3HODnId8m0Q18b2pkr0LbpN6TWmvbCf+d73exd25FPSd9Ya/
ECv436w+/4CCoa2xyyTxjlzlWW8eU3i2ItVfpIMGbyDWSLiIwhuzLH054rwl
AkzTEgp+irnXFhD3HvC/yy6nkGQm+GgZsVLyp76HlRSEGD8Zq4mt3u9Z+K2a
wgteV6c+cYhMjdPKOgot26XHNxDnW5meO9xIwbvjwxNj4k/R+ZUpLRTU9sct
NSVWKV8m0NJOoVswGmbENtOJhrLdFNKXywj/32EbJH2t+ijEmIRRIH7MCMmO
GqBwvUk7yYh44N6P7tKvFN4neHgaEqt+cVf5/R+FJvPw3rXEtsta7Q3GKYgU
NUppEUccsj7tM0lh9897/RrET66WlmdPU9AUP+ajQjzYrDfVI8iG1xKHm3OJ
F8rd0l8owobS6ZexQsT2NipezuJshKfLaIyTekbyz9y4MJeNOb2xx/qJh2b8
FUSU2Kg/eFi0gviX734pLVU2ao4dfZ5PLNRrKWynxoaD9ODGNGKVKuXxpBVs
/Lxa5MkkXrZRaLhEi42Q/7IWuhKvzRnq69VlY2XpnvgtxNvjSppWb2AjK3tr
qTSxg2B2zd/GbDIflwb+/z4eZFx4yTJjo2hqzrf3xCzno4+eb2dDtWaZxhXi
m2riCU572ZAQSLohTvzgwmgsx5WNL1SgVx/pl+JZHRFpbmzM2A//KiZu/JzH
GDzOxp3E4oMniIXuOzkEcdgQ0lQ68IT0p5SGqVVGMBvNqw9bRROrJKy0qAon
33ekesaReC01pScby4Y5jAq/kf4+aHZd7uZVUh/b61HziE/mnxavTiPvD7Xc
bSV5EbiUKfQ9k43sy6Up14jPztn2Y8NdNpwvD7csJS5+97W+ppiNiPWtLzVI
/lRtbn49UsYGP/fupq735Pc+Kn2uWMFGccP3oGTiocSLDw7VsiFtvvuIFLGK
24YLYx3kff7Ui75GUu/GxbRKDxu/zlumXiFeYykRhn42Mt6ztuwg3qbZ6cv/
xkbbpU/T2SQfA0ci7BYIcCASIbl8H8nPxrA66S3qHDQ+Hr0UQfI4y3H93BdL
OUh19TRVJeauSJXcrMmBd2tX9AOS5xq1J8TIaITS6MWRVpL3fsois4y3cKCW
+p/5fDIPZPKMf+of4+DfmSidvVWk/8Iyx/K9OHCwjR5qI/PlqaP46Fo/DkwN
3W1ciA/+bvmuy+HgVRFLcE8F6V9LxqDWGQ4UXQUNzcl8svl4++OS+xzUp3/Y
0FhC5kGeTHvGIw4UWu+yTInHw1itiws5CFq98fCdZzRSV1g2q5Vz8KPqjjGP
zMev/t11qk0c9O6n5GTI/IwVU3oxb4IDQbWhzIlHNF6tj7w9y4wLjzvJjHe3
yf/N6XixbgsXfgFjT9WIddUNOz23czFksbXbO5vGFbEvcjV2XFRsDe0UyaLh
+dGWl+DGxaeCjGStGzSEw1Vtl0VwUdgxy93sGsnv2vyxrZVc2PK0apIukH4y
l5RmV3Nx0l3bsvI8yeMn7po5b7l4L9qeOxJH8jdd+YB0CxcZlYW2ludIHvoH
V7V85qKpTKWzi+wroco7k4+J8fBKfiqsh+w7z478a3ramocupSIf9QAaGzcW
HFK054E9u11IiUnyZm5cWIYTDyNNIu6SDJLfhcYvig7wMOF75NIo2adSpRO3
DvnyoFvp+/ChF42gf3bZWF/ioX7T711TR2iYzCveN7eTB7/PAbtz7GmUlF8O
uHgqCI/5mna3NUne1/U6iTGDcF1ynqPrSlKP9jXrQ6kgsM09dsmsIPNsrPqn
d1gQHvVvW8lYSs57mQC1Iz4IZxmZQdpqNAT4npy/ngbBq0NZ3keehrnNhhCf
mSC8u/Zt/hqy375saeXvPBsMjQvjva/Ivty3tsfqqFUIOjWkXa578eEtG5nZ
1x6C7oTvR23GY/BTm8N+dTgU1qXaBa7cGIQtMcTsz6G4PLtWcd9UNOT00xtC
A8OwYt3Dff7HopEZ7Prp0J8wWJa/njBojYJRb2VV2NlwuFjOeZq4IQqNEZEr
RRQisNg6TrX+WiS8BcSonqQItKbMxEUKR0IqYeMVgVWR0LaQOc1wjUDu0RKD
0PuR0BUrmawrDYfDru/XzTdH4UrgypVzFMIxJfd5el99FELMtSbW+4Qhc57+
h5bd0ei90BY63RiKv1drhV/6HA1W1S6BLp1QCEaw7jzxiYHFuG6T5pUQ5D88
/Vx3NAaLfYPy5wuH4Pj0juzBcD526RiI/mgKgnqEq5SoGNkj5zydMCziwfRx
W7+rBI0VhzYv3PuYh4OfncseSZE9UkW9lnOfh1SrvxmH5WhY1tnXld7iQVV+
W+szVXLOvn+52cXzoHBzzU2mDo3nQ3eaYr14EKuaZdLjQPZsSeM6LzUeVk6G
Km7cTSN546KktPk8bNOa+R63h9y7x+I/GhR4iI6byDBxJX3c7mtvJMnDrD3D
c5LIXo9gn9dyk1xMDzQ32bJp7G67/fhjAxcLVB3v3eKSe+DUylMmfWFkUx8z
HUT2mMBnTY6vueA8eLMph+z93Z1ihnWlXPxil6WLnCE5/pb1qvouF4p3TTiu
pG/622WVJbK5WNdZ5PCI9Nnel5qTVplcMDc/Fjl8iUbNiXW+dUlcxDP1uguu
0Bib3isid4mLh7fyCqWTyRxVOKDjdJ6Lhg/a8R4pNArq9g4kxnIxIn7H6xnp
6x2a7gYd0Vz8DxJH8gE=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"z (m)\"", TraditionalForm], 
    FormBox["\"F (N/A)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  PlotRange->{{0, 0.013}, {0., 0.013119230033113495`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.480262195466113*^9, 3.480692274101901*^9, 
  3.481941952516597*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fz", "[", 
  RowBox[{"VE", ",", "0.0064"}], "]"}]], "Input",
 CellChangeTimes->{{3.45375087506522*^9, 3.453750875607725*^9}, 
   3.453823640650034*^9, 3.453837393601057*^9, 3.45383890126833*^9, 
   3.4538394359743757`*^9}],

Cell[BoxData["0.013117074132794828`"], "Output",
 CellChangeTimes->{
  3.453749602972189*^9, 3.453749666574046*^9, 3.453750876352957*^9, 
   3.453752731604185*^9, 3.4538236694422503`*^9, 3.4538259483409157`*^9, 
   3.453826469350016*^9, {3.4538373992114477`*^9, 3.4538374256931763`*^9}, 
   3.453837477368595*^9, 3.453838646018355*^9, {3.453838905538686*^9, 
   3.453838910306279*^9}, 3.453839436745421*^9, 3.463844880639366*^9, 
   3.4802621955329037`*^9, 3.4806922741384277`*^9, 3.481941952544153*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"oldsweetspot", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "0.0254"}], "*", 
    RowBox[{"0.205", "/", "2"}]}], "-", 
   RowBox[{"0.0254", "*", "0.12"}], "-", "0.001115", "+", 
   RowBox[{"0.003175", "/", "2"}]}]}]], "Input",
 CellChangeTimes->{{3.4537508826011543`*^9, 3.453750883775889*^9}, {
  3.4537527418735323`*^9, 3.453752742503742*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.0051790000000000004`"}]], "Output",
 CellChangeTimes->{
  3.4537496030114202`*^9, 3.453749666610465*^9, {3.453750887396463*^9, 
   3.453750909722947*^9}, 3.4537527433073397`*^9, 3.4538236694697313`*^9, 
   3.453825948369759*^9, 3.453837425726906*^9, 3.453838918528926*^9, 
   3.4638448806922894`*^9, 3.480262195562632*^9, 3.4806922741597643`*^9, 
   3.481941952586825*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"fz", "[", 
   RowBox[{"VE", ",", "oldsweetspot"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4537509122631893`*^9, 3.45375094919713*^9}, {
   3.453823640684885*^9, 3.453823640735626*^9}, {3.453826474859961*^9, 
   3.45382647576938*^9}, 3.4538373936510477`*^9, 3.453838901300256*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.021511999999997755`", ",", 
   RowBox[{"-", "0.012695220225685578`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.453750950353718*^9, 3.453823671960964*^9, 
  3.453825948604528*^9, 3.453826476451028*^9, 3.453837425763947*^9, 
  3.453838918661368*^9, 3.4638448807548018`*^9, 3.4802621956072607`*^9, 
  3.480692274189659*^9, 3.4819419526252537`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"fz", "[", 
   RowBox[{"VE", ",", 
    RowBox[{"-", "0.010"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.453751088575416*^9, 3.453751089087048*^9}, 
   3.453823640769184*^9, 3.453837393699996*^9, 3.453838901333053*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.017410000000001702`", ",", 
   RowBox[{"-", "0.010337130337810318`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.453749683527301*^9, 3.45375109040812*^9, 
  3.4538236722686167`*^9, 3.453825948821306*^9, 3.45382648659874*^9, 
  3.453837425793631*^9, 3.453838918742206*^9, 3.463844880837522*^9, 
  3.4802621956487217`*^9, 3.480692274215329*^9, 3.481941952668998*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"fz", "[", 
   RowBox[{"VE", ",", 
    RowBox[{"-", "0.003"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.453751094726705*^9, 3.453751095317946*^9}, 
   3.453823640822011*^9, 3.453837393750527*^9, 3.453838901368658*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.02348800000000395`", ",", 
   RowBox[{"-", "0.009243782811928643`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4537496838232193`*^9, 3.4537510967086277`*^9, 
  3.453823672557324*^9, 3.4538259490222588`*^9, 3.4538264890979757`*^9, 
  3.453837425851626*^9, 3.4538389187839413`*^9, 3.46384488093897*^9, 
  3.480262195696735*^9, 3.480692274248917*^9, 3.48194195271663*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sweet spot relative to centre of coil", "Text",
 CellChangeTimes->{{3.453823657396553*^9, 3.45382366152324*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"VE", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"-", "0.010"}], ",", "0.010"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453750960628242*^9, 3.453750962514122*^9}, 
   3.453823640869858*^9, 3.4538373938007517`*^9, {3.453838657031551*^9, 
   3.453838662984824*^9}, 3.453838901400448*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt2Xk4VO0bB3BRlJQlsoREK71SRAm3bCFkKSTZSgrZxjILY5vBHCJvKi2W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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{-0.01, 0.01}, {-0.013119228388884133`, 0.013119230426461693`}},
  
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.45374974088566*^9, 3.453751021464161*^9, 3.453823734388617*^9, 
   3.45382595105693*^9, 3.453826495876092*^9, 3.453837430614188*^9, {
   3.453838660033111*^9, 3.45383867436195*^9}, 3.4538389289668913`*^9, 
   3.46384489286368*^9, 3.4802622059949303`*^9, 3.480692283838723*^9, 
   3.481941962908568*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"VE", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.0", ",", "0.01"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, 
   3.453823640937874*^9, {3.4538265543875103`*^9, 3.453826559178968*^9}, 
   3.453837393850636*^9, {3.453838705965811*^9, 3.453838717842711*^9}, 
   3.453838901436325*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k8lNsfB3AqbopQEpdwSy5xrZUl+bRI0iZKlBZbi7JlZszzzMg2g3kk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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0., 0.01}, {0., 0.013119229771598732`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.4538234640829372`*^9, 3.45382375947115*^9, 
  3.453825952943671*^9, 3.4538265081040163`*^9, 3.453826563804844*^9, 
  3.45383743232346*^9, 3.453838725272155*^9, 3.453838935442772*^9, 
  3.463844900055211*^9, 3.480262212578673*^9, 3.48069228997019*^9, 
  3.48194196963024*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SSdata", "[", "VE", "]"}], " ", "=", " ", 
  RowBox[{"FindMinimum", "[", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"fz", "[", 
      RowBox[{"VE", ",", "p"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"p", ",", "0.005"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.453823404829797*^9, 3.453823405956604*^9}, {
   3.453823506088236*^9, 3.453823516693254*^9}, 3.453823641011278*^9, {
   3.4538265379087467`*^9, 3.453826543745769*^9}, 3.453837393910678*^9, {
   3.4538387257460747`*^9, 3.453838749683352*^9}, {3.4538387973199577`*^9, 
   3.453838821469616*^9}, {3.453862450307226*^9, 3.45386248039209*^9}, {
   3.453862568949154*^9, 3.453862570115514*^9}, {3.45386264847299*^9, 
   3.453862649636854*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.013119230572841659`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", "0.00631545419721644`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453823468555167*^9, 3.453823535452108*^9, 3.453825954168241*^9, {
   3.453826526324848*^9, 3.453826545225122*^9}, 3.4538374328189507`*^9, {
   3.4538387298936996`*^9, 3.4538387449128933`*^9}, {3.4538387984605837`*^9, 
   3.453838822542676*^9}, 3.453840162093855*^9, 3.4538402359560423`*^9, {
   3.4538624679971113`*^9, 3.4538624812382927`*^9}, 3.453862586264966*^9, 
   3.453862659344542*^9, 3.453862832601221*^9, 3.463844900650577*^9, 
   3.480692290440241*^9, 3.481941970310296*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SSpos", "[", "VE", "]"}], " ", "=", " ", 
  RowBox[{"p", "/.", 
   RowBox[{
    RowBox[{"SSdata", "[", "VE", "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.453862483701729*^9, 3.4538625105182133`*^9}, {
  3.453862576749049*^9, 3.453862581411574*^9}, {3.453862650555091*^9, 
  3.45386265144018*^9}}],

Cell[BoxData["0.00631545419721644`"], "Output",
 CellChangeTimes->{{3.4538625068641663`*^9, 3.4538625109082727`*^9}, 
   3.4538625864136257`*^9, 3.453862659454235*^9, 3.4538628327231894`*^9, 
   3.463844900679907*^9, 3.480692290473279*^9, 3.481941970349381*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SSpeak", "[", "VE", "]"}], " ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"SSdata", "[", "VE", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.453862473476694*^9, 3.453862474190342*^9}, {
  3.453862598812314*^9, 3.453862615921789*^9}, {3.453862652024186*^9, 
  3.4538626531996193`*^9}}],

Cell[BoxData["0.013119230572841659`"], "Output",
 CellChangeTimes->{3.453862616387323*^9, 3.4538626595105743`*^9, 
  3.453862832777169*^9, 3.4638449007258987`*^9, 3.4806922905067368`*^9, 
  3.481941970402519*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["New coil calc for alternate value-engineered LIGO-I", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, {
  3.45382361286519*^9, 3.4538236144707003`*^9}, {3.453838874626217*^9, 
  3.4538388807274017`*^9}, {3.453841072413919*^9, 3.4538410760356073`*^9}}],

Cell[CellGroupData[{

Cell["\<\
VE2vals = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->lold,\t\t\t\t(* length *)
\t\ta->aold,\t\t\t(* radius *)
\t\t(* coil length *)
\t\tcoillen->0.207*0.0254, (* D0901048-v4 *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.334*0.0254, (* 0.334=0.498-0.164, increased from 0.302 *)
\t\tcoilarea->0.347*0.164*0.0254^2, (* desired area, same as VEvals *)
\t\tcoildr->coilarea/(0.207*0.0254), (* desired difference in radius for \
desired area and length from OOvals *)
\t\tcoilrad2->coilrad1+coildr, (*  *)
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.453819143842659*^9, 3.45381916873015*^9}, {
   3.453819205916604*^9, 3.453819229397924*^9}, {3.4538192680904627`*^9, 
   3.453819317992671*^9}, {3.453819379538721*^9, 3.453819381962309*^9}, {
   3.453819414835219*^9, 3.453819449256628*^9}, {3.453823205503562*^9, 
   3.453823222597754*^9}, {3.453826073117807*^9, 3.453826150751071*^9}, 
   3.4538373389188223`*^9, 3.453841092308299*^9, {3.453841283965046*^9, 
   3.4538412881475286`*^9}, {3.4538413725493402`*^9, 
   3.4538413849806833`*^9}, {3.453841501978483*^9, 3.453841779519685*^9}, {
   3.480274240165839*^9, 3.480274249772677*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.00006696614374535086`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.014824999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.005257799999999999`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.0026288999999999996`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.0026288999999999996`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.0084836`"}], ",", 
   RowBox[{"coilarea", "\[Rule]", "0.00003671476528`"}], ",", 
   RowBox[{"coildr", "\[Rule]", "0.006982914009661837`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.015466514009661838`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.089479932527026`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4538417843516493`*^9, 3.463844900775058*^9, 
  3.480692290540955*^9, 3.481941970502873*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "VE2", "]"}], " ", ":=", " ", "VE2vals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, {
   3.453823624487136*^9, 3.453823640631469*^9}, {3.453837378474317*^9, 
   3.453837393571328*^9}, {3.4538388861923847`*^9, 3.453838889904484*^9}, {
   3.453841247783547*^9, 3.4538412572609777`*^9}, 3.4538417923838587`*^9}],

Cell[CellGroupData[{

Cell["Sweet spot relative to centre of coil", "Text",
 CellChangeTimes->{{3.453823657396553*^9, 3.45382366152324*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"VE2", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"-", "0.010"}], ",", "0.010"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453750960628242*^9, 3.453750962514122*^9}, 
   3.453823640869858*^9, 3.4538373938007517`*^9, {3.453838657031551*^9, 
   3.453838662984824*^9}, 3.453838901400448*^9, 3.453841257421837*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt2Xk0Vd8XAHAhlRKiDGkgFRKSRIYtQ0kSSUIZosk8vncfHnrvefdWGmkW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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{-0.01, 0.01}, {-0.011911333952159105`, 0.0119113346320878}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.45374974088566*^9, 3.453751021464161*^9, 3.453823734388617*^9, 
   3.45382595105693*^9, 3.453826495876092*^9, 3.453837430614188*^9, {
   3.453838660033111*^9, 3.45383867436195*^9}, 3.4538389289668913`*^9, 
   3.4538418441367064`*^9, 3.4638449203570347`*^9, 3.480692306252309*^9, 
   3.4819419881990843`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"VE2", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.0", ",", "0.01"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, 
   3.453823640937874*^9, {3.4538265543875103`*^9, 3.453826559178968*^9}, 
   3.453837393850636*^9, {3.453838705965811*^9, 3.453838717842711*^9}, 
   3.453838901436325*^9, 3.453841257441544*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk41FsYB3BxSRIRE1KEVNyQq5Lkq5IthWRJyBKyZZvlNzMKY5ifkq2o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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0., 0.01}, {0., 0.011911334644876743`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.4538234640829372`*^9, 3.45382375947115*^9, 
  3.453825952943671*^9, 3.4538265081040163`*^9, 3.453826563804844*^9, 
  3.45383743232346*^9, 3.453838725272155*^9, 3.453838935442772*^9, 
  3.453841854513754*^9, 3.463844932499839*^9, 3.480692315858614*^9, 
  3.481942001190299*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindMinimum", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"fz", "[", 
     RowBox[{"VE2", ",", "p"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.005"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823404829797*^9, 3.453823405956604*^9}, {
   3.453823506088236*^9, 3.453823516693254*^9}, 3.453823641011278*^9, {
   3.4538265379087467`*^9, 3.453826543745769*^9}, 3.453837393910678*^9, {
   3.4538387257460747`*^9, 3.453838749683352*^9}, {3.4538387973199577`*^9, 
   3.453838821469616*^9}, 3.453838901466652*^9, 3.453841257454495*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.011911334644952164`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", "0.005962869118767199`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453823468555167*^9, 3.453823535452108*^9, 3.453825954168241*^9, {
   3.453826526324848*^9, 3.453826545225122*^9}, 3.4538374328189507`*^9, {
   3.4538387298936996`*^9, 3.4538387449128933`*^9}, {3.4538387984605837`*^9, 
   3.453838822542676*^9}, 3.453838936153399*^9, 3.453839519837987*^9, 
   3.453841855442709*^9, 3.463844933406391*^9, 3.48069231649853*^9, 
   3.481942002157364*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SSpeak", "[", "VE", "]"}], "/", 
  RowBox[{"SSpeak", "[", "OO", "]"}]}]], "Input",
 CellChangeTimes->{{3.453865307265691*^9, 3.453865311272402*^9}}],

Cell[BoxData["0.827109947907036`"], "Output",
 CellChangeTimes->{3.4538653118630533`*^9, 3.463844933516652*^9, 
  3.48069231654394*^9, 3.481942002211248*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["New coil calc for AOSEM (D0901048-v4) and LIGO-I magnet", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, {
  3.45382361286519*^9, 3.4538236144707003`*^9}, {3.453838874626217*^9, 
  3.4538388807274017`*^9}, {3.453841072413919*^9, 3.4538410760356073`*^9}, {
  3.48069476991868*^9, 3.4806947920213118`*^9}}],

Cell[CellGroupData[{

Cell["\<\
AOvals = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->lold,\t\t\t\t(* length *)
\t\ta->aold,\t\t\t(* radius *)
\t\t(* coil length *)
\t\tcoillen->0.207*0.0254, (* D0901048-v4 *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.304*0.0254, (* D0901048-v4 *)
\t\tcoilrad2->0.996/2*0.0254, (* D0901048-v4 *)
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.453819143842659*^9, 3.45381916873015*^9}, {
   3.453819205916604*^9, 3.453819229397924*^9}, {3.4538192680904627`*^9, 
   3.453819317992671*^9}, {3.453819379538721*^9, 3.453819381962309*^9}, {
   3.453819414835219*^9, 3.453819449256628*^9}, {3.453823205503562*^9, 
   3.453823222597754*^9}, {3.453826073117807*^9, 3.453826150751071*^9}, 
   3.4538373389188223`*^9, 3.453841092308299*^9, {3.453841283965046*^9, 
   3.4538412881475286`*^9}, {3.4538413725493402`*^9, 
   3.4538413849806833`*^9}, {3.453841501978483*^9, 3.453841779519685*^9}, {
   3.480274240165839*^9, 3.480274249772677*^9}, 3.480694811626128*^9, {
   3.4806948459029713`*^9, 3.480694858042783*^9}, {3.480694900775441*^9, 
   3.480694950070912*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.00006696614374535086`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.014824999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.005257799999999999`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.0026288999999999996`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.0026288999999999996`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.0077215999999999995`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.0126492`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.5439046765338914`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4538417843516493`*^9, 3.463844900775058*^9, 
  3.480692290540955*^9, 3.480695055734477*^9, 3.481942002252563*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "AO", "]"}], " ", ":=", " ", "AOvals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, {
   3.453823624487136*^9, 3.453823640631469*^9}, {3.453837378474317*^9, 
   3.453837393571328*^9}, {3.4538388861923847`*^9, 3.453838889904484*^9}, {
   3.453841247783547*^9, 3.4538412572609777`*^9}, 3.4538417923838587`*^9, {
   3.480694812819429*^9, 3.480694813277412*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"optdata", "[", "AO", "]"}], " ", "=", " ", 
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.01577331278972314`"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", "\[Rule]", "0.005342368876734437`"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"Minimize", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"fz", "[", 
           RowBox[{"AO", ",", "z"}], "]"}]}], ",", " ", 
         RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
        "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.479667008672338*^9, 3.4796670332310963`*^9}, {
   3.480244318582687*^9, 3.4802443450940313`*^9}, {3.4806950416816607`*^9, 
   3.48069504236414*^9}, 3.4806950855740757`*^9, 3.480695391023115*^9, {
   3.480695424453774*^9, 3.480695426213916*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"plot", "[", "AO", "]"}], " ", "=", " ", 
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
     GraphicsBox[{{}, {}, 
       {GrayLevel[0], LineBox[CompressedData["
1:eJwV13k8VOsfB3C0EJLspIuSshNtwkebuCHK0kaijRBmzgwzk50yjDNZElGR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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      PlotRange->{{0, 0.013}, {0., 0.01577331278116163}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"fz", "[", 
        RowBox[{"AO", ",", "p"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.479666887455168*^9, 
   3.479666888838862*^9}, {3.480244879780376*^9, 3.480244897499516*^9}, 
   3.4802450058581*^9, {3.480695043059854*^9, 3.480695043824891*^9}, 
   3.480695087059374*^9, 3.480695404783731*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "AO", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "AO", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.479666890574193*^9, 
   3.479666892310862*^9}, {3.480695044500922*^9, 3.480695045299432*^9}}],

Cell[BoxData["0.005342368876734437`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.4796669544241667`*^9, 
  3.479667628122774*^9, 3.480244912925961*^9, 3.480692316685502*^9, 
  3.480695182351778*^9, 3.4819420024634247`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "AO", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "AO", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.479666893782012*^9, 
   3.479666894910797*^9}, {3.480695045805807*^9, 3.480695046244318*^9}}],

Cell[BoxData["0.01577331278972314`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.479666954466415*^9, 
  3.4796676281467333`*^9, 3.480244912993281*^9, 3.480692316727179*^9, 
  3.480695182407237*^9, 3.4819420025016727`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "AO", "]"}], " ", "=", " ", 
  RowBox[{"-", 
   RowBox[{"ND", "[", 
    RowBox[{
     RowBox[{"fz", "[", 
      RowBox[{"AO", ",", "z"}], "]"}], ",", "z", ",", 
     RowBox[{"zmax", "[", "AO", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479666215169937*^9, 3.479666222032254*^9}, {
  3.479666896879272*^9, 3.479666899310975*^9}, {3.4806950467973213`*^9, 
  3.480695048584566*^9}}],

Cell[BoxData["1.612572093492645`"], "Output",
 CellChangeTimes->{3.479666223290411*^9, 3.479666954528255*^9, 
  3.479667628426712*^9, 3.480244913348442*^9, 3.480692317008646*^9, 
  3.480695182494129*^9, 3.4819420026376257`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sweet spot relative to centre of coil", "Text",
 CellChangeTimes->{{3.453823657396553*^9, 3.45382366152324*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"AO", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"-", "0.010"}], ",", "0.010"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453750960628242*^9, 3.453750962514122*^9}, 
   3.453823640869858*^9, 3.4538373938007517`*^9, {3.453838657031551*^9, 
   3.453838662984824*^9}, 3.453838901400448*^9, 3.453841257421837*^9, 
   3.4806948139055853`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt2Xk0Vd0bB3BTCiEzpUIlVJokST1FMiQ0SIgoQmS6k3m+yHDPFd5UGpUp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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{-0.01, 0.01}, {-0.015773312770077815`, 0.01577331065555399}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.45374974088566*^9, 3.453751021464161*^9, 3.453823734388617*^9, 
   3.45382595105693*^9, 3.453826495876092*^9, 3.453837430614188*^9, {
   3.453838660033111*^9, 3.45383867436195*^9}, 3.4538389289668913`*^9, 
   3.4538418441367064`*^9, 3.4638449203570347`*^9, 3.480692306252309*^9, 
   3.481942019293109*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"AO", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.0", ",", "0.01"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, 
   3.453823640937874*^9, {3.4538265543875103`*^9, 3.453826559178968*^9}, 
   3.453837393850636*^9, {3.453838705965811*^9, 3.453838717842711*^9}, 
   3.453838901436325*^9, 3.453841257441544*^9, 3.480694814624156*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk4lF8bB3BSImQJRYmQNiF5q5/wbRUqW7IVJVuUjJl5HkOyzsg+Q1K2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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0., 0.01}, {0., 0.015773312580828872`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.4538234640829372`*^9, 3.45382375947115*^9, 
  3.453825952943671*^9, 3.4538265081040163`*^9, 3.453826563804844*^9, 
  3.45383743232346*^9, 3.453838725272155*^9, 3.453838935442772*^9, 
  3.453841854513754*^9, 3.463844932499839*^9, 3.480692315858614*^9, 
  3.481942029259119*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindMinimum", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"fz", "[", 
     RowBox[{"AO", ",", "p"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.005"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823404829797*^9, 3.453823405956604*^9}, {
   3.453823506088236*^9, 3.453823516693254*^9}, 3.453823641011278*^9, {
   3.4538265379087467`*^9, 3.453826543745769*^9}, 3.453837393910678*^9, {
   3.4538387257460747`*^9, 3.453838749683352*^9}, {3.4538387973199577`*^9, 
   3.453838821469616*^9}, 3.453838901466652*^9, 3.453841257454495*^9, 
   3.480694816395583*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.01577331278970187`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", "0.00534236490162246`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453823468555167*^9, 3.453823535452108*^9, 3.453825954168241*^9, {
   3.453826526324848*^9, 3.453826545225122*^9}, 3.4538374328189507`*^9, {
   3.4538387298936996`*^9, 3.4538387449128933`*^9}, {3.4538387984605837`*^9, 
   3.453838822542676*^9}, 3.453838936153399*^9, 3.453839519837987*^9, 
   3.453841855442709*^9, 3.463844933406391*^9, 3.48069231649853*^9, 
   3.481942029872281*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
New coil calc for AOSEM (D0901048-v4) and extra small, \[OSlash]2 mm x 0.5 mm \
magnet\
\>", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, {
   3.45382361286519*^9, 3.4538236144707003`*^9}, {3.453838874626217*^9, 
   3.4538388807274017`*^9}, {3.453841072413919*^9, 3.4538410760356073`*^9}, {
   3.48069476991868*^9, 3.4806947920213118`*^9}, {3.480695820456702*^9, 
   3.4806958224791937`*^9}, {3.480699030573723*^9, 3.480699039227467*^9}, 
   3.480699179006065*^9}],

Cell[CellGroupData[{

Cell["\<\
AOESvals = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->0.0005,\t\t\t\t(* length *)
\t\ta->0.002/2,\t\t\t(* radius *)
\t\t(* coil length *)
\t\tcoillen->0.207*0.0254, (* D0901048-v4 *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.304*0.0254, (* D0901048-v4 *)
\t\tcoilrad2->0.996/2*0.0254, (* D0901048-v4 *)
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.453819143842659*^9, 3.45381916873015*^9}, {
   3.453819205916604*^9, 3.453819229397924*^9}, {3.4538192680904627`*^9, 
   3.453819317992671*^9}, {3.453819379538721*^9, 3.453819381962309*^9}, {
   3.453819414835219*^9, 3.453819449256628*^9}, {3.453823205503562*^9, 
   3.453823222597754*^9}, {3.453826073117807*^9, 3.453826150751071*^9}, 
   3.4538373389188223`*^9, 3.453841092308299*^9, {3.453841283965046*^9, 
   3.4538412881475286`*^9}, {3.4538413725493402`*^9, 
   3.4538413849806833`*^9}, {3.453841501978483*^9, 3.453841779519685*^9}, {
   3.480274240165839*^9, 3.480274249772677*^9}, 3.480694811626128*^9, {
   3.4806948459029713`*^9, 3.480694858042783*^9}, {3.480694900775441*^9, 
   3.480694950070912*^9}, 3.480695858267105*^9, {3.480696997173448*^9, 
   3.48069702724988*^9}, {3.480699187974929*^9, 3.480699197276938*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.000011623892818282234`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.017499999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.0005`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.001`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.005257799999999999`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.0026288999999999996`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.0026288999999999996`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.0077215999999999995`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.0126492`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.5439046765338914`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4538417843516493`*^9, 3.463844900775058*^9, 
  3.480692290540955*^9, 3.480695055734477*^9, 3.480697045556779*^9, 
  3.480699218382852*^9, 3.481566729144149*^9, 3.481942029907995*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "AOES", "]"}], " ", ":=", " ", "AOESvals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, {
   3.453823624487136*^9, 3.453823640631469*^9}, {3.453837378474317*^9, 
   3.453837393571328*^9}, {3.4538388861923847`*^9, 3.453838889904484*^9}, {
   3.453841247783547*^9, 3.4538412572609777`*^9}, 3.4538417923838587`*^9, {
   3.480694812819429*^9, 3.480694813277412*^9}, {3.4806958602050734`*^9, 
   3.480695860693163*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "AOES", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.002807824198073727`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.005198473408953153`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"fz", "[", 
          RowBox[{"AOES", ",", "z"}], "]"}]}], ",", " ", 
        RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.479667008672338*^9, 3.4796670332310963`*^9}, {
   3.480244318582687*^9, 3.4802443450940313`*^9}, {3.4806950416816607`*^9, 
   3.48069504236414*^9}, 3.4806950855740757`*^9, 3.480695391023115*^9, {
   3.480695424453774*^9, 3.480695426213916*^9}, {3.4806958612576303`*^9, 
   3.480695861809552*^9}, 3.480697041276504*^9, 3.480699359418405*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.002807824198073727`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.005198473408953153`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4806971192435513`*^9, 3.4806993237886267`*^9, 
  3.4806993994484053`*^9, 3.48156682235257*^9, 3.481942029984186*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "AOES", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nk4VdsbB3Bxi0qSypBuKIXiRikUvgglQ5mHUqazKeI45+zjGDJHjkhF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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 0.002807824129332503}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"AOES", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.479666887455168*^9, 
   3.479666888838862*^9}, {3.480244879780376*^9, 3.480244897499516*^9}, 
   3.4802450058581*^9, {3.480695043059854*^9, 3.480695043824891*^9}, 
   3.480695087059374*^9, 3.480695404783731*^9, {3.4806958623058577`*^9, 
   3.480695862857663*^9}, 3.4806970427358437`*^9, 3.480699363708275*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nk4VdsbB3Bxi0qSypBuKIXiRikUvgglQ5mHUqazKeI45+zjGDJHjkhF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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 0.013}, {0., 0.002807824129332503}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.48069712546273*^9, 3.480699332309153*^9, 
  3.480699399566325*^9, 3.481566829952278*^9, 3.481942030040433*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "AOES", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "AOES", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.479666890574193*^9, 
   3.479666892310862*^9}, {3.480695044500922*^9, 3.480695045299432*^9}, {
   3.48069586344763*^9, 3.480695864000742*^9}}],

Cell[BoxData["0.005198473408953153`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.4796669544241667`*^9, 
  3.479667628122774*^9, 3.480244912925961*^9, 3.480692316685502*^9, 
  3.480695182351778*^9, 3.480697125524988*^9, 3.480699332401712*^9, 
  3.481566830010151*^9, 3.48194203006644*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "AOES", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "AOES", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.479666893782012*^9, 
   3.479666894910797*^9}, {3.480695045805807*^9, 3.480695046244318*^9}, {
   3.480695864548365*^9, 3.4806958649909143`*^9}}],

Cell[BoxData["0.002807824198073727`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.479666954466415*^9, 
  3.4796676281467333`*^9, 3.480244912993281*^9, 3.480692316727179*^9, 
  3.480695182407237*^9, 3.480697125554319*^9, 3.480699332444682*^9, 
  3.481566830040126*^9, 3.481942030118945*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "AOES", "]"}], " ", "=", " ", 
  RowBox[{"-", 
   RowBox[{"ND", "[", 
    RowBox[{
     RowBox[{"fz", "[", 
      RowBox[{"AOES", ",", "z"}], "]"}], ",", "z", ",", 
     RowBox[{"zmax", "[", "AOES", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479666215169937*^9, 3.479666222032254*^9}, {
  3.479666896879272*^9, 3.479666899310975*^9}, {3.4806950467973213`*^9, 
  3.480695048584566*^9}, {3.480695865586025*^9, 3.480695866881131*^9}}],

Cell[BoxData["0.28805476674820313`"], "Output",
 CellChangeTimes->{3.479666223290411*^9, 3.479666954528255*^9, 
  3.479667628426712*^9, 3.480244913348442*^9, 3.480692317008646*^9, 
  3.480695182494129*^9, 3.480697125653082*^9, 3.4806993325320377`*^9, 
  3.481566830119721*^9, 3.481942030212583*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sweet spot relative to centre of coil", "Text",
 CellChangeTimes->{{3.453823657396553*^9, 3.45382366152324*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"AOES", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"-", "0.010"}], ",", "0.010"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453750960628242*^9, 3.453750962514122*^9}, 
   3.453823640869858*^9, 3.4538373938007517`*^9, {3.453838657031551*^9, 
   3.453838662984824*^9}, 3.453838901400448*^9, 3.453841257421837*^9, 
   3.4806948139055853`*^9, 3.48069586856068*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt2Xk0VP//B3DZKpW0SEmSdmT7SAv1KlSWkpJEGdvMlSXLzNyZYSxhQihr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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{-0.01, 0.01}, {-0.0028078239864345513`, 0.002807824196044576}},
  
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.45374974088566*^9, 3.453751021464161*^9, 3.453823734388617*^9, 
   3.45382595105693*^9, 3.453826495876092*^9, 3.453837430614188*^9, {
   3.453838660033111*^9, 3.45383867436195*^9}, 3.4538389289668913`*^9, 
   3.4538418441367064`*^9, 3.4638449203570347`*^9, 3.480692306252309*^9, 
   3.480697135921809*^9, 3.480699347175211*^9, 3.481566843006109*^9, 
   3.481942047830917*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"AOES", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.0", ",", "0.01"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, 
   3.453823640937874*^9, {3.4538265543875103`*^9, 3.453826559178968*^9}, 
   3.453837393850636*^9, {3.453838705965811*^9, 3.453838717842711*^9}, 
   3.453838901436325*^9, 3.453841257441544*^9, 3.480694814624156*^9, 
   3.480695869313149*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk81NsbB3AKEaJCcSuSK5UkdSkxH0m2NlmjjHW+ZR9mvmOobI02khQl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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0., 0.01}, {0., 0.0028078240720869}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.4538234640829372`*^9, 3.45382375947115*^9, 
  3.453825952943671*^9, 3.4538265081040163`*^9, 3.453826563804844*^9, 
  3.45383743232346*^9, 3.453838725272155*^9, 3.453838935442772*^9, 
  3.453841854513754*^9, 3.463844932499839*^9, 3.480692315858614*^9, 
  3.480697141979739*^9, 3.480699356475226*^9, 3.481566851563313*^9, 
  3.481942060181831*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindMinimum", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"fz", "[", 
     RowBox[{"AOES", ",", "p"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.005"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823404829797*^9, 3.453823405956604*^9}, {
   3.453823506088236*^9, 3.453823516693254*^9}, 3.453823641011278*^9, {
   3.4538265379087467`*^9, 3.453826543745769*^9}, 3.453837393910678*^9, {
   3.4538387257460747`*^9, 3.453838749683352*^9}, {3.4538387973199577`*^9, 
   3.453838821469616*^9}, 3.453838901466652*^9, 3.453841257454495*^9, 
   3.480694816395583*^9, 3.4806958708335733`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.0028078241980691253`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", "0.005198470254476054`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453823468555167*^9, 3.453823535452108*^9, 3.453825954168241*^9, {
   3.453826526324848*^9, 3.453826545225122*^9}, 3.4538374328189507`*^9, {
   3.4538387298936996`*^9, 3.4538387449128933`*^9}, {3.4538387984605837`*^9, 
   3.453838822542676*^9}, 3.453838936153399*^9, 3.453839519837987*^9, 
   3.453841855442709*^9, 3.463844933406391*^9, 3.48069231649853*^9, 
   3.480697142379641*^9, 3.4806993585664883`*^9, 3.481566852005377*^9, 
   3.481942060656612*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
New coil calc for AOSEM (D0901048-v4) and (approximately) double length, \
\[OSlash]2 mm x 6 mm magnet\
\>", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, {
  3.45382361286519*^9, 3.4538236144707003`*^9}, {3.453838874626217*^9, 
  3.4538388807274017`*^9}, {3.453841072413919*^9, 3.4538410760356073`*^9}, {
  3.48069476991868*^9, 3.4806947920213118`*^9}, {3.480695820456702*^9, 
  3.4806958224791937`*^9}, {3.480699030573723*^9, 3.480699039227467*^9}, {
  3.480699105085774*^9, 3.480699140273758*^9}, {3.480699240398816*^9, 
  3.4806992456450768`*^9}, {3.4806992858633623`*^9, 3.480699289781164*^9}}],

Cell[CellGroupData[{

Cell["\<\
AODLvals = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->0.006,\t\t\t\t(* length *)
\t\ta->0.002/2,\t\t\t(* radius *)
\t\t(* coil length *)
\t\tcoillen->0.207*0.0254, (* D0901048-v4 *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.304*0.0254, (* D0901048-v4 *)
\t\tcoilrad2->0.996/2*0.0254, (* D0901048-v4 *)
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.453819143842659*^9, 3.45381916873015*^9}, {
   3.453819205916604*^9, 3.453819229397924*^9}, {3.4538192680904627`*^9, 
   3.453819317992671*^9}, {3.453819379538721*^9, 3.453819381962309*^9}, {
   3.453819414835219*^9, 3.453819449256628*^9}, {3.453823205503562*^9, 
   3.453823222597754*^9}, {3.453826073117807*^9, 3.453826150751071*^9}, 
   3.4538373389188223`*^9, 3.453841092308299*^9, {3.453841283965046*^9, 
   3.4538412881475286`*^9}, {3.4538413725493402`*^9, 
   3.4538413849806833`*^9}, {3.453841501978483*^9, 3.453841779519685*^9}, {
   3.480274240165839*^9, 3.480274249772677*^9}, 3.480694811626128*^9, {
   3.4806948459029713`*^9, 3.480694858042783*^9}, {3.480694900775441*^9, 
   3.480694950070912*^9}, 3.480695858267105*^9, {3.480696997173448*^9, 
   3.48069702724988*^9}, {3.48069930379321*^9, 3.480699340598193*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.0001394867138193868`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.011999999999999999`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.006`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.001`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.005257799999999999`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.0026288999999999996`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.0026288999999999996`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.0077215999999999995`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.0126492`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.5439046765338914`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4538417843516493`*^9, 3.463844900775058*^9, 
  3.480692290540955*^9, 3.480695055734477*^9, 3.480697045556779*^9, 
  3.480699411967904*^9, 3.481566894140891*^9, 3.4819420607019053`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "AODL", "]"}], " ", ":=", " ", "AODLvals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, {
   3.453823624487136*^9, 3.453823640631469*^9}, {3.453837378474317*^9, 
   3.453837393571328*^9}, {3.4538388861923847`*^9, 3.453838889904484*^9}, {
   3.453841247783547*^9, 3.4538412572609777`*^9}, 3.4538417923838587`*^9, {
   3.480694812819429*^9, 3.480694813277412*^9}, {3.4806958602050734`*^9, 
   3.480695860693163*^9}, {3.480699304968781*^9, 3.480699305631609*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.01577331278972314`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.005342368876734437`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"fz", "[", 
          RowBox[{"AODL", ",", "z"}], "]"}]}], ",", " ", 
        RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.479667008672338*^9, 3.4796670332310963`*^9}, {
   3.480244318582687*^9, 3.4802443450940313`*^9}, {3.4806950416816607`*^9, 
   3.48069504236414*^9}, 3.4806950855740757`*^9, 3.480695391023115*^9, {
   3.480695424453774*^9, 3.480695426213916*^9}, {3.4806958612576303`*^9, 
   3.480695861809552*^9}, 3.480697041276504*^9, {3.480699306305072*^9, 
   3.480699307040391*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.01577331278972314`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.005342368876734437`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4806971192435513`*^9, 3.480699516644302*^9, 
  3.481566985502486*^9, 3.481942060779174*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV13k8VOsfB3C0EJLspIuSshNtwkebuCHK0kaijRBmzgwzk50yjDNZElGR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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 0.01577331278116163}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"AODL", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.479666887455168*^9, 
   3.479666888838862*^9}, {3.480244879780376*^9, 3.480244897499516*^9}, 
   3.4802450058581*^9, {3.480695043059854*^9, 3.480695043824891*^9}, 
   3.480695087059374*^9, 3.480695404783731*^9, {3.4806958623058577`*^9, 
   3.480695862857663*^9}, 3.4806970427358437`*^9, {3.480699307709909*^9, 
   3.4806993083441687`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV13k8VOsfB3C0EJLspIuSshNtwkebuCHK0kaijRBmzgwzk50yjDNZElGR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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 0.013}, {0., 0.01577331278116163}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.48069712546273*^9, 3.480699525015361*^9, 
  3.481566993083891*^9, 3.4819420608359413`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "AODL", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "AODL", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.479666890574193*^9, 
   3.479666892310862*^9}, {3.480695044500922*^9, 3.480695045299432*^9}, {
   3.48069586344763*^9, 3.480695864000742*^9}, {3.4806993090802107`*^9, 
   3.480699309671587*^9}}],

Cell[BoxData["0.005342368876734437`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.4796669544241667`*^9, 
  3.479667628122774*^9, 3.480244912925961*^9, 3.480692316685502*^9, 
  3.480695182351778*^9, 3.480697125524988*^9, 3.4806995251344767`*^9, 
  3.481566993139513*^9, 3.481942060861919*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "AODL", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "AODL", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.479666893782012*^9, 
   3.479666894910797*^9}, {3.480695045805807*^9, 3.480695046244318*^9}, {
   3.480695864548365*^9, 3.4806958649909143`*^9}, {3.4806993103161793`*^9, 
   3.480699311077731*^9}}],

Cell[BoxData["0.01577331278972314`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.479666954466415*^9, 
  3.4796676281467333`*^9, 3.480244912993281*^9, 3.480692316727179*^9, 
  3.480695182407237*^9, 3.480697125554319*^9, 3.480699525202236*^9, 
  3.481566993161881*^9, 3.4819420609176197`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{"-", 
   RowBox[{"ND", "[", 
    RowBox[{
     RowBox[{"fz", "[", 
      RowBox[{"AODL", ",", "z"}], "]"}], ",", "z", ",", 
     RowBox[{"zmax", "[", "AODL", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479666215169937*^9, 3.479666222032254*^9}, {
  3.479666896879272*^9, 3.479666899310975*^9}, {3.4806950467973213`*^9, 
  3.480695048584566*^9}, {3.480695865586025*^9, 3.480695866881131*^9}, {
  3.480699311786655*^9, 3.480699312934915*^9}}],

Cell[BoxData["3.0784112215536754`"], "Output",
 CellChangeTimes->{3.479666223290411*^9, 3.479666954528255*^9, 
  3.479667628426712*^9, 3.480244913348442*^9, 3.480692317008646*^9, 
  3.480695182494129*^9, 3.480697125653082*^9, 3.480699525342955*^9, 
  3.481566993242647*^9, 3.481942061013647*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sweet spot relative to centre of coil", "Text",
 CellChangeTimes->{{3.453823657396553*^9, 3.45382366152324*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"AODL", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"-", "0.010"}], ",", "0.010"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453750960628242*^9, 3.453750962514122*^9}, 
   3.453823640869858*^9, 3.4538373938007517`*^9, {3.453838657031551*^9, 
   3.453838662984824*^9}, 3.453838901400448*^9, 3.453841257421837*^9, 
   3.4806948139055853`*^9, 3.48069586856068*^9, 3.48069931407596*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt2Xk8VN//B3AUilBkCRXaLJGQFvQuS5YQKkskUlmyz5g7Y6sYS5ZkCWHm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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{-0.01, 0.01}, {-0.03093422027097565, 0.030934222090156456`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.45374974088566*^9, 3.453751021464161*^9, 3.453823734388617*^9, 
   3.45382595105693*^9, 3.453826495876092*^9, 3.453837430614188*^9, {
   3.453838660033111*^9, 3.45383867436195*^9}, 3.4538389289668913`*^9, 
   3.4538418441367064`*^9, 3.4638449203570347`*^9, 3.480692306252309*^9, 
   3.480697135921809*^9, 3.480699539484208*^9, 3.481567006130314*^9, 
   3.481942077639205*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"AODL", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.0", ",", "0.01"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, 
   3.453823640937874*^9, {3.4538265543875103`*^9, 3.453826559178968*^9}, 
   3.453837393850636*^9, {3.453838705965811*^9, 3.453838717842711*^9}, 
   3.453838901436325*^9, 3.453841257441544*^9, 3.480694814624156*^9, 
   3.480695869313149*^9, 3.480699314862365*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1mk4VO8fBnBkKwolKUQl0iKkRHKrKJSsRbayL4VhljODbE0LbVLGkpkT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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0., 0.01}, {0., 0.030934221846478906`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.4538234640829372`*^9, 3.45382375947115*^9, 
  3.453825952943671*^9, 3.4538265081040163`*^9, 3.453826563804844*^9, 
  3.45383743232346*^9, 3.453838725272155*^9, 3.453838935442772*^9, 
  3.453841854513754*^9, 3.463844932499839*^9, 3.480692315858614*^9, 
  3.480697141979739*^9, 3.480699548181242*^9, 3.481567013982223*^9, 
  3.4819420873711357`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindMinimum", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"fz", "[", 
     RowBox[{"AODL", ",", "p"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.005"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823404829797*^9, 3.453823405956604*^9}, {
   3.453823506088236*^9, 3.453823516693254*^9}, 3.453823641011278*^9, {
   3.4538265379087467`*^9, 3.453826543745769*^9}, 3.453837393910678*^9, {
   3.4538387257460747`*^9, 3.453838749683352*^9}, {3.4538387973199577`*^9, 
   3.453838821469616*^9}, 3.453838901466652*^9, 3.453841257454495*^9, 
   3.480694816395583*^9, 3.4806958708335733`*^9, 3.4806993158810596`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.030934223187089285`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", "0.005708643127292772`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453823468555167*^9, 3.453823535452108*^9, 3.453825954168241*^9, {
   3.453826526324848*^9, 3.453826545225122*^9}, 3.4538374328189507`*^9, {
   3.4538387298936996`*^9, 3.4538387449128933`*^9}, {3.4538387984605837`*^9, 
   3.453838822542676*^9}, 3.453838936153399*^9, 3.453839519837987*^9, 
   3.453841855442709*^9, 3.463844933406391*^9, 3.48069231649853*^9, 
   3.480697142379641*^9, 3.480699548871449*^9, 3.481567014542268*^9, 
   3.4819420880567417`*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["New coil calc for bigmagnetvals5", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, 
   3.463844192181329*^9}],

Cell[CellGroupData[{

Cell["\<\
bigmagnetvals5 = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->0.005,\t\t\t\t(* length of half-big magnets *)
\t\ta->0.005,\t\t\t\t(* radius of half-big magnets *)
\t\t(* coil length *)
\t\tcoillen->0.16*0.0254,
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.35*0.0254,
\t\tcoilrad2->0.55*0.0254,
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.453837228357688*^9, 3.453837230833909*^9}, {
  3.463844183252262*^9, 3.463844223147016*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.0029059732045705585`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.012999999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.005`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.005`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.004064`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.002032`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.002032`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.008889999999999999`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.01397`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.9375038750077497`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.463844933665338*^9, 3.47966690722052*^9, 
  3.4802449126813803`*^9, 3.4806923165771303`*^9, 3.481941607857794*^9, 
  3.481942088088718*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "BM5", "]"}], " ", ":=", " ", "bigmagnetvals5"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, 
   3.463844187524227*^9, 3.463845359588154*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"optdata", "[", "BM5", "]"}], " ", "=", " ", 
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.6371543615438662`"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", "\[Rule]", "0.0050900302724624065`"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"Minimize", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"fz", "[", 
           RowBox[{"BM5", ",", "z"}], "]"}]}], ",", " ", 
         RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
        "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.479667008672338*^9, 3.4796670332310963`*^9}, {
   3.480244318582687*^9, 3.4802443450940313`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"plot", "[", "BM5", "]"}], " ", "=", " ", 
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
     GraphicsBox[{{}, {}, 
       {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nc8Vf8fB3ANo5KZFZUVDX1pkKyXSsMsWREZTXvcc+xN4qLQoK3SllQq
hKKiUNyLUijXPUZFNEXF7/P76z6ej3vO43M+n3Per/dbxStw256pAgIC06YI
CPz/t1KqO3Or4Tfj+cvbJF7KBprsikmpdCtrNjnpKFdzI9kKFz17N64p6zaR
D+iifZNd8aTl6CzNshETjb5LzPpkP7RkDA7NKxNA09POQKnkaOzwlndXKJOA
+LbZwklJGTjnVCQnV6aMkvQT5R4Jp1FtM/ZdpkwHK7RyNvWHF6LUpdtV1X8t
JOxu+5onV0L8lfClr3xzGE0GbJl89AxPwl8NLpC3RdaeW6L++xtxhxuRbJ3n
AJnkBn25Qg7yRevEchuccUBlvrrho1ZUi9Gy/dt3QkOnVO/3hzeI+KFlEbXf
E9s9qyrUHrxDtm3QVMnYXSjxWFvqr96FJ1K7x6493oOjU34N7E/+gJ9Prn5s
7twHwxc9BmJV3dDmiRxz+uKNtpifVMxxHlap3a6wHfXGeqdLAn0neDDY48xY
CvhAcrx8m9UZHsw+XltpKuUD/k07C6kCHly+WnAX6flgA5dJTbrNQ/KUTPHx
GB/YZIja/WngoV1Fkn16ti+ypnwsMZ3kIdFLIY6n5Ye1+tqbFrv3YNPA5fdr
df0wP+u9e4tnD0QDVplcMPZDt0jy4ajdPciN2PLPy8YPXU+2r6r17kFh1oEo
JtAPvNUBeWZUD95UfQ3rv+OHRebOw72pPdBSrA8a0vfH/mNPpCqKe9DWEuk1
ZhYA5d83TarHe7BEcVrTbJsAYJl0rsq/HsR7pRuqOgWgwlDucdwkuf/rqTmW
3gHQVhpL1p3OR6JYZe3pzAAsyRv/nDKbDx3zySWmrwNw+doDs+oFfLCrkr6n
7AuEzBqq8vg6ProFRT1OBQXirN+0l7fN+NCzPtp4KyIQETLipfUb+eB1FFxq
Tw+Eaqym6i8LPvTHnjktKQ7Ei+ds25V2fPSuFKl4+TsQBmqmwZt28ZFvv3Hd
zA1BqApoCX2bwIfaLQH9OPMgtPBfzb+axMflGQ+X/bAOAmddcA11gI/CKm2F
945BOGhjPiGcxseDRQojt/cHoddGyF42i49Xfz+fcc4Iwgwbv2buGT7+FWSP
XW0Jgqax1ujLB3zET1oOz2sPQtfUWp5rGR9TXYR6czqD8Domo+1jOR8i4lHN
0b1BaHXve/evko85EbuvbB0NgoFd4l6xp3xoWa92+D03GKsTGwY4TXy4/Ows
3uQVDJ7zaHdvLx+VX9NqAvcG46B31TLlfj6Uv+i15voE49AVUe72AT76+rJG
+0OCsb6cq/rsEx/B7WYmqUnBOBI0Ppw2zEfqw8KG5wXBsNAUzX76m+wvIbrP
vD8YixpFnwrMZDA3dvHv4M9kPVnN50KzGERHvp5xcjgY7rWlOrNEGaxj6Sz7
NBpM6v6LjrgYg1e7GRZbJAR+1qFj06QY9G2ymtKwOAQX1fbOOK/AYI6YkpKV
XwhcPv1WLtRkAN+Nq14FEdepO2UvYuDzPMhqKx2C3I8eZdRiBo8Tn0Xbx4bg
q86m6XpLGfiPBnS5ZoUgpPP0kwv/Majtrj7rXxKCaJH5+xbqMvhqPHh/uDQE
iaWKF4aIlU7JNgVXhsBg/2apEj0GIQ6+k3RtCCxCS44a6jNYUD/HI7Y9BPKR
Rdq6hgzC7+5TOfw3BEqJ69a3mDK4KJGzRnIKCzo8RiZuLdmff4XtEUEWnG2/
ayxex0B9kWRirhgLwT/uCYWvZ8A5Xd5zTpkFZmDFS4GNDJakzC4oNmOhzyTw
b5UFAwf+6ooV5ixI/3frr40lg3hTr9YSaxY4v7hmXcSvx+9PL3NkIdQo9NYP
KwaJgR57qvez8P6f+T+xLQw6tt/V4Gaw0BbRPO3bNnK+Ts0uwtksjJWpSrjb
MfjmOHTI6BgLW+1GC+qJRRw0Ry+fYYHnt8nvjD2DVban6qKKWJjC+RK13JGc
/9bSP8V3WGA3XunKIbbY0qbdd58Fc9f32d+IPazF87Y+YiEwUX1bkRODDPOk
/QubWXh8r0RsjjOD3M35p11aWZANzu71Jr6wqbL5cDsLox221lXEpRtG9ce7
WegYiud4uTDoXes7o+krC/k0q/zkDgYmBnbXw6Up5NU4xtW6MTBfE/T+phyF
2Lz8fMGdDOz1M6X4ihTYBRLO64l99OoirdUpKDzce7KcOHeFoaWqLoWpZV93
5rmT9Zdvj3NaQ8G8o8uhkbhIh76bYUxBs6/m4wTx0/9uKY5uoOBik/rJ3YPB
yBK1wQZHCgGdK3dKejL4s9hUecoOCldbVlkaEAstdrPXc6ewKnX9W09iJc3c
ivx9FFbqHHlXSKypUTLS5kuhkPvOppl4xUKO+qwgsl6Kzt5vxOZqszLpcAqN
w7zAFV5kP6qLqq9HU6hmXWRtJfZQ2fDzQzwFravXlPyJQxfEuVmkUXDQHna/
QJww/3R2XCYFR6fcWQ+JM+aVPSvJppDYqGbDJb6g+H3ZgpMUciwt6/8S01GZ
+4vOUlDelZ4tuYvB5g7Ni8YXKTB/DGrViZUMa7oar1C4+GyNtx7x8ElXeddC
CtoLNKM2EteM/9r2uZjCMrmCv/bEx12yMyPvUdjS6/bFk9i7fOnzGeUUFuZo
2foTG82tnXqiigKnyGZhGLFEpIfxoicU7Ggj/zhi/tvxsAd1FKoOHtJIIb6/
5tidjY0Udsw3tksnZp/QHmprpuB3TLHvELHb2AvNPW0UjkhV/Mki1nHe7fXj
LYWBZwMp2cTTyyZOJ72nIPhzWer//38jf+KNFJ+CapaRwP/vvx6+UupCP4Xy
kvThNOLY9pdWywcpvLmn6pRMbKu//+DjEQrNtdGrY4jV86bWbPlJoUQA2RTx
79HTf9+PUVhq8SnEh7jBafXqgAly3qelru8kPvuAE/xvKg3pI6KULXGInF9h
hjANfpF2xTriDWFC/YqiNJbv/RC7glj+Tb7KDQkasX/Hq5SJB/UMXQ1kaCio
pcbMJn50vO34CwUayU7R5b/J+8v5FcjZPp/GKcEboT3Eex1nig6o0tC9eedO
PbGoLBKEtGjE55XdPE78gX778JgOjVWKH/0jie+0sX6p69IwHTtb5ErsfOyq
73oTGse1vB4pEWv9XHeZu47GWhfjQ+Pk+xRw6Or23ERDRo7De018eY6UY/xW
GmkKnkrpxBFUYZa4A40YYaPpu4itWjc2nHWm4SH0mLWG+PuRKNNKLxquDp1D
PFJPptK9S8YpGkI5lLsKsTQrbk9aBA2RV1Ynhkj99XEV8uVjaUzP3+FRSpyZ
YyOz+iANt2jdE+bE7yRLJ1knaCRtu97gQuq7KHibwbSzNF62f0lQJE7gDFI5
F2j8q7xf/47kxaJslU/FN2hE+Y1KOBDTEumtQ5U05tSlFei7MlC+curVvhoa
ytKPPYZJ3jQaFz7n1dLo4d6uLiBW9X1Z0dZEQ+JuKTWLuPmZ+KVKHo09Ow2L
n5P8Whp1lM4UDMUGjZUzppH8ey15KVB4ZijquqrcCkg+Jl69550gFoqGXCtP
M+L2ttdutBy5/o5BWLwDgxQdhY1ui0NRa/95ZIDkMa/3jOwy61A07rp3JWor
qefoIokrtqHwsp+jK0KsL/1opopjKAL63aKOkLw/ZNo9Mcc9FO4yorqXbUi9
nVLt/xsUitap4QEVpD/kbr3yoPEouX5k0YHCzQysHxZv9+sMhWjk47PnQJ7n
+92AE92hcPL8MCxGvFvrQXItE4qNJad1Y0wYRJ6pLFYeCsVl2U/5jsYMrsbV
i7T9C8XTJnnBfwYMppoxpcYLwvBRw9ZBnvTP0kY5BXGvMNBrEoIyST82E1TU
Ntobhs2cZTadSxg0Gc/f4O0ThrUfInSWEPcVqQc/CQlDrFLK9Cekv0tnL38R
lhSGw+Nj4wMLGQQ4WEZ0F4Qhol40U0iZ1OP72Le3+8NQQlk0pUuTfhw2+VN/
MAzzRvOKr5N5okEiXurxSBiadAVjnkuS+lufYPlqLAzeO7rfCkiQeeFqUuWn
WeG4xim5vZvMJ26s1PNqOuEQClhAjU0neSaS430sPBxPDzUk7PhJ5q+Vl8bC
Z0TA2r98RK2FD6MA+RV3Z0fg+EmD6zJcPgKvpfsMSUZg06DZUSEOH68XhHR4
zo3A6mP8P72v+CgQRaXF0gg0bH6jcaqej7V97fFK1hHwOcq3/1DNR+QJUZHH
WRG4YvYumHuLj8FJlqywfCTGXm//HEPmydbEZokNKlFQey18KlyPjxerD1yf
vjYaiyj/On1uD6p295imW8fAtNgzrNavB4+e5IYeCYrFwmQf7aFRHp61v0uz
PBSHjr7Omro4HnpX8K32WMXDV99Gca4oDwFSBwp6O+Nx0VGmvTe9G6PLoiJf
7EqAsrbqzDypbiSq60NwIAG7NbYMdOt+gPSq8y0JYYkITAuuk1jxHgVxO/s8
/yVCV6t1/JFpF4yYuueJh5IgftH8cpJxJ1qTDywWlk3GzHlOR47YdCBAYGYE
/2QyfNvO5I/uewexYwZ5AksPQE30YMehkLco2vNIN+H2ATTElErSOe2w3zJy
Yd36FBxw2lMeeOkN/koPTOzgpqBAUPTbeM1rFMxZ9bbd6SAitIYfsn+2we4/
raTjAwfxJVkoxnJeG6Ymh994EJgKiRCtpnPOrbhbkl6j8yMVq1sPV9881wKf
CYtrn5LSMCZ40S61kwuV5J1iIjPZMOrvSD+pxYXp/Y7+naJszNo8Fnx8MRce
A9ur74mxUT+36WWOBhdnreyoXdJsLLyd2ZehzIWSzOZ3VUpsxH1+cCplDhey
l5dfprXZqKk4L571l4OZz6eb8O3ZwKDXj/FGDhaPJ8gZOLGRb2WaIljPwWat
yZEsZzZ8JnkZEnUcHMwau2iyk42ApR9/a1ZzMN35y4yT+9g46mJh6XqPg4mP
b9q2RrKxJmV3y7szHMxTcrh1JZqNlYn/3R48yYGRDTd1IpaNTJW4aZO5HETd
aTQsTGLDPq1v2sIcDn5HVp8XzmQjxXhVTGgKB3I3TaJ2HmZDY9B3Ij2JA70P
D+3vZbNhh5Hv5+M5oNffF951nI1xtwbDpkgOjtIreWV5bIjrzjjUF8ZByZXi
colTbChM0PYTFActb5cd3XeGjYk1Mw/LhnDwbdYN/6pzbGzwqjLWDuTgf9D1
xrU=
         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      PlotRange->{{0, 0.013}, {0., 0.6371543536135365}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"fz", "[", 
        RowBox[{"BM5", ",", "p"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.479666887455168*^9, 
   3.479666888838862*^9}, {3.480244879780376*^9, 3.480244897499516*^9}, 
   3.4802450058581*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "BM5", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "BM5", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.479666890574193*^9, 
   3.479666892310862*^9}}],

Cell[BoxData["0.0050900302724624065`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.4796669544241667`*^9, 
  3.479667628122774*^9, 3.480244912925961*^9, 3.480692316685502*^9, 
  3.4819416080006037`*^9, 3.4819420881974697`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "BM5", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "BM5", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.479666893782012*^9, 
   3.479666894910797*^9}}],

Cell[BoxData["0.6371543615438662`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.479666954466415*^9, 
  3.4796676281467333`*^9, 3.480244912993281*^9, 3.480692316727179*^9, 
  3.481941608053739*^9, 3.4819420882381277`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "BM5", "]"}], " ", "=", " ", 
  RowBox[{"-", 
   RowBox[{"ND", "[", 
    RowBox[{
     RowBox[{"fz", "[", 
      RowBox[{"BM5", ",", "z"}], "]"}], ",", "z", ",", 
     RowBox[{"zmax", "[", "BM5", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479666215169937*^9, 3.479666222032254*^9}, {
  3.479666896879272*^9, 3.479666899310975*^9}}],

Cell[BoxData["62.73689995259677`"], "Output",
 CellChangeTimes->{3.479666223290411*^9, 3.479666954528255*^9, 
  3.479667628426712*^9, 3.480244913348442*^9, 3.480692317008646*^9, 
  3.481941608362261*^9, 3.481942088635146*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"plot", "[", "BM5", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<z (m)\>\"", ",", "\"\<F (N/A)\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, {
   3.453838538440839*^9, 3.453838572806719*^9}, 3.463844247723119*^9, 
   3.478894943196905*^9, 3.4788950132010527`*^9, {3.478961709433363*^9, 
   3.47896175216029*^9}, {3.478961842569364*^9, 3.478961894377494*^9}, {
   3.4789619830038633`*^9, 3.478961984506156*^9}, {3.4789699280628653`*^9, 
   3.478969982243393*^9}, {3.478970021389124*^9, 3.478970165180615*^9}, {
   3.478970224319232*^9, 3.478970261501657*^9}, {3.4789703108875017`*^9, 
   3.478970348344078*^9}, 3.478970398020482*^9, {3.478970871122594*^9, 
   3.47897087265033*^9}, {3.478971414854863*^9, 3.4789714317583723`*^9}, {
   3.4789723334965277`*^9, 3.4789723911200447`*^9}, {3.4794964690726423`*^9, 
   3.4794964944567127`*^9}, {3.479496975356181*^9, 3.479496976183571*^9}, {
   3.47949787094656*^9, 3.479497874578391*^9}, {3.4794981429899273`*^9, 
   3.479498147044504*^9}, {3.479498193967552*^9, 3.479498236581649*^9}, {
   3.479662116006764*^9, 3.479662117075882*^9}, {3.479666955542605*^9, 
   3.479666963425733*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nc8Vf8fB3ANo5KZFZUVDX1pkKyXSsMsWREZTXvcc+xN4qLQoK3SllQq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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"z (m)\"", TraditionalForm], 
    FormBox["\"F (N/A)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  PlotRange->{{0, 0.013}, {0., 0.6371543536135365}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.478970312655707*^9, 3.478970349956621*^9}, 
   3.4789703994875298`*^9, 3.478971607584939*^9, 3.4789719008193083`*^9, {
   3.478972321794873*^9, 3.4789723915815496`*^9}, 3.478973514856566*^9, 
   3.479486967021886*^9, {3.479496470359309*^9, 3.479496495124946*^9}, 
   3.479496976846184*^9, 3.479497079117694*^9, 3.479497903680291*^9, 
   3.4794981476612797`*^9, 3.4794982377851954`*^9, 3.479663512480014*^9, 
   3.479664582004204*^9, 3.4796657495921383`*^9, 3.479665823576626*^9, 
   3.47966696773402*^9, 3.479667628752988*^9, 3.480245019281752*^9, 
   3.48069231710384*^9, 3.481941608391829*^9, 3.4819420887496758`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["New coil calc for BOSEM (10x10 magnet)", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, 
   3.463844192181329*^9, {3.478894850822432*^9, 3.478894851717502*^9}, {
   3.4788951705281897`*^9, 3.4788951754720497`*^9}}],

Cell["\<\
bigmagnetvalsSA = bosemvals10 = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->0.010,\t\t\t\t(* length of big magnets *)
\t\ta->0.005,\t\t\t\t(* radius of big magnets *)
\t\t(* coil length *)
\t\tcoillen->0.315*0.0254,  (* SA email, 08/14/06 *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.35*0.0254, (* unchanged *)
\t\tcoilrad2->0.65*0.0254, (* SA email, 08/14/06 *)
\t\t(* the number of turns *)
\t\tcoilturns->800, (* SA email, 08/14/06 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
];\
\>", "Input",
 CellChangeTimes->{{3.453837228357688*^9, 3.453837230833909*^9}, {
  3.463844183252262*^9, 3.463844223147016*^9}, {3.478894862544446*^9, 
  3.4788948852377567`*^9}, {3.478894985619047*^9, 3.4788949913587503`*^9}, {
  3.4788950240972023`*^9, 3.478895025494358*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "BO10", "]"}], " ", ":=", " ", "bosemvals10"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, 
   3.463844187524227*^9, 3.463845359588154*^9, {3.47889491108751*^9, 
   3.47889491212925*^9}, {3.4788949966551943`*^9, 3.478894997123682*^9}, 
   3.4788950699694643`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"optdata", "[", "BO10", "]"}], " ", "=", " ", 
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.694858202857608`"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", "\[Rule]", "0.0071958504693359565`"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"Minimize", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"fz", "[", 
           RowBox[{"BO10", ",", "z"}], "]"}]}], ",", " ", 
         RowBox[{"0.006", " ", "<", " ", "z", " ", "<", " ", "0.010"}]}], 
        "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.480244382554545*^9, 3.480244405961742*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"plot", "[", "BO10", "]"}], " ", "=", " ", 
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
     GraphicsBox[{{}, {}, 
       {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nk4VdsbB3BDRQiRWWiiwU9Cg8I31VUpogFxyVhRpCScc/Y5h5BOEyVT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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      PlotRange->{{0, 0.013}, {0., 1.6948581299755139`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"fz", "[", 
        RowBox[{"BO10", ",", "p"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.4794970273251*^9, 3.4794970280748262`*^9}, {3.479497850691868*^9, 
   3.479497851721608*^9}, {3.4802445496159487`*^9, 3.4802445841180058`*^9}, {
   3.4802446656757193`*^9, 3.4802446687524443`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "BO10", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "BO10", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.4796619220112333`*^9, 3.4796619454416037`*^9}, 3.479665671740583*^9}],

Cell[BoxData["0.0071958504693359565`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.479486914888383*^9, 
  3.479659289850292*^9, 3.4796634565750093`*^9, 3.479665742764594*^9, 
  3.479665816570661*^9, 3.480243747684814*^9, 3.480692317253339*^9, 
  3.481566060871256*^9, 3.481941615983523*^9, 3.4819420888840933`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "BO10", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "BO10", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, 
   3.479661922078005*^9, 3.4796619593447857`*^9, 3.479665787682528*^9}],

Cell[BoxData["1.694858202857608`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.479486914934926*^9, 
  3.479659289887826*^9, 3.479663456628942*^9, 3.479665742793458*^9, 
  3.4796658166882772`*^9, 3.480243747711088*^9, 3.480692317295466*^9, 
  3.481566060924111*^9, 3.481941616034875*^9, 3.481942088922996*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"-", 
   RowBox[{"ND", "[", 
    RowBox[{
     RowBox[{"fz", "[", 
      RowBox[{"BO10", ",", "z"}], "]"}], ",", "z", ",", 
     RowBox[{"zmax", "[", "BO10", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9}],

Cell[BoxData["150.76737498024153`"], "Output",
 CellChangeTimes->{
  3.4796611607361183`*^9, 3.479661209333243*^9, {3.4796612702637243`*^9, 
   3.47966130570842*^9}, 3.479661373421825*^9, 3.479661471574224*^9, 
   3.479661860947604*^9, {3.479662726071348*^9, 3.47966274404876*^9}, 
   3.479663512851673*^9, 3.479665743087571*^9, 3.4796658169851303`*^9, 
   3.4802437481454697`*^9, 3.480692317637856*^9, 3.481566061244952*^9, 
   3.4819416163963213`*^9, 3.4819420893486023`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f95plus", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BO10", ",", "z"}], "]"}], "-", 
      RowBox[{"0.95", "*", 
       RowBox[{"fmax", "[", "BO10", "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BO10", "]"}], "+", "0.001"}], ",", 
       RowBox[{"zmax", "[", "BO10", "]"}], ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BO10", "]"}], "+", "0.005"}]}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479658613425561*^9, 3.4796587501410933`*^9}, {
   3.479658790462825*^9, 3.4796587993088913`*^9}, {3.479658852062684*^9, 
   3.479658891629363*^9}, {3.4796589431729183`*^9, 3.479658948798299*^9}, {
   3.479658987032153*^9, 3.47965898990287*^9}, {3.479659310386307*^9, 
   3.4796593125701933`*^9}, {3.479661624172262*^9, 3.479661679901505*^9}, {
   3.479661945541445*^9, 3.4796619594445953`*^9}, {3.4796656734658623`*^9, 
   3.479665674680963*^9}, 3.47966578778349*^9}],

Cell[BoxData["0.008975706429643198`"], "Output",
 CellChangeTimes->{{3.479659290207419*^9, 3.4796593177022877`*^9}, {
   3.479661644377719*^9, 3.4796616514833097`*^9}, 3.479661686065053*^9, 
   3.4796634593803263`*^9, 3.479665745824663*^9, 3.4796658197389708`*^9, 
   3.480243751933235*^9, 3.480692320796873*^9, 3.4815660640155077`*^9, 
   3.4819416198814373`*^9, 3.481942093179961*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f95minus", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BO10", ",", "z"}], "]"}], "-", 
      RowBox[{"0.95", "*", 
       RowBox[{"fmax", "[", "BO10", "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BO10", "]"}], "-", "0.001"}], ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BO10", "]"}], "-", "0.005"}], ",", 
       RowBox[{"zmax", "[", "BO10", "]"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479658613425561*^9, 3.4796587501410933`*^9}, {
   3.479658790462825*^9, 3.4796587993088913`*^9}, {3.479658852062684*^9, 
   3.479658891629363*^9}, {3.4796589431729183`*^9, 3.479658948798299*^9}, {
   3.479658997678957*^9, 3.4796590027188377`*^9}, {3.479659318794853*^9, 
   3.479659344898431*^9}, {3.479661657421668*^9, 3.4796616780054293`*^9}, {
   3.479661945775414*^9, 3.479661959545474*^9}, {3.479665675209929*^9, 
   3.479665676278386*^9}, 3.4796657878831253`*^9}],

Cell[BoxData["0.005594057700839214`"], "Output",
 CellChangeTimes->{
  3.479659290545846*^9, {3.479659322545879*^9, 3.479659348979048*^9}, {
   3.4796616661527233`*^9, 3.479661689555737*^9}, 3.479663462870864*^9, 
   3.479665749329587*^9, 3.479665823257647*^9, 3.480243756605932*^9, 
   3.480692324819867*^9, 3.481566067504561*^9, 3.481941624492373*^9, 
   3.481942097749235*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Measurement", "Subsubsection",
 CellChangeTimes->{{3.478970601031336*^9, 3.478970602486655*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v10", " ", "=", " ", 
  RowBox[{"Recurse", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"zflange", " ", "->", " ", 
      RowBox[{"0.1", "*", "0.0254"}]}], ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"end", " ", "flange", " ", "thickness"}], ",", " ", 
       RowBox[{"D060106", "-", "C"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"l", " ", "->", " ", "0.010"}], ",", "\[IndentingNewLine]", 
     RowBox[{"zplug", " ", "->", " ", "0.001"}], ",", "\[IndentingNewLine]", 
     RowBox[{"zcoil", " ", "->", " ", 
      RowBox[{"0.315", "*", "0.0254"}]}], ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"coil", " ", "length"}], ",", " ", 
       RowBox[{"D060106", "-", "C"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"zc", " ", "->", " ", 
      RowBox[{
       RowBox[{"l", "/", "2"}], "+", "zplug", "+", "zflange", "+", 
       RowBox[{"zcoil", "/", "2"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"newportcal", " ", "->", " ", "0.5"}]}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{
     "micrometer", " ", "to", " ", "stage", " ", "factor", " ", "for", " ", 
      "Newport", " ", "NVM80"}], " ", "*)"}], "\[IndentingNewLine]", "}"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478364871938177*^9, 3.4783650430215597`*^9}, {
   3.478365123922604*^9, 3.478365126702361*^9}, {3.478365254617469*^9, 
   3.4783652660805397`*^9}, {3.4783655084186296`*^9, 
   3.4783655130572557`*^9}, {3.47836555422621*^9, 3.478365578866078*^9}, 
   3.478366553883871*^9, 3.4783667391579103`*^9, {3.479485983949397*^9, 
   3.4794860302373734`*^9}, {3.4794860941303663`*^9, 3.479486095079904*^9}, 
   3.4794861957899227`*^9, {3.479502242049817*^9, 3.4795022420685263`*^9}, {
   3.47965572449089*^9, 3.479655724556625*^9}, {3.479655785531518*^9, 
   3.479655785532816*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"zflange", "\[Rule]", "0.00254`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.01`"}], ",", 
   RowBox[{"zplug", "\[Rule]", "0.001`"}], ",", 
   RowBox[{"zcoil", "\[Rule]", "0.008001`"}], ",", 
   RowBox[{"zc", "\[Rule]", "0.0125405`"}], ",", 
   RowBox[{"newportcal", "\[Rule]", "0.5`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.4794861147697887`*^9, 3.479486119482292*^9}, 
   3.479661794400094*^9, 3.4796627436715107`*^9, 3.47966574239032*^9, 
   3.4802437567011843`*^9, 3.4806923249227753`*^9, 3.4815660675895853`*^9, 
   3.4819416246164713`*^9, 3.4819420978508997`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"m10", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "0", ",", " ", "0.5", ",", " ", "1", ",", " ", "1.5", ",", " ", "2", ",", 
     " ", "2.5", ",", " ", "3", ",", " ", "3.5", ",", " ", "4", ",", " ", 
     "4.5", ",", " ", "\[IndentingNewLine]", "5", ",", " ", "5.5", ",", " ", 
     "6", ",", " ", "6.5", ",", " ", "7", ",", " ", "7.5", ",", " ", "8", ",",
      " ", "8.5", ",", " ", "9", ",", " ", "9.5", ",", " ", 
     "\[IndentingNewLine]", "10", ",", " ", "10.5", ",", " ", "11", ",", " ", 
     "11.5", ",", " ", "12", ",", " ", "12.5", ",", " ", "13", ",", " ", 
     "13.5", ",", " ", "14", ",", " ", "14.5", ",", " ", 
     "\[IndentingNewLine]", "15", ",", " ", "15.5", ",", " ", "16", ",", " ", 
     "16.5", ",", " ", "17", ",", " ", "17.5", ",", " ", "18", ",", " ", 
     "18.5", ",", " ", "19", ",", " ", "19.5", ",", " ", 
     "\[IndentingNewLine]", "20", ",", " ", "20.5", ",", " ", "21", ",", " ", 
     "21.5", ",", " ", "22", ",", " ", "22.5", ",", " ", "21.10", ",", " ", 
     "21.03"}], "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.478359123403325*^9, 3.478359312201968*^9}, {
   3.478359382197403*^9, 3.478359482378661*^9}, 3.4783602880061617`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f10", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "21.6", ",", " ", "24", ",", " ", "26.4", ",", " ", "28.6", ",", " ", 
     "30.7", ",", " ", "32.7", ",", " ", "34.7", ",", " ", "36.4", ",", " ", 
     "38.3", ",", " ", "39.7", ",", " ", "\[IndentingNewLine]", "41", ",", 
     " ", "42.6", ",", " ", "43.8", ",", " ", "44.8", ",", " ", "45.7", ",", 
     " ", "46.4", ",", " ", "47", ",", " ", "47.6", ",", " ", "48", ",", " ", 
     "48.2", ",", "\[IndentingNewLine]", "48.4", ",", " ", "48.8", ",", " ", 
     "48.7", ",", " ", "48.6", ",", " ", "48.3", ",", " ", "48.0", ",", " ", 
     "47.4", ",", " ", "47.1", ",", " ", "46.2", ",", " ", "45.6", ",", 
     "\[IndentingNewLine]", "44.8", ",", " ", "44.0", ",", " ", "43.4", ",", 
     " ", "42.5", ",", " ", "41.6", ",", " ", "40.6", ",", " ", "39.6", ",", 
     " ", "38.7", ",", " ", "37.8", ",", " ", "36.7", ",", 
     "\[IndentingNewLine]", "35.8", ",", " ", "34.9", ",", " ", "34", ",", 
     " ", "33.1", ",", " ", "32.1", ",", " ", "31.3", ",", " ", "33.3", ",", 
     " ", "33.4"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.478358656639378*^9, 3.478358736957609*^9}, {
   3.478358785279069*^9, 3.478358785557148*^9}, {3.47835979499054*^9, 
   3.478360057375266*^9}, {3.478360132331086*^9, 3.478360132808681*^9}, {
   3.478360292284709*^9, 3.478360320802071*^9}, 3.478360369604032*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"c10", " ", "=", " ", 
   RowBox[{
    RowBox[{"zc", "+", 
     RowBox[{"newportcal", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m10", "-", 
         RowBox[{"m10", "[", 
          RowBox[{"[", 
           RowBox[{"-", "1"}], "]"}], "]"}]}], ")"}], "/", "1000"}]}]}], "/.",
     "v10"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.47837088802363*^9, 3.478370914162881*^9}, {
  3.478961618977281*^9, 3.478961625407113*^9}, {3.479486145012785*^9, 
  3.479486146227991*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"m10b", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "25.", ",", " ", "24.5", ",", " ", "24.", ",", " ", "23.5", ",", " ", 
     "23.", ",", " ", "22.5", ",", " ", "22.", ",", " ", "21.5", ",", " ", 
     "21.", ",", " ", "20.5", ",", " ", "\[IndentingNewLine]", "20.", ",", 
     " ", "19.5", ",", " ", "19.", ",", " ", "18.5", ",", " ", "18.", ",", 
     " ", "17.5", ",", " ", "17.", ",", " ", "16.5", ",", " ", "16.", ",", 
     " ", "15.5", ",", " ", "\[IndentingNewLine]", "15.", ",", " ", "14.5", 
     ",", " ", "14.", ",", " ", "13.5", ",", " ", "13.", ",", " ", "12.5", 
     ",", " ", "12.", ",", " ", "11.5", ",", " ", "11.", ",", " ", "10.5", 
     ",", " ", "\[IndentingNewLine]", "10.", ",", " ", "9.5", ",", " ", "9.", 
     ",", " ", "8.5", ",", " ", "8.", ",", " ", "7.5", ",", " ", "7.", ",", 
     " ", "6.5", ",", " ", "6.", ",", " ", "5.5", ",", " ", 
     "\[IndentingNewLine]", "5.", ",", " ", "4.5", ",", " ", "4.", ",", " ", 
     "3.5", ",", " ", "3.", ",", " ", "2.5", ",", " ", "2.", ",", " ", "1.5", 
     ",", " ", "1.", ",", " ", "0.5", ",", " ", "\[IndentingNewLine]", "0.", 
     ",", " ", 
     RowBox[{"-", "0.42"}]}], "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.480242266026979*^9, 3.4802422811926517`*^9}, {
  3.480242551485073*^9, 3.480242638696825*^9}, {3.480243603406623*^9, 
  3.480243604629949*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f10b", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "33", ",", " ", "33.9", ",", " ", "34.8", ",", " ", "35.6", ",", " ", 
     "36.4", ",", " ", "37.3", ",", " ", "38.5", ",", " ", "39.3", ",", " ", 
     "40.2", ",", " ", "40.9", ",", "\[IndentingNewLine]", "41.7", ",", " ", 
     "42.6", ",", " ", "43.3", ",", " ", "43.9", ",", " ", "44.5", ",", " ", 
     "45.2", ",", " ", "45.5", ",", " ", "46", ",", " ", "46.3", ",", " ", 
     "46.6", ",", "\[IndentingNewLine]", "46.7", ",", " ", "46.7", ",", " ", 
     "46.7", ",", " ", "46.7", ",", " ", "46.4", ",", " ", "45.9", ",", " ", 
     "45.4", ",", " ", "44.7", ",", " ", "44.1", ",", " ", "43.1", ",", 
     "\[IndentingNewLine]", "42.1", ",", " ", "41.0", ",", " ", "39.7", ",", 
     " ", "38.4", ",", " ", "37.0", ",", " ", "35.3", ",", " ", "33.5", ",", 
     " ", "31.6", ",", " ", "29.7", ",", " ", "27.6", ",", 
     "\[IndentingNewLine]", "25.6", ",", " ", "23.3", ",", " ", "21", ",", 
     " ", "18.5", ",", " ", "16.1", ",", " ", "13.5", ",", " ", "10.9", ",", 
     " ", "8.35", ",", " ", "5.70", ",", " ", "2.97", ",", 
     "\[IndentingNewLine]", "0.376", ",", " ", "1.90"}], " ", 
    "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.480242672165991*^9, 3.480242777357607*^9}, {
  3.4802428393374243`*^9, 3.480242994903599*^9}, {3.4802430986494913`*^9, 
  3.4802431295923853`*^9}, {3.480243226913352*^9, 3.480243571963694*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"c10b", " ", "=", " ", 
   RowBox[{
    RowBox[{"zc", "+", 
     RowBox[{"newportcal", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m10b", "-", 
         RowBox[{"m10b", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", "1000"}]}]}], "/.", 
    "v10"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.47837088802363*^9, 3.478370914162881*^9}, {
   3.478961618977281*^9, 3.478961625407113*^9}, {3.479486145012785*^9, 
   3.479486146227991*^9}, {3.480243648203948*^9, 3.4802436546744833`*^9}, 
   3.4802439178688*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1000", "*", "c10b"}], ",", "f10b"}], "}"}], "]"}], ",", 
   RowBox[{"AxesOrigin", "->", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.478358869240918*^9, 3.478358894149914*^9}, {
   3.478358970183876*^9, 3.4783590158067007`*^9}, {3.47836015386373*^9, 
   3.478360163119385*^9}, {3.478366673756214*^9, 3.478366679969379*^9}, {
   3.478367462673428*^9, 3.4783674799853067`*^9}, {3.478368631699589*^9, 
   3.478368685400792*^9}, {3.4783687314761667`*^9, 3.478368733441554*^9}, {
   3.4783687696995564`*^9, 3.478368770875265*^9}, {3.478370370616754*^9, 
   3.478370372904202*^9}, {3.478370502073501*^9, 3.478370514529298*^9}, 
   3.478370885346918*^9, {3.478370917867898*^9, 3.4783709191468763`*^9}, {
   3.478961631541224*^9, 3.4789616328231297`*^9}, {3.480243885079197*^9, 
   3.480243886827784*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJxdk8srRHEUx28S0jR5XMN4zmDGTFIyJEm/M2bmzgIppJSVoryysLHS/AFk
ozTKziOSBbFSRKywGBaGhWQhK6Yh5BHzO9+fhVO326fP+Z1zOvd37X1jHf1J
mqbV/j6J9/X75NCu7iYtESEiybMu8iQiDtZdNCDDC19BpyeJ8NKV9BWc72mG
d3L+Mlh3cn3ywTvgwbqD5sO/YfXDl3O9cbBezj6qfBn3bw3Al6EeeLYU8ytf
iv4GvJ3rhcG6nf2+8jZmLQhv4/rOIO3Evy4m3CXor7iY6/UEaVty0R+zL/zH
Bf84H/tT562Y3wDnMW8ZyM/FecUWnsek8nOYpwLwOrzibHxvPzgL+/XhfCbm
UZyB/GYauv9YjXWYsW8vDUo2YX9Eo5LTsV9BI5LTMH8TOAW+kYYlJ4MbwEnY
bz36afgedXR+9tp5t/QpeJ4aupL8Jvj+VFNU8jN7rZIuJT8Jvq8O2lh4XDlu
eRA8j43WJd/CW6ir8aZ9ei4iDl9cvTMHqRSSF3xRrMUibX0Zl8JI7jZXbR7t
8f/wLX4AeiSFBA==
    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{
  3.478358895979022*^9, 3.478358972250873*^9, {3.478359003617921*^9, 
   3.478359016368936*^9}, {3.47836013995588*^9, 3.478360163674849*^9}, 
   3.478360374248694*^9, 3.478366680674487*^9, 3.478367480647264*^9, {
   3.478368632443274*^9, 3.478368686420216*^9}, 3.478368734382247*^9, 
   3.478368772182708*^9, 3.47837037368084*^9, {3.478370502759603*^9, 
   3.478370515076358*^9}, 3.478370922682131*^9, 3.478894392703998*^9, 
   3.4789609320542917`*^9, 3.478961633495669*^9, 3.479485745361719*^9, {
   3.479486132534732*^9, 3.4794861523034983`*^9}, 3.479661794640168*^9, 
   3.479662743820785*^9, 3.479665742592085*^9, 3.480243756892487*^9, 
   3.4802438881018877`*^9, 3.480243922252112*^9, 3.480692325124424*^9, 
   3.481566067790287*^9, 3.481941625063833*^9, 3.481942098115423*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"quadsect", "[", "BO10", "]"}], " ", "=", " ", 
   RowBox[{"Take", "[", 
    RowBox[{
     RowBox[{"Sort", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"c10b", ",", "f10b"}], "}"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#1", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", 
         RowBox[{"#2", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"23", ",", 
       RowBox[{"-", "15"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.479492900596332*^9, 3.479493003075787*^9}, {
   3.479493311477222*^9, 3.479493315988943*^9}, {3.4794935683920727`*^9, 
   3.4794935803839912`*^9}, {3.479493647064962*^9, 3.4794936781853*^9}, {
   3.479494587120398*^9, 3.479494587799402*^9}, 3.479495122108719*^9, {
   3.479496268693829*^9, 3.4794962786689043`*^9}, {3.479496348223323*^9, 
   3.4794963960461197`*^9}, {3.479498099636911*^9, 3.479498116836277*^9}, {
   3.479661771654023*^9, 3.4796617820129557`*^9}, {3.4802439413724613`*^9, 
   3.480243944481743*^9}, {3.480243980865246*^9, 3.4802439981026154`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"quadsect", "[", "BO10", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.479492922070776*^9, 3.479492925832822*^9}, {
   3.47949628323759*^9, 3.479496283675993*^9}, 3.479661799309276*^9}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], 
   PointBox[{{0.005290499999999999, 43.1}, {0.005540499999999999, 44.1}, {
    0.0057905, 44.7}, {0.006040499999999999, 45.4}, {0.006290499999999999, 
    45.9}, {0.0065404999999999994`, 46.4}, {0.0067905, 46.7}, {0.0070405, 
    46.7}, {0.007290499999999999, 46.7}, {0.0075404999999999995`, 46.7}, {
    0.0077905, 46.6}, {0.008040499999999999, 46.3}, {0.0082905, 46.}, {
    0.0085405, 45.5}, {0.0087905, 45.2}, {0.0090405, 44.5}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{
  3.47949292648037*^9, {3.4794929901025677`*^9, 3.479493006913755*^9}, 
   3.479493322040373*^9, {3.479493571055421*^9, 3.479493582720769*^9}, {
   3.479493654111162*^9, 3.479493680849517*^9}, 3.479494594442368*^9, 
   3.4794951275012083`*^9, 3.4794962841775846`*^9, {3.479496352894401*^9, 
   3.4794963992533207`*^9}, {3.4794981044621353`*^9, 3.47949812000502*^9}, 
   3.479661800865757*^9, 3.4796627438875427`*^9, 3.47966574265806*^9, 
   3.480243756913067*^9, 3.480243949523509*^9, {3.480243993159051*^9, 
   3.48024400283206*^9}, 3.480692325191889*^9, 3.481566067857037*^9, 
   3.481941625118208*^9, 3.481942098169249*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"q", "[", 
   RowBox[{"BO10", ",", "z_"}], "]"}], " ", "=", " ", 
  RowBox[{"Fit", "[", 
   RowBox[{
    RowBox[{"quadsect", "[", "BO10", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "z", ",", 
      RowBox[{"z", "^", "2"}]}], "}"}], ",", "z"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.479492821084407*^9, 3.479492906857025*^9}, {
   3.479493026130746*^9, 3.479493088769916*^9}, {3.479496292861574*^9, 
   3.479496298886504*^9}, {3.4796617492454433`*^9, 3.479661752316023*^9}, 
   3.4796618065898314`*^9}],

Cell[BoxData[
 RowBox[{"1.5052714249997052`", "\[InvisibleSpace]", "+", 
  RowBox[{"12320.257983193318`", " ", "z"}], "-", 
  RowBox[{"837815.1260504235`", " ", 
   SuperscriptBox["z", "2"]}]}]], "Output",
 CellChangeTimes->{{3.479493065534417*^9, 3.479493090921401*^9}, 
   3.479493347575324*^9, 3.479493687032943*^9, 3.4794945945082073`*^9, 
   3.479495127601207*^9, 3.4794962995907373`*^9, {3.479496356170768*^9, 
   3.4794964020264187`*^9}, 3.479661807352735*^9, 3.479662743921276*^9, 
   3.479665742692679*^9, 3.480243756989594*^9, 3.480244010141424*^9, 
   3.480692325243474*^9, 3.481566067893443*^9, 3.481941625191751*^9, 
   3.4819420981852303`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{"quadsect", "[", "BO10", "]"}], "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"q", "[", 
      RowBox[{"BO10", ",", "z"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "0.0055", ",", "0.0093"}], "}"}]}], "]"}], ",", 
   RowBox[{"PlotRange", "->", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.479493098474358*^9, 3.4794931473471107`*^9}, {
   3.4794950541082687`*^9, 3.479495059418387*^9}, 3.479495140140613*^9, {
   3.479496302750866*^9, 3.479496325477083*^9}, 3.479496410959276*^9, 
   3.4794980716129704`*^9, {3.479498110109133*^9, 3.479498134380343*^9}, {
   3.47966180953386*^9, 3.479661832340538*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {Hue[0.67, 0.6, 0.6], 
    PointBox[{{0.005290499999999999, 43.1}, {0.005540499999999999, 44.1}, {
     0.0057905, 44.7}, {0.006040499999999999, 45.4}, {0.006290499999999999, 
     45.9}, {0.0065404999999999994`, 46.4}, {0.0067905, 46.7}, {0.0070405, 
     46.7}, {0.007290499999999999, 46.7}, {0.0075404999999999995`, 46.7}, {
     0.0077905, 46.6}, {0.008040499999999999, 46.3}, {0.0082905, 46.}, {
     0.0085405, 45.5}, {0.0087905, 45.2}, {0.0090405, 44.5}}]}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k8VHsUAHBSlrSXJcpDCEWh8CLnhplJSYSEKER5ZYlnbHN/w0jZiyRL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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->All,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{
  3.479493147789712*^9, 3.479493348745586*^9, 3.479493687869093*^9, 
   3.479494594544231*^9, 3.4794950600870647`*^9, {3.479495127635968*^9, 
   3.4794951412551003`*^9}, {3.479496311016521*^9, 3.479496326374604*^9}, {
   3.479496357540121*^9, 3.479496411535761*^9}, 3.479498073597056*^9, {
   3.479498111163803*^9, 3.479498134994309*^9}, {3.4796618101860933`*^9, 
   3.479661833787763*^9}, 3.479662743973064*^9, 3.479665742731904*^9, 
   3.4802437570207*^9, 3.480244013149205*^9, 3.480692325283217*^9, 
   3.481566067931078*^9, 3.4819416252399197`*^9, 3.481942098241775*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmaxq", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"q", "[", 
        RowBox[{"BO10", ",", "z"}], "]"}], ",", "z"}], "]"}]}], "/", 
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{"q", "[", 
       RowBox[{"BO10", ",", "z"}], "]"}], ",", 
      RowBox[{"z", "^", "2"}]}], "]"}]}], "/", "2"}]}]], "Input",
 CellChangeTimes->{{3.479495438249634*^9, 3.479495505318678*^9}, 
   3.479662502748355*^9, 3.4796629041886263`*^9, 3.479664469475191*^9, {
   3.479665540402864*^9, 3.479665540432529*^9}, 3.479665679958331*^9, {
   3.480252658965609*^9, 3.4802526608978167`*^9}}],

Cell[BoxData["0.007352611334002001`"], "Output",
 CellChangeTimes->{{3.479495497456901*^9, 3.479495505729022*^9}, 
   3.479664646330089*^9, 3.479665767660248*^9, 3.4796658003302927`*^9, 
   3.479666123140691*^9, 3.480085429491647*^9, 3.480244564434903*^9, 
   3.480245921975265*^9, 3.480252685630768*^9, 3.4806923253165283`*^9, 
   3.481941625292397*^9, 3.481942098249529*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmaxq", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"q", "[", 
   RowBox[{"BO10", ",", 
    RowBox[{"zmaxq", "[", "BO10", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4796645166114473`*^9, 3.4796645680107403`*^9}, {
   3.479664629540166*^9, 3.4796646354272118`*^9}, 3.479665680445608*^9, 
   3.479665788251362*^9, {3.480252661732663*^9, 3.480252662768613*^9}}],

Cell[BoxData["46.798305667527615`"], "Output",
 CellChangeTimes->{3.479664568867193*^9, 3.479664646359799*^9, 
  3.479665585669737*^9, 3.479665767693388*^9, 3.479665800365254*^9, 
  3.479666123176936*^9, 3.48008543183556*^9, 3.480244564491827*^9, 
  3.480245922030847*^9, 3.480252685747806*^9, 3.4806923253494253`*^9, 
  3.481941625327002*^9, 3.481942098307748*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"delta", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"zmaxq", "[", "BO10", "]"}], " ", "-", " ", 
   RowBox[{"zmax", "[", "BO10", "]"}], " "}]}]], "Input",
 CellChangeTimes->{{3.479495523610161*^9, 3.479495542381401*^9}, 
   3.479661946209796*^9, 3.479662081271207*^9, 3.47966250284426*^9, 
   3.47966290430508*^9, 3.479664469476417*^9, {3.479665683454405*^9, 
   3.479665683520638*^9}, {3.480252663458889*^9, 3.480252664767067*^9}}],

Cell[BoxData["0.0001567608646660442`"], "Output",
 CellChangeTimes->{3.4794955436804543`*^9, 3.479665380340073*^9, 
  3.479665767759824*^9, 3.479665800431348*^9, 3.4796661232447157`*^9, 
  3.4800854342417307`*^9, 3.4802445645293713`*^9, 3.480245953636918*^9, 
  3.4802526858259706`*^9, 3.480692325383745*^9, 3.4819416253693733`*^9, 
  3.481942098341453*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Scale factor to make measured and theoretical curves have same maximum\
\>", "Text",
 CellChangeTimes->{{3.478970887912784*^9, 3.478970908928837*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"scale", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"fmax", "[", "BO10", "]"}], "/", 
   RowBox[{"fmaxq", "[", "BO10", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970696648231*^9, 3.478970705072441*^9}, {
   3.478970839616865*^9, 3.478970857497159*^9}, 3.4789715324564857`*^9, {
   3.478971784562731*^9, 3.4789717872495337`*^9}, 3.478971846731222*^9, {
   3.4789723755682993`*^9, 3.478972380734989*^9}, {3.4789735142646723`*^9, 
   3.4789735163909893`*^9}, 3.479661959846012*^9, 3.479662130234865*^9, {
   3.479665563524087*^9, 3.479665591276129*^9}, {3.479665788451865*^9, 
   3.479665788518486*^9}, {3.480252675294587*^9, 3.4802526771361427`*^9}}],

Cell[BoxData["0.03621623002547367`"], "Output",
 CellChangeTimes->{
  3.478971485608411*^9, 3.478971533659111*^9, 3.478971787849442*^9, {
   3.478971841091794*^9, 3.4789718473084917`*^9}, 3.478972382639682*^9, 
   3.4789745781001587`*^9, 3.478974629064003*^9, 3.4794913230668173`*^9, 
   3.4796653804411373`*^9, 3.479665592037429*^9, 3.4796657678267307`*^9, 
   3.47966580051572*^9, 3.479666123310278*^9, 3.480085442306896*^9, 
   3.480085474403487*^9, 3.480244564572826*^9, 3.480245967181128*^9, 
   3.480252685882967*^9, 3.4806923254154778`*^9, 3.481941625424059*^9, 
   3.4819420983918962`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"plot", "[", "BO10", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"c10b", ",", 
        RowBox[{
         RowBox[{"scale", "[", "BO10", "]"}], "*", "f10b"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Blue", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"scale", "[", "BO10", "]"}], "*", 
      RowBox[{"q", "[", 
       RowBox[{"BO10", ",", "z"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "0.0055", ",", "0.0093"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Red", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<z (m)\>\"", ",", "\"\<F (N/A)\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, {
   3.453838538440839*^9, 3.453838572806719*^9}, 3.463844247723119*^9, 
   3.478894943196905*^9, 3.4788950132010527`*^9, {3.478961709433363*^9, 
   3.47896175216029*^9}, {3.478961842569364*^9, 3.478961894377494*^9}, {
   3.4789619830038633`*^9, 3.478961984506156*^9}, {3.4789699280628653`*^9, 
   3.478969982243393*^9}, {3.478970021389124*^9, 3.478970165180615*^9}, {
   3.478970224319232*^9, 3.478970261501657*^9}, {3.4789703108875017`*^9, 
   3.478970348344078*^9}, 3.478970398020482*^9, {3.478970871122594*^9, 
   3.47897087265033*^9}, {3.478971414854863*^9, 3.4789714317583723`*^9}, {
   3.4789723334965277`*^9, 3.4789723911200447`*^9}, {3.478973525233735*^9, 
   3.47897352833882*^9}, {3.479495227181163*^9, 3.4794952662789087`*^9}, {
   3.4794954131043873`*^9, 3.4794954161349077`*^9}, {3.479497883443406*^9, 
   3.479497887306903*^9}, {3.4794980354692507`*^9, 3.479498036795588*^9}, 
   3.4794982488155937`*^9, {3.479662131489229*^9, 3.479662133377276*^9}, 
   3.479665540471899*^9, {3.4802459792714577`*^9, 3.480245981573744*^9}, {
   3.4802525542284737`*^9, 3.4802525884311867`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nk4VdsbB3BDRQiRWWiiwU9Cg8I31VUpogFxyVhRpCScc/Y5h5BOEyVT
JfN0JVGGuqZIA6WBqBRCqajMzj7it+4f+9nP53nW2nsN73rftcD92G4vESEh
oWny/PeukOu8YLNhyDSB6Vr00ppl5kFFVjiXvzR7MCOv59L4fqS79VoYl3ea
LeHUe9qNe6P2TaykTvlvs/d2o+fXjIfgzfn+gfnlQpj0SzVXHT8LJ2/lAyrl
snB/1ZD8fiwRN+0LlJTKtdC+/GzHyGguaqz5wwrl+miOcC32GSpHmWPn3wt9
zXGzSP2OF/8ZZF6IZQ52b4daB0vm7tgb1Aa/6NdUtoW+qemtV+vfo+h1SLhV
wj44jH2puBfQiRSpx9LxDfuhMrZp1Vt2N2qkAxW/Orgg0cc/v6H4C0JGdC2Z
h91wN9UlsbTyG2Js/UXmsj1wMSFHdB+jH7Vynvzcai/McWl90WTzC6O1Od9e
th9CdUZrlcWP31jZJX7V/qc3jjjZ30hXGkKYuwqnS/coIoWW/XvGchgtbxju
/C1+4E+tldhtN4KUvRabJP7yR4Vxh/gtj1E4jrYXbnU/js+iIuOedmOYJ62u
vvPoCSy2a4gRXjKODw7F2q/PB2AFLc/f+mscaWrD/9NMOomqkqDwwPgJBMqe
ax6oCITPS3X7lWv5sHpQ6HC0/RTqe+cfsK3go2242C+x8xQMw73i1Kr48NQt
Da/vOQXbvefje6r5YNyoKNQaOAXfqXvjJ+r4yOE8E2/5cwoi5X36oQ18iGzp
KTPVDEKmU8sVj3d8lDUqqci4B6EpYcOZjSN8LP7EfnfnaxBuhgqeuWjTCA6a
Hl3XH4Q5D9VFJ3VoNMhy5ap/B+H03fw38ctonNgcuuMFPwitE5RZgy6N6pzT
Fd8lg3F+9j3TBYY0nAOiUhfpB2N+lzb/LGjEiV/2vhocjGqdeq1d9jS+p8pF
qlPB0DFXSapyoGG64UpaemgwWtM33tZzpNHjG/vhDi8YR7uO3xJ3pmHwJs7q
xXXSX2xo8h93Gk03rq0SqwmGxBJlkUJfGuKGmfzg2SH4OP43qyCMhomfskHx
nBDEHy03+niaxrHccz4Dc0OQMcUvl4ig8VbzxAc31RBITsaucD9DI0MKFZYr
QqCetaFA5DwN8y9tXHWrEIgzs7ZJXKXBSJQSr44OQd6BoHijLBoFzZyNdGwI
dEp0F5pm0+iSGQ42SgyB720raksOjW2R777lpJLv5Vtl7sqjoRiQ1RBTFIJd
O6Kr7AtoFO/ceMmjOQT169PXriyh0T8doCimzADX5Yn0ZB2NiePO0rrqDCRf
WHL8/SMaoj0Ws2y1GJhtzyouraeh+kRlLGkpA57dMW1+T2hsj65q0TNmYGos
PbupgUaWluRVO0cGOO2HAp1e03A1T5PPus6ARdzdW9c/0ThafE6yIYWBtyLU
TvsOGkFLAkV/ZzCQkr6xSbaTxsXZ24aNbzEgZoxQbheNilcDr59XMBAWUJe0
u4f839348ugnBrL25NTUfKPRHPZS9q8FTJQ/W/+ycZhGzr61MnVLmKj9KDfp
P0KDtTR5zublTIQH1H+SH6Wx6MURCXNDJupNTj7dN0biSUVshulfTMRs4a97
NkFjbqHpuJE3E47tVG7gHxIPYRmjxb5MOKx86jBzikbZPskRgxNMCOw+1Fwh
dhW0/dZnMqGZpPAwf5pGocXJ77oXmDDnL+Q2CQtg/THv4+I7TCgdFJvfNlOA
hYVz29Pvkf7Zxzh7ZgkwFhb8fuF9Jmw9c5OfEycvtWjVqmXCMNZuXqWYAAMB
XS/VW5iQqpT5fGm2AOcllOvm8ZkwyOgzGJcSwPUj++GVP0xY3uwKcZkjgFFh
b7WcCAuVFq+5dcQf9hVXyEqycG76UNN5aQGWp1qXSs1noXtYPFBaVoCnayPy
Zpiz4Cx7Q+atnACs/E91a/5iYU9S4JdF8gLoL1jXcXg7C8/bfHP9iRMkfsg/
t2XBctJ7ZNY8AQ5/tKGuurOgZ2qVrq0ggPruvPjHB1mY+6Sz4wjxy3rRIr4P
C5m5A7MLidcWlnxxDmCB/2CJzmpFAWadVrfRDmdhv9dXnoGSAPfHA30colho
faGx7hix39GmcN55Ft416DXnEb/dF1b+M5aFGr2EdxrKAmQu7VtYmslCV7eH
Bk3scMPc9FsuCw0Rdlv1VASQkrtmr1bAgsIynqsb8UmB1XlOCQspqebOdcRb
XhSPbn3MglrTs9uUqgATm+bIMhpY8DEqPZBLnF96cHl+EwtOfruEm4nlU1UO
yLaxMPlgnaq2mgD1CgEhm9pZyJf9GmNFzOA1XjnZycL1mAlBAPHnAM6Ttj4W
3Gz/ZFcQx/W1fZYYYMFEZ833TmJLZ4M/JoMs9IWnaoqqC1Bk0bsqlc+C7ZII
zy3EoSo7rnlLUKgUj3O6T2x0MePeNWkKafc/b2gh7hOZanouR8GbLpX9RWzT
XzjDQI3Cc51XCZrzBZjhJqHpqUnBcUblnjXEZS0exnGLKCitK5jcQaxVpehH
r6DQ+MVw5UniZkP/KF19CkUmS8sjiaNynqa5GFGIvmhinEBsMn9RRfQ60j/m
1O0c4l8xrNaHJhQepcmrlxGnzXo7OLKRwmKd3Zx6YjvmSimdvygSV47v3hBL
/I7S3r+dgtsi5+WdxJWenzees6JwKPrsiR/E69eXuyntpuCa1B06RlwiEx2W
bkdBpizHUUhDAIPeg+krnch46OlJceKC+6Z1Dw5Q6Ktd7y1LvDx6Xu9WTwoe
r87fVCTO8voxs/kwhZ1fDVPUiBdueKjt6kvhTK/vEU3iZNnErf3HKTg9DhZe
SKz65djh4FMUfNMvuy8ijntgcXYGk4JJPv/if5aLmZ8XzaGwYmV/5H/tLx4c
eaYeTmHd1RxLLWIJk4YfOVEUrE/4v1cnjpybJrX6AoUAC9YaZWKRr8H/q4mh
IKyw6IAcMfvfXdZWcRSsOoP2ShLTMdrH3iVR8Ix+pShKfOrQn0teNymsamJk
8cl6DJk0Fw6mk/1pTBD9Rewn988rKoesb0OQXjfx96+hQ7NvUfBbZq/zlvhg
hYN83B3S/nXYz8fELodn7Su4T+bvktGXTfze9GPg+ioKg1UTanH/7Zf83bj6
Wgr+uh4ap4mtK93aPjVSMOLZXd5P/OzKOr7PKwpNj/VmbCa28JZRHW+hkH3c
wmIFsdm8CieZDgrat3RNJkg83v92hXWtmwLvQsTvduI1VT43dPooqCzVOlVN
rOej3IFBCqJCGmOnifPwa7phlMJZY9FBD2JthXotB5qCc3xt7iZijeoAd39R
NtgLxx9MkvOTdNXy9KQYG9Nv2cJtxIpHFmRESbGRvNlatYhYWrGpN0WBDaZq
R7078dSR5d6vdNh4NqtVroScZ4a5MM9Zlw3l1wP8M8Rjim153/TZEFvpUeJA
/LMmol94PRtaPa6FYyRffFLqOmawkw214xqFi4mrauNPXfFnQ2rDXpXtJD/N
e9ljJxHIRoSmadZs4sPtq9aGhrDRut9V6SnJd7KjDeN+YWz83WWevYXYVVso
xDKWDeOxtHA9kh+Fzh5mCpexEVlU4Pec5OO9V+85Bf/LRthcB2cWcU6qiMmv
ajZyUrYZLSe2uX99sv0pm9ShWdfD5gqQ+uMlVfaBjSlXQ0dtkt83WRtzj02z
obHUp8GY1IM4x0jXL6IcLDG67txK6sf3g282OotzIMs1aw8gvszxFd4xlwNT
sd6buZICdBemhmkv4mDGEaFt4hIChMtLRHy04CA1T8n+MqlXj9ren91xkYMT
YZm7PpB6SEeqRgZe5sAvarr7ALHeasewm3EcxD6eG91N6mlczDvGcDIHXrvN
9fsmaRy0bDty7TYHvAKp+C80jVn/tlj9eMlBU46tfhmpzxm7+qIezeZi8brg
JYUDNCq1xc+8l+RC/MViLWXitj86Eb/mcFHv+tCY009DKv9QqIocFwaXHzyz
/EHjpPjXEF9VLmRs5Xxa+2hsqen1UVjBRY3W6tf13TR6Dbp3eu3k4r6BV990
Gw3P++bW2dZc6JtNT5oQfzZP2fXNhotzBkVzQ1ppfLJx3u27j4u08RsmP1vI
fc6v1T7QhYsbO/RSG8l950leg3uEPxcLynP69jfSyFt4Nzgzlot5cs2xZZU0
Oa8RGb3tXNRmR5bEp9Bo/95uKNzBRXj4gr05N2lY1hrVqndxsbxE2KgsmYb2
yZ6uPb1cmMdPHGm5TqOjZbPmwwEuWLYbNs1KpGGTKJKUPMVFhE1jrXkMua9q
cS/Za4VCQy93aEEojfH/MRlPPUIxUqJZetWFRtjidZjZFwq1QDPrg3I05I1S
34QGhaFl2ztxubt8ZHBcvrj9CUOX58Nu7ObDpOfxk7CLp5G4QK/0yacJNIdH
LBNTDMeHJym2Fkcm4CckEdKdFI7xosyMjuFxSF9dnyC0IgJbvWnRxKPjKPCq
Wh16JwL/Hlcd/fVtDHt3/U7btDkSFlRtY4LDGCbl+6acXkeifaZbovLjUWTM
M3rXZn8GB6Svq+aajmKPnu7puL4zGJJbPRadPQKR8OB/So9FocfRyVNBbQTF
d8891B+JgnRdRcPlmGH4TFnmfj99Fqkfy610/gxhQbiLtLgED/5+tcGvA4aw
seTDVxcpHg6cqDzof3wIrn0ONfekeVj2veCE9LEhJO/cc9JDngf+7t4eS58h
qCtse1+pzkO0reGaR65DUMxalRW4kgeTLSoZVVZDkHgyw6x7Lw9K39WCG3WG
sIwOVVpvz8OG7rK//ZYMYZvu9O/o/TzsNHvvLrtoCGei+elmLjxsH13ZvFdj
CDP2/5yddIiHpowj2zrmDWHqW2uLDYOH6mm5Alp4CPPV993OZvEwOnilNHl6
ECbWr6Om2DzIO2zp2fRnEMyixg35p3morbyWfW5iEBOMmlSxCzycvX7qo8av
QSjdMmO6XOLBbPVW0br+QazpeLD3XgwP8V8UrLy/DyJwc4mYRxwPZyRsbO/2
DiI20LCrPIGH9kfDYo7dg7ibXXhf9hoPfptKPk93DuLNu//FHrrBQ4e90OfM
T4MYkvzHt/ImGf+nlpk72wfxfxYlw+Y=
      "]]}}, 
   {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJw90G1MkwcABOAXogTpSp2oUEU7FbcIZFLBOWjxKGqJEsQVEYHJGEIF6wSL
YGGtQJFCRXQaFUVwBmvENYh1w8KAwRzKZBopnSQdDZAyyocwRPr50si2xPDj
cnn+XW5dSiYvzZkgiKD/8n//NU8IXt2XQ7AhuoDLmMVZYYbjsZ8cSX5Swe+K
WYSMaCoe1JVhX2Bj3B5fEybiQhg3N5ZBfcGgttwyoaq79kF5bSm8J2letz3N
iAylhOcxSkEzhS/aWGPGXEO2ll8tQ9072eVPoi1Qrten7qfLQE38yaR9YkHi
lZ0WztUSOB0eHYqNtILiWl+62aMEOg9ao/+PVrTkr6Cv+e4MwrLYK3SbbDg2
JfnBjXoGW0SZTokNNngnG1k2eTEomypfMT3teN6798WISzEOftq8JjDLDvEu
dZK2WApFYH9a0DM7/JsYbzoIKU7/7RxCYZLQ+5YV3ZcUwWfUY6D8EIlzNW+W
VZOFGA4LqFLfJcFeGq+QnyqEfAdn++d/ktAtLhb8M1aAAC7P0ETMIfh1zPln
htNom4k7fp42h+s9PiqFXrJgstGsLegTLzjhxlNLQs+3C/65sJL+WXc+Vk5z
u6nDJFbx09kfdubhwBVfd8M1EvmRwV9NtolQyXLnPdpLoj/ATdqlPoVfzhol
g0Y7WCv7FbWqXJwo6dw6UGHHjTlll0SZg7ea8jaZ3QbHkHji4J2TyF4bs2tz
mg1fPo2iBn2fDX77co7zYytalWsDaNeF4Cz5w8fXyQrvi9O8iUsnsDqmyJUX
ZoE4tyPnybksZMwwkxVZZjSp1zM51EwsrdB45J40QSTtzLUS38BPImAJM2bB
juK31puOovnX+b5r0W/h8HR1Th1LR4TLZWH71hm0Gu5FrNLzIRoNnsxxTENc
H1nR8zIV+fQ4ipdyCmzRVK/st5T3/76GI/yCV6g6GUZhVHP8gTGIVqe0GmMP
vd8zAkJ1JyImNB4uXesYVXUGFHLHe9t9YjGgNydm7xkEofdP8v/gCzz0q8t7
uEMHYniolzm6Gzc1aQ3VCVoQ7unjbo84UF2iH/36WDcI4cB815JA6Pom922R
t4AI4x/RsBbj1qCGf3i4HB3jPeN52z5u/0jdwr1ao8K/FyOTfQ==
     "]]}, {{}, {}, 
    {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwV13k41N0XAHBaZMmSskQUUUoSFX6WjihSCJGlKEuWkC37fL/DaEFSSfYt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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"z (m)\"", TraditionalForm], 
    FormBox["\"F (N/A)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  ImageSize->{641., Automatic},
  PlotRange->{{0, 0.013}, {0., 1.6948581299755139`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.478970312655707*^9, 3.478970349956621*^9}, 
   3.4789703994875298`*^9, 3.478971607584939*^9, 3.4789719008193083`*^9, {
   3.478972321794873*^9, 3.4789723915815496`*^9}, 3.47897462857933*^9, 
   3.479491375853756*^9, {3.479495240008403*^9, 3.479495266824088*^9}, 
   3.479495416841895*^9, 3.479497903792444*^9, 3.4794980383520308`*^9, 
   3.4794982508041973`*^9, 3.479665430756591*^9, 3.47966555437061*^9, 
   3.4796655952965937`*^9, 3.479665767861109*^9, 3.479665800596849*^9, 
   3.479666123343511*^9, 3.480085442474633*^9, 3.480085476792396*^9, 
   3.480244564663542*^9, {3.480245967281913*^9, 3.4802459841655083`*^9}, 
   3.480252591260969*^9, 3.480252685939891*^9, 3.480692325467414*^9, 
   3.481941625474936*^9, 3.4819420984427*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["New coil calc for BOSEM (5x10 magnet)", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, 
   3.463844192181329*^9, {3.478894850822432*^9, 3.478894851717502*^9}, {
   3.478895153999941*^9, 3.478895157728011*^9}}],

Cell["\<\
bosemvals5 = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->0.005,\t\t\t\t(* length of big magnets *)
\t\ta->0.005,\t\t\t\t(* radius of big magnets *)
\t\t(* coil length *)
\t\tcoillen->0.315*0.0254,  (* SA email, 08/14/06 *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.35*0.0254, (* unchanged *)
\t\tcoilrad2->0.65*0.0254, (* SA email, 08/14/06 *)
\t\t(* the number of turns *)
\t\tcoilturns->800, (* SA email, 08/14/06 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
];\
\>", "Input",
 CellChangeTimes->{{3.453837228357688*^9, 3.453837230833909*^9}, {
  3.463844183252262*^9, 3.463844223147016*^9}, {3.478894862544446*^9, 
  3.4788948852377567`*^9}, {3.478894985619047*^9, 3.4788949913587503`*^9}, {
  3.4788950240972023`*^9, 3.478895025494358*^9}, {3.478895116514908*^9, 
  3.478895118897944*^9}, {3.478895285651181*^9, 3.478895286185315*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "BO5", "]"}], " ", ":=", " ", "bosemvals5"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, 
   3.463844187524227*^9, 3.463845359588154*^9, {3.47889491108751*^9, 
   3.47889491212925*^9}, {3.4788949966551943`*^9, 3.478894997123682*^9}, 
   3.4788950699694643`*^9, {3.478895122464415*^9, 3.478895146305952*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"optdata", "[", "BO5", "]"}], " ", "=", " ", 
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.9628352953498257"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"z", "\[Rule]", "0.0061809572312008145`"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"Minimize", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"fz", "[", 
           RowBox[{"BO5", ",", "z"}], "]"}]}], ",", " ", 
         RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
        "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, {
   3.4789735053303223`*^9, 3.478973506356164*^9}, 3.478974572010633*^9, {
   3.478974602170628*^9, 3.4789746026573887`*^9}, 3.479661922162386*^9, {
   3.480244453457839*^9, 3.480244472141658*^9}, {3.480244801803609*^9, 
   3.4802448024252663`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"plot", "[", "BO5", "]"}], " ", "=", " ", 
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
     GraphicsBox[{{}, {}, 
       {GrayLevel[0], LineBox[CompressedData["
1:eJwV1ns4VNv/B/C+IaIkRAqhUqdUkopc3m5FJ5wUKoqiIiG3MbNnSK5pQhSi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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      PlotRange->{{0, 0.013}, {0., 0.9628352949866621}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"fz", "[", 
        RowBox[{"BO5", ",", "p"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.4802448296734753`*^9, 
   3.480244857272909*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "BO5", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "BO5", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9}],

Cell[BoxData["0.0061809572312008145`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.480085256476678*^9, 
  3.480244563873888*^9, 3.480244811221223*^9, 3.4802459142441196`*^9, 
  3.480692325590218*^9, 3.481941625685656*^9, 3.481942098570314*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "BO5", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "BO5", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9}],

Cell[BoxData["0.9628352953498257`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.480085460576848*^9, 
  3.480244563919486*^9, 3.480245914361339*^9, 3.4806923256341553`*^9, 
  3.481941625797789*^9, 3.4819420986261683`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{"-", 
   RowBox[{"ND", "[", 
    RowBox[{
     RowBox[{"fz", "[", 
      RowBox[{"BO5", ",", "z"}], "]"}], ",", "z", ",", 
     RowBox[{"zmax", "[", "BO5", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479666215169937*^9, 3.479666222032254*^9}}],

Cell[BoxData["87.56908556907709`"], "Output",
 CellChangeTimes->{3.479666223290411*^9, 3.4800854634063387`*^9, 
  3.480244563981793*^9, 3.4802459147274513`*^9, 3.480692325973102*^9, 
  3.481941626163953*^9, 3.481942098994108*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Measurement", "Subsubsection",
 CellChangeTimes->{{3.478970601031336*^9, 3.478970602486655*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v5", " ", "=", " ", 
  RowBox[{"Recurse", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"zflange", " ", "->", " ", 
      RowBox[{"0.1", "*", "0.0254"}]}], ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"end", " ", "flange", " ", "thickness"}], ",", " ", 
       RowBox[{"D060106", "-", "C"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"l", " ", "->", " ", "0.005"}], ",", "\[IndentingNewLine]", 
     RowBox[{"zplug", " ", "->", " ", "0.001"}], ",", "\[IndentingNewLine]", 
     RowBox[{"zcoil", " ", "->", " ", 
      RowBox[{"0.315", "*", "0.0254"}]}], ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"coil", " ", "length"}], ",", " ", 
       RowBox[{"D060106", "-", "C"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"zc", " ", "->", " ", 
      RowBox[{
       RowBox[{"l", "/", "2"}], "+", "zplug", "+", "zflange", "+", 
       RowBox[{"zcoil", "/", "2"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"newportcal", " ", "->", " ", "0.5"}]}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{
     "micrometer", " ", "to", " ", "stage", " ", "factor", " ", "for", " ", 
      "Newport", " ", "NVM80"}], " ", "*)"}], "\[IndentingNewLine]", "}"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478364871938177*^9, 3.4783650430215597`*^9}, {
   3.478365123922604*^9, 3.478365126702361*^9}, {3.478365254617469*^9, 
   3.4783652660805397`*^9}, {3.4783655084186296`*^9, 
   3.4783655130572557`*^9}, {3.478365552219092*^9, 3.4783656736355543`*^9}, 
   3.47948618034295*^9, 3.479486213991674*^9, {3.479502242119833*^9, 
   3.4795022421218023`*^9}, {3.479655724672627*^9, 3.479655724740677*^9}, {
   3.4796557854574213`*^9, 3.479655785465637*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"zflange", "\[Rule]", "0.00254`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.005`"}], ",", 
   RowBox[{"zplug", "\[Rule]", "0.001`"}], ",", 
   RowBox[{"zcoil", "\[Rule]", "0.008001`"}], ",", 
   RowBox[{"zc", "\[Rule]", "0.010040499999999999`"}], ",", 
   RowBox[{"newportcal", "\[Rule]", "0.5`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.478365674218483*^9, 3.4788943916835203`*^9, 
  3.478960931218412*^9, 3.478973701033331*^9, 3.479490566372048*^9, 
  3.479664646024015*^9, 3.4796657673893423`*^9, 3.480084171866323*^9, 
  3.480244564038784*^9, 3.480245921425527*^9, 3.4806923260597963`*^9, 
  3.481941626208601*^9, 3.481942099102745*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"cal5", " ", "=", " ", "0.5"}], ";"}]], "Input",
 CellChangeTimes->{{3.4783589573423653`*^9, 3.478358966550098*^9}, 
   3.478973591713312*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"m5", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "20.02", ",", "\[IndentingNewLine]", "20.0", ",", "\[IndentingNewLine]", 
     "19", ",", "18", ",", "17", ",", "16", ",", "15", ",", 
     "\[IndentingNewLine]", "14", ",", "13", ",", "12", ",", "11.5", ",", 
     "11", ",", "10.5", ",", "10", ",", "\[IndentingNewLine]", "9.5", ",", 
     "9.0", ",", "8.5", ",", "8", ",", "7.5"}], "\[IndentingNewLine]", 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.47835857022501*^9, 3.478358649532322*^9}, {
  3.478358853952238*^9, 3.478358855805633*^9}, {3.478370614629692*^9, 
  3.4783706455854597`*^9}, {3.478370676433776*^9, 3.478370679402834*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f5", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"21.7", ",", "  ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"was", " ", "25.7"}], " ", "-", " ", 
       RowBox[{"typo", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", "21.7", 
     ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"was", " ", "25.7"}], " ", "-", " ", 
       RowBox[{"typo", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", "23", ",",
      "\:3000", "24", ",", "\:3000", "25", ",", "\:3000", "26", ",", "\:3000",
      "26.9", ",", "\:3000", "\[IndentingNewLine]", "27.6", ",", "\:3000", 
     "28.2", ",", "\:3000", "28.7", ",", "\:3000", "28.6", ",", "\:3000", 
     "28.7", ",", "\:3000", "28.5", ",", "\:3000", "28.2", ",", "\:3000", 
     "\[IndentingNewLine]", "27.6", ",", "\:3000", "27.4", ",", "\:3000", 
     "26.5", ",", "\:3000", "25.9", ",", "\:3000", "25.4"}], 
    "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.478358656639378*^9, 3.478358736957609*^9}, {
   3.478358785279069*^9, 3.478358785557148*^9}, {3.47836952405042*^9, 
   3.478369528607705*^9}, {3.4783705484182587`*^9, 3.478370609603867*^9}, 
   3.478370656935858*^9, {3.478370688621035*^9, 3.47837070158915*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"c5", " ", "=", " ", 
   RowBox[{
    RowBox[{"zc", "+", 
     RowBox[{"newportcal", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m5", "-", 
         RowBox[{"m5", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", "1000"}]}]}], "/.", 
    "v5"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.478370938123036*^9, 3.478370942043363*^9}, {
   3.478961639423946*^9, 3.478961643935979*^9}, 3.4789735974419727`*^9, 
   3.479490549175753*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"m5b", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "25", ",", "24.5", ",", "24", ",", "23.5", ",", "23", ",", "22.5", ",", 
     "22", ",", "21.5", ",", "21", ",", "20.5", ",", "\[IndentingNewLine]", 
     "20", ",", "19.5", ",", "19", ",", "18.5", ",", "18", ",", "17.5", ",", 
     "17", ",", "16.5", ",", "16", ",", "15.5", ",", "\[IndentingNewLine]", 
     "15", ",", "14.4", ",", "14", ",", "13.5", ",", "13", ",", "12.5", ",", 
     "12", ",", "11.5", ",", "11", ",", "10.5", ",", "\[IndentingNewLine]", 
     "10", ",", "9.5", ",", "9", ",", "8.5", ",", "8", ",", "7.5", ",", "7", 
     ",", "6.5", ",", "6", ",", "5.5", ",", "\[IndentingNewLine]", "5.25", 
     ",", "5", ",", "4.75", ",", "4.5", ",", "4.25", ",", "4"}], 
    "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.480082947570427*^9, 3.4800831719740562`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f5b", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "21.9", ",", "22.5", ",", "23.0", ",", "23.4", ",", "23.9", ",", "24.4", 
     ",", "24.9", ",", "25.4", ",", "25.8", ",", "26.2", ",", 
     "\[IndentingNewLine]", "26.5", ",", "26.9", ",", "27.3", ",", "27.5", 
     ",", "27.6", ",", "27.7", ",", "27.8", ",", "27.9", ",", 
     "\[IndentingNewLine]", "27.7", ",", "27.5", ",", "27.1", ",", "26.6", 
     ",", "26.1", ",", "25.4", ",", "24.7", ",", "23.8", ",", "22.8", ",", 
     "21.8", ",", "20.7", ",", "19.4", ",", "\[IndentingNewLine]", "18", ",", 
     "16.6", ",", "15.0", ",", "13.4", ",", "11.7", ",", "10.0", ",", "8.17", 
     ",", "6.34", ",", "4.45", ",", "2.53", ",", "\[IndentingNewLine]", 
     "1.61", ",", "0.658", ",", "0.290", ",", "0.124", ",", "0.222", ",", 
     "3.19"}], "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.48008383483594*^9, 3.4800841583652897`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"c5b", " ", "=", " ", 
   RowBox[{
    RowBox[{"zc", "+", 
     RowBox[{"newportcal", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m5b", "-", 
         RowBox[{"m5b", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", "1000"}]}]}], "/.", 
    "v5"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.478370938123036*^9, 3.478370942043363*^9}, {
   3.478961639423946*^9, 3.478961643935979*^9}, 3.4789735974419727`*^9, 
   3.479490549175753*^9, {3.480085294755208*^9, 3.480085305264647*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{"c5b", ",", "f5b"}], "}"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.480244170219839*^9, 3.480244174751951*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQvbtKVFJ2Qot9Ggg8M3XIflu7iou3xZ4BBBrMHKQT
nln/6GyG8BnMHU5f8jv7lK0Zoj7N3KHGdXvc5eYmqH5zB50d8h8OMED5aRYO
d7Q6GtfVNkLlLRx65n4QmvOrASpv6WAjELmks7zB/uwZELB0uMHanP3uRb29
MRhYOVi8Du47+agO6h4rh5kXVDYuuVMLNc/K4efWr5frr9VA9PtYO0TOPvYt
6kI1VL21w66G6ZJmp6rsZ80EAWsHqbQMG8EjlRDzN1s7VHlbxr/ZWwG139rh
lgFX0/Ht5VDzrR2sxW4vWbSxDK5+9u/Vx2tXl8LN//2g5lXE0hKI+ZLWDld7
y92PZRVD7bNy2LNazoB/ZhFU3spBZuL7oFeTCuH+ryk7UHq0pwBqvoXDju1K
ho68+VD3mDtUNR0p+86QC+WbOVj5pu1Z+yULyjd1+CXOwZTyIgOq38Rh16OV
7lJ30qDmGzvUrPXuvXA+BRp/Rg42FW8vtR1OgrrPwOGPU7+E7fYEqLyeQ4V0
0p5nobFQ87UcfmxY6h5sGwk1T92hwu3lpf0qoVD1Kg4Md3TidHgC7a8vLrDl
CldwYHj84JLhc0/7mP5DXzViJB0Y+DJecm1zhJon6MBQdO//cU5je1sukA4W
Bwar0zpOG1XtDwNV9x/6ac/gkJZ+0ZrVvnSyBEsY31N7BhODT5vUxPaDjeu/
ZM9whNNnean2/gjLLSfK9u23Z9he2//rten+i0q3f9ZlnbFn6PlWoShrt7/1
deAOuVZOBwCkWD22
    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{3.480244175910057*^9, 3.480244564266391*^9, 
  3.480245921792756*^9, 3.4806923262774763`*^9, 3.481941626785322*^9, 
  3.48194209932056*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"g5", " ", "=", " ", 
   RowBox[{"Take", "[", 
    RowBox[{
     RowBox[{"Sort", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"c5", ",", "f5"}], "}"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#1", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", 
         RowBox[{"#2", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "6"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.479492900596332*^9, 3.479493003075787*^9}, {
   3.479493311477222*^9, 3.479493315988943*^9}, {3.4794935683920727`*^9, 
   3.4794935803839912`*^9}, {3.479493647064962*^9, 3.4794936781853*^9}, {
   3.479494587120398*^9, 3.479494587799402*^9}, 3.479495122108719*^9, 
   3.479664850461237*^9, {3.479666071209745*^9, 3.479666118376079*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"g5b", " ", "=", " ", 
   RowBox[{"Take", "[", 
    RowBox[{
     RowBox[{"Sort", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"c5b", ",", "f5b"}], "}"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#1", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", 
         RowBox[{"#2", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"23", ",", 
       RowBox[{"-", "10"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.479492900596332*^9, 3.479493003075787*^9}, {
   3.479493311477222*^9, 3.479493315988943*^9}, {3.4794935683920727`*^9, 
   3.4794935803839912`*^9}, {3.479493647064962*^9, 3.4794936781853*^9}, {
   3.479494587120398*^9, 3.479494587799402*^9}, 3.479495122108719*^9, 
   3.479664850461237*^9, {3.479666071209745*^9, 3.479666118376079*^9}, {
   3.4800842394941673`*^9, 3.480084256187529*^9}, {3.480085381741091*^9, 
   3.4800854050584*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", "g5b", "]"}]], "Input",
 CellChangeTimes->{{3.479492922070776*^9, 3.479492925832822*^9}, 
   3.480084241379088*^9}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], 
   PointBox[{{0.004290499999999999, 25.4}, {0.004540499999999999, 26.1}, {
    0.004740499999999999, 26.6}, {0.005040499999999999, 27.1}, {
    0.005290499999999999, 27.5}, {0.005540499999999999, 27.7}, {
    0.005790499999999999, 27.9}, {0.006040499999999999, 27.8}, {
    0.006290499999999999, 27.7}, {0.0065404999999999994`, 27.6}, {
    0.006790499999999999, 27.5}, {0.007040499999999999, 27.3}, {
    0.007290499999999999, 26.9}, {0.007540499999999999, 26.5}, {
    0.007790499999999999, 26.2}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{
  3.47949292648037*^9, {3.4794929901025677`*^9, 3.479493006913755*^9}, 
   3.479493322040373*^9, {3.479493571055421*^9, 3.479493582720769*^9}, {
   3.479493654111162*^9, 3.479493680849517*^9}, 3.479494594442368*^9, 
   3.4794951275012083`*^9, 3.479664646222107*^9, 3.479665767557681*^9, 
   3.4796658002277327`*^9, {3.479666082950231*^9, 3.479666122957705*^9}, 
   3.480085257681452*^9, 3.48008532219565*^9, {3.480085387449814*^9, 
   3.480085408824621*^9}, 3.4802445643515987`*^9, 3.480245921875152*^9, 
   3.4806923263613043`*^9, 3.481941626886848*^9, 3.481942099405159*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"q", "[", 
   RowBox[{"BO5", ",", "z_"}], "]"}], " ", "=", " ", 
  RowBox[{"Fit", "[", 
   RowBox[{"g5b", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "z", ",", 
      RowBox[{"z", "^", "2"}]}], "}"}], ",", "z"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.479492821084407*^9, 3.479492906857025*^9}, {
   3.479493026130746*^9, 3.479493088769916*^9}, 3.47966554034807*^9, 
   3.480085337997651*^9}],

Cell[BoxData[
 RowBox[{"2.6127607538419864`", "\[InvisibleSpace]", "+", 
  RowBox[{"8218.061371644684`", " ", "z"}], "-", 
  RowBox[{"669099.8444305127`", " ", 
   SuperscriptBox["z", "2"]}]}]], "Output",
 CellChangeTimes->{{3.479493065534417*^9, 3.479493090921401*^9}, 
   3.479493347575324*^9, 3.479493687032943*^9, 3.4794945945082073`*^9, 
   3.479495127601207*^9, 3.4796646462647676`*^9, 3.4796655437102633`*^9, 
   3.479665767592616*^9, 3.479665800264008*^9, {3.4796660829847727`*^9, 
   3.479666123040353*^9}, 3.480085339448057*^9, 3.480085414970368*^9, 
   3.4802445643682337`*^9, 3.4802459219083157`*^9, 3.48069232640238*^9, 
   3.481941626925313*^9, 3.481942099421473*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", "g5b", "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"q", "[", 
      RowBox[{"BO5", ",", "z"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "0.00375", ",", "0.008"}], "}"}]}], "]"}], ",", 
   RowBox[{"PlotRange", "->", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.479493098474358*^9, 3.4794931473471107`*^9}, {
   3.4794950541082687`*^9, 3.479495059418387*^9}, 3.479495140140613*^9, {
   3.479498020636153*^9, 3.4794980214908237`*^9}, 3.4796655403666763`*^9, 
   3.480085344678802*^9}],

Cell[BoxData[
 GraphicsBox[{
   {Hue[0.67, 0.6, 0.6], 
    PointBox[{{0.004290499999999999, 25.4}, {0.004540499999999999, 26.1}, {
     0.004740499999999999, 26.6}, {0.005040499999999999, 27.1}, {
     0.005290499999999999, 27.5}, {0.005540499999999999, 27.7}, {
     0.005790499999999999, 27.9}, {0.006040499999999999, 27.8}, {
     0.006290499999999999, 27.7}, {0.0065404999999999994`, 27.6}, {
     0.006790499999999999, 27.5}, {0.007040499999999999, 27.3}, {
     0.007290499999999999, 26.9}, {0.007540499999999999, 26.5}, {
     0.007790499999999999, 26.2}}]}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k8VdsXAHBCmZv4ZUhpIHlIeHLvqdYOT6pXhpAkSpMkQ4Z7zkVu6clQ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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->All,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{
  3.479493147789712*^9, 3.479493348745586*^9, 3.479493687869093*^9, 
   3.479494594544231*^9, 3.4794950600870647`*^9, {3.479495127635968*^9, 
   3.4794951412551003`*^9}, 3.479498022175354*^9, 3.479664646293791*^9, 
   3.479665767627028*^9, 3.479665800298114*^9, {3.4796660830395527`*^9, 
   3.4796661230758743`*^9}, 3.4800853458498983`*^9, 3.480085417240912*^9, 
   3.480244564408826*^9, 3.48024592195185*^9, 3.4806923264358673`*^9, 
   3.481941626979694*^9, 3.481942099477305*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmaxq", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"q", "[", 
        RowBox[{"BO5", ",", "z"}], "]"}], ",", "z"}], "]"}]}], "/", 
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{"q", "[", 
       RowBox[{"BO5", ",", "z"}], "]"}], ",", 
      RowBox[{"z", "^", "2"}]}], "]"}]}], "/", "2"}]}]], "Input",
 CellChangeTimes->{{3.479495438249634*^9, 3.479495505318678*^9}, 
   3.479662502748355*^9, 3.4796629041886263`*^9, 3.479664469475191*^9, {
   3.479665540402864*^9, 3.479665540432529*^9}, 3.479665679958331*^9}],

Cell[BoxData["0.006141132328792631`"], "Output",
 CellChangeTimes->{{3.479495497456901*^9, 3.479495505729022*^9}, 
   3.479664646330089*^9, 3.479665767660248*^9, 3.4796658003302927`*^9, 
   3.479666123140691*^9, 3.480085429491647*^9, 3.480244564434903*^9, 
   3.480245921975265*^9, 3.480692326468603*^9, 3.481941627025852*^9, 
   3.481942099487645*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmaxq", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{"q", "[", 
   RowBox[{"BO5", ",", 
    RowBox[{"zmaxq", "[", "BO5", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4796645166114473`*^9, 3.4796645680107403`*^9}, {
   3.479664629540166*^9, 3.4796646354272118`*^9}, 3.479665680445608*^9, 
   3.479665788251362*^9}],

Cell[BoxData["27.846861938546535`"], "Output",
 CellChangeTimes->{3.479664568867193*^9, 3.479664646359799*^9, 
  3.479665585669737*^9, 3.479665767693388*^9, 3.479665800365254*^9, 
  3.479666123176936*^9, 3.48008543183556*^9, 3.480244564491827*^9, 
  3.480245922030847*^9, 3.480692326501891*^9, 3.481941627098565*^9, 
  3.4819420995401154`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"delta", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"zmaxq", "[", "BO5", "]"}], " ", "-", " ", 
   RowBox[{"zmax", "[", "BO5", "]"}], " "}]}]], "Input",
 CellChangeTimes->{{3.479495523610161*^9, 3.479495542381401*^9}, 
   3.479661946209796*^9, 3.479662081271207*^9, 3.47966250284426*^9, 
   3.47966290430508*^9, 3.479664469476417*^9, {3.479665683454405*^9, 
   3.479665683520638*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.000039824902408183704`"}]], "Output",
 CellChangeTimes->{3.4794955436804543`*^9, 3.479665380340073*^9, 
  3.479665767759824*^9, 3.479665800431348*^9, 3.4796661232447157`*^9, 
  3.4800854342417307`*^9, 3.4802445645293713`*^9, 3.480245953636918*^9, 
  3.48069232653566*^9, 3.481941627141439*^9, 3.4819420995770683`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Scale factor to make measured and theoretical curves have same maximum\
\>", "Text",
 CellChangeTimes->{{3.478970887912784*^9, 3.478970908928837*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"scale", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"fmax", "[", "BO5", "]"}], "/", 
   RowBox[{"fmaxq", "[", "BO5", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970696648231*^9, 3.478970705072441*^9}, {
   3.478970839616865*^9, 3.478970857497159*^9}, 3.4789715324564857`*^9, {
   3.478971784562731*^9, 3.4789717872495337`*^9}, 3.478971846731222*^9, {
   3.4789723755682993`*^9, 3.478972380734989*^9}, {3.4789735142646723`*^9, 
   3.4789735163909893`*^9}, 3.479661959846012*^9, 3.479662130234865*^9, {
   3.479665563524087*^9, 3.479665591276129*^9}, {3.479665788451865*^9, 
   3.479665788518486*^9}}],

Cell[BoxData["0.03457607889444224`"], "Output",
 CellChangeTimes->{
  3.478971485608411*^9, 3.478971533659111*^9, 3.478971787849442*^9, {
   3.478971841091794*^9, 3.4789718473084917`*^9}, 3.478972382639682*^9, 
   3.4789745781001587`*^9, 3.478974629064003*^9, 3.4794913230668173`*^9, 
   3.4796653804411373`*^9, 3.479665592037429*^9, 3.4796657678267307`*^9, 
   3.47966580051572*^9, 3.479666123310278*^9, 3.480085442306896*^9, 
   3.480085474403487*^9, 3.480244564572826*^9, 3.480245967181128*^9, 
   3.480692326580511*^9, 3.4819416271735687`*^9, 3.481942099628888*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"plot", "[", "BO5", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"c5b", ",", 
        RowBox[{
         RowBox[{"scale", "[", "BO5", "]"}], "*", "f5b"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Blue", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"scale", "[", "BO5", "]"}], "*", 
      RowBox[{"q", "[", 
       RowBox[{"BO5", ",", "z"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "0.00375", ",", "0.008"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Red", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<z (m)\>\"", ",", "\"\<F (N/A)\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, {
   3.453838538440839*^9, 3.453838572806719*^9}, 3.463844247723119*^9, 
   3.478894943196905*^9, 3.4788950132010527`*^9, {3.478961709433363*^9, 
   3.47896175216029*^9}, {3.478961842569364*^9, 3.478961894377494*^9}, {
   3.4789619830038633`*^9, 3.478961984506156*^9}, {3.4789699280628653`*^9, 
   3.478969982243393*^9}, {3.478970021389124*^9, 3.478970165180615*^9}, {
   3.478970224319232*^9, 3.478970261501657*^9}, {3.4789703108875017`*^9, 
   3.478970348344078*^9}, 3.478970398020482*^9, {3.478970871122594*^9, 
   3.47897087265033*^9}, {3.478971414854863*^9, 3.4789714317583723`*^9}, {
   3.4789723334965277`*^9, 3.4789723911200447`*^9}, {3.478973525233735*^9, 
   3.47897352833882*^9}, {3.479495227181163*^9, 3.4794952662789087`*^9}, {
   3.4794954131043873`*^9, 3.4794954161349077`*^9}, {3.479497883443406*^9, 
   3.479497887306903*^9}, {3.4794980354692507`*^9, 3.479498036795588*^9}, 
   3.4794982488155937`*^9, {3.479662131489229*^9, 3.479662133377276*^9}, 
   3.479665540471899*^9, {3.4802459792714577`*^9, 3.480245981573744*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {GrayLevel[0], LineBox[CompressedData["
1:eJwV1ns4VNv/B/C+IaIkRAqhUqdUkopc3m5FJ5wUKoqiIiG3MbNnSK5pQhSi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      "]]}}, 
   {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJw9kXtQC3AAx3/limIqzywV3XAUt5JXq76qI65xlGGeXVa6XGi0ZjatrcPO
FM6jKY8oHXnFaaRuozSVToa8lpvSXm2LjkrlhjvXH9/7/vO5793nvtOT9sQn
OxNC5v3Nv34smDjF90QuTm/wWevLMGGXTXTDnZILMadysmenCT6JBka/TIpu
xaKaO1wzmrSrmztdpfjSdzFqqMMM4TLlttdSCdbMnWYszLAg6KH/NzWRQJVU
LGc4LNDNOZpzW5SDeQUBIZ/kXZBf+DauaECMC81X3wmoVoR7sktkWWKcCBy9
RXPMivcu0l12UzYkMq5+/G8rFncl5DW0H0K/hzqGEm+DooVWUaITwZI+6zm7
1oZfD36+zm4Voq0pj3kt1A52YX3vppaDaBU8zWOm21ElPjdlYaMACfG6O5dk
dlBTUsO96g7g5ezelp5SOwRxS7Zba/hgOnn2LHtqx0e6u0SjzILm/ezxis92
MCZ9KrlSwRvmCwfLNaLyzOH9Qb3QsrF0P75O3exOhmx4ezwrtj5tHzKNHziJ
u22oLvejeyi4cL23UaXWWzH1ZHe85VTGsL+Qp858Jt+LBWZ7d+i6LjxUBgRH
UfbgDcu1fgXLAoGkjtdH0tFrGXHQLcyMsFUp1bd+pMFb7ERv9DNhYPIoZ44p
FTURnbWLjAZUtV+PpepSkMY8M9HB64TwVtzxlpccnJcGLt9n6UA436Y9XJuE
xqonPOPWdgxF53tHKBNBYmjJDwr04PskVRtYW7H7LKXMtawN/XdLYxMi2P//
/gD+crNWRWNhPZuu+z6tFUQXtC1ozFr407yPRE/QgnTotcHGldC2OXbM9HgB
MjbV7F4ZheI3fSOaK2pBuJ8dGrf5oPaPPGXlVIKENQVFV8zAM8ZOE1d8E2Rp
ys5XDBf4xno3UJjnQELpPfdmTlI9uhyg8JLlgtS5McsyA1W2CdTI+/kZIEpR
/kDXAhWr2GpQ780Gkffyp/tGqhxF+SH88Gr8AV9XbZM=
     "]]}, {{}, {}, 
    {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwV13k4VWsXAHBDKjPhUuYilCvJJcIy9AmVMUNCERmSmbP3OYajQcptUoZy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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"z (m)\"", TraditionalForm], 
    FormBox["\"F (N/A)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  ImageSize->{641., Automatic},
  PlotRange->{{0, 0.013}, {0., 0.9628352949866621}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.478970312655707*^9, 3.478970349956621*^9}, 
   3.4789703994875298`*^9, 3.478971607584939*^9, 3.4789719008193083`*^9, {
   3.478972321794873*^9, 3.4789723915815496`*^9}, 3.47897462857933*^9, 
   3.479491375853756*^9, {3.479495240008403*^9, 3.479495266824088*^9}, 
   3.479495416841895*^9, 3.479497903792444*^9, 3.4794980383520308`*^9, 
   3.4794982508041973`*^9, 3.479665430756591*^9, 3.47966555437061*^9, 
   3.4796655952965937`*^9, 3.479665767861109*^9, 3.479665800596849*^9, 
   3.479666123343511*^9, 3.480085442474633*^9, 3.480085476792396*^9, 
   3.480244564663542*^9, {3.480245967281913*^9, 3.4802459841655083`*^9}, 
   3.480692326631896*^9, 3.481941627229917*^9, 3.481942099677737*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
New coil calc for BOSEM (10x\[OSlash]5 magnet as for tiptilt)\
\>", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, 
   3.463844192181329*^9, {3.478894850822432*^9, 3.478894851717502*^9}, {
   3.4788951705281897`*^9, 3.4788951754720497`*^9}, {3.4819407269664*^9, 
   3.481940736973164*^9}}],

Cell["\<\
bosemvalsTT = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->0.010,\t\t\t\t(* length of big magnets *)
\t\ta->0.005/2,\t\t\t\t(* radius of big magnets *)
\t\t(* coil length *)
\t\tcoillen->0.315*0.0254,  (* SA email, 08/14/06 *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.35*0.0254, (* unchanged *)
\t\tcoilrad2->0.65*0.0254, (* SA email, 08/14/06 *)
\t\t(* the number of turns *)
\t\tcoilturns->800, (* SA email, 08/14/06 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
];\
\>", "Input",
 CellChangeTimes->{{3.453837228357688*^9, 3.453837230833909*^9}, {
  3.463844183252262*^9, 3.463844223147016*^9}, {3.478894862544446*^9, 
  3.4788948852377567`*^9}, {3.478894985619047*^9, 3.4788949913587503`*^9}, {
  3.4788950240972023`*^9, 3.478895025494358*^9}, {3.481940748223406*^9, 
  3.481940763510077*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "BOTT", "]"}], " ", ":=", " ", "bosemvalsTT"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, 
   3.463844187524227*^9, 3.463845359588154*^9, {3.47889491108751*^9, 
   3.47889491212925*^9}, {3.4788949966551943`*^9, 3.478894997123682*^9}, 
   3.4788950699694643`*^9, {3.4819407740626507`*^9, 3.481940800888165*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"optdata", "[", "BOTT", "]"}], " ", "=", " ", 
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.3925374169455943`"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", "\[Rule]", "0.00759707468312686`"}], "}"}]}], "}"}], ",",
      "\[IndentingNewLine]", 
     RowBox[{"Minimize", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"fz", "[", 
           RowBox[{"BOTT", ",", "z"}], "]"}]}], ",", " ", 
         RowBox[{"0.006", " ", "<", " ", "z", " ", "<", " ", "0.010"}]}], 
        "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.480244382554545*^9, 3.480244405961742*^9}, {
   3.4819408015577917`*^9, 3.4819408027090397`*^9}, {3.481940979763582*^9, 
   3.481940981746011*^9}, {3.481941548420309*^9, 3.481941559738948*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"plot", "[", "BOTT", "]"}], " ", "=", " ", 
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
     GraphicsBox[{{}, {}, 
       {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nk4Fe0bB3BR2ZckS5EoKiolhMo3RKVCSrRQka1EQjjOOXOOLR3SqkWb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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      PlotRange->{{0, 0.013}, {0., 0.3925374150688015}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"fz", "[", 
        RowBox[{"BOTT", ",", "p"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.4794970273251*^9, 3.4794970280748262`*^9}, {3.479497850691868*^9, 
   3.479497851721608*^9}, {3.4802445496159487`*^9, 3.4802445841180058`*^9}, {
   3.4802446656757193`*^9, 3.4802446687524443`*^9}, {3.481940803363203*^9, 
   3.481940804034131*^9}, {3.481941063760079*^9, 3.4819410664063997`*^9}, {
   3.481941556057631*^9, 3.4819415664906*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "BOTT", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "BOTT", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.4796619220112333`*^9, 3.4796619454416037`*^9}, 3.479665671740583*^9, {
   3.48194080448247*^9, 3.481940804971867*^9}}],

Cell[BoxData["0.00759707468312686`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.479486914888383*^9, 
  3.479659289850292*^9, 3.4796634565750093`*^9, 3.479665742764594*^9, 
  3.479665816570661*^9, 3.480243747684814*^9, 3.480692317253339*^9, 
  3.481566060871256*^9, 3.481940897154257*^9, 3.481940954139496*^9, 
  3.4819414009024477`*^9, 3.481941627387727*^9, 3.481942099804831*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "BOTT", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "BOTT", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, 
   3.479661922078005*^9, 3.4796619593447857`*^9, 3.479665787682528*^9, {
   3.481940805601218*^9, 3.481940806091435*^9}}],

Cell[BoxData["0.3925374169455943`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.479486914934926*^9, 
  3.479659289887826*^9, 3.479663456628942*^9, 3.479665742793458*^9, 
  3.4796658166882772`*^9, 3.480243747711088*^9, 3.480692317295466*^9, 
  3.481566060924111*^9, 3.48194089720923*^9, 3.48194095418651*^9, 
  3.481941400927742*^9, 3.4819416274500303`*^9, 3.48194209986127*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "BOTT", "]"}], " ", "=", " ", 
  RowBox[{"-", 
   RowBox[{"ND", "[", 
    RowBox[{
     RowBox[{"fz", "[", 
      RowBox[{"BOTT", ",", "z"}], "]"}], ",", "z", ",", 
     RowBox[{"zmax", "[", "BOTT", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}}],

Cell[BoxData["33.880059861057546`"], "Output",
 CellChangeTimes->{
  3.4796611607361183`*^9, 3.479661209333243*^9, {3.4796612702637243`*^9, 
   3.47966130570842*^9}, 3.479661373421825*^9, 3.479661471574224*^9, 
   3.479661860947604*^9, {3.479662726071348*^9, 3.47966274404876*^9}, 
   3.479663512851673*^9, 3.479665743087571*^9, 3.4796658169851303`*^9, 
   3.4802437481454697`*^9, 3.480692317637856*^9, 3.481566061244952*^9, 
   3.4819408972419558`*^9, 3.4819409542455378`*^9, 3.481941401101359*^9, 
   3.4819416276185503`*^9, 3.481942100030518*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f95plus", "[", "BOTT", "]"}], " ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BOTT", ",", "z"}], "]"}], "-", 
      RowBox[{"0.95", "*", 
       RowBox[{"fmax", "[", "BOTT", "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BOTT", "]"}], "+", "0.001"}], ",", 
       RowBox[{"zmax", "[", "BOTT", "]"}], ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BOTT", "]"}], "+", "0.005"}]}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479658613425561*^9, 3.4796587501410933`*^9}, {
   3.479658790462825*^9, 3.4796587993088913`*^9}, {3.479658852062684*^9, 
   3.479658891629363*^9}, {3.4796589431729183`*^9, 3.479658948798299*^9}, {
   3.479658987032153*^9, 3.47965898990287*^9}, {3.479659310386307*^9, 
   3.4796593125701933`*^9}, {3.479661624172262*^9, 3.479661679901505*^9}, {
   3.479661945541445*^9, 3.4796619594445953`*^9}, {3.4796656734658623`*^9, 
   3.479665674680963*^9}, 3.47966578778349*^9, {3.481940808072547*^9, 
   3.4819408112927933`*^9}}],

Cell[BoxData["0.009502179799013966`"], "Output",
 CellChangeTimes->{{3.479659290207419*^9, 3.4796593177022877`*^9}, {
   3.479661644377719*^9, 3.4796616514833097`*^9}, 3.479661686065053*^9, 
   3.4796634593803263`*^9, 3.479665745824663*^9, 3.4796658197389708`*^9, 
   3.480243751933235*^9, 3.480692320796873*^9, 3.4815660640155077`*^9, 
   3.4819408973674994`*^9, 3.481940954361327*^9, 3.481941402301373*^9, 
   3.481941628781619*^9, 3.481942101498692*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f95minus", "[", "BOTT", "]"}], " ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BOTT", ",", "z"}], "]"}], "-", 
      RowBox[{"0.95", "*", 
       RowBox[{"fmax", "[", "BOTT", "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BOTT", "]"}], "-", "0.001"}], ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BOTT", "]"}], "-", "0.005"}], ",", 
       RowBox[{"zmax", "[", "BOTT", "]"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479658613425561*^9, 3.4796587501410933`*^9}, {
   3.479658790462825*^9, 3.4796587993088913`*^9}, {3.479658852062684*^9, 
   3.479658891629363*^9}, {3.4796589431729183`*^9, 3.479658948798299*^9}, {
   3.479658997678957*^9, 3.4796590027188377`*^9}, {3.479659318794853*^9, 
   3.479659344898431*^9}, {3.479661657421668*^9, 3.4796616780054293`*^9}, {
   3.479661945775414*^9, 3.479661959545474*^9}, {3.479665675209929*^9, 
   3.479665676278386*^9}, 3.4796657878831253`*^9, {3.481940812147341*^9, 
   3.481940829419257*^9}}],

Cell[BoxData["0.005897248057591024`"], "Output",
 CellChangeTimes->{
  3.479659290545846*^9, {3.479659322545879*^9, 3.479659348979048*^9}, {
   3.4796616661527233`*^9, 3.479661689555737*^9}, 3.479663462870864*^9, 
   3.479665749329587*^9, 3.479665823257647*^9, 3.480243756605932*^9, 
   3.480692324819867*^9, 3.481566067504561*^9, 3.4819408974084797`*^9, 
   3.481940954404307*^9, 3.481941404076367*^9, 3.481941630539411*^9, 
   3.481942103389555*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"plot", "[", "BOTT", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<z (m)\>\"", ",", "\"\<F (N/A)\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, {
   3.453838538440839*^9, 3.453838572806719*^9}, 3.463844247723119*^9, 
   3.478894943196905*^9, 3.4788950132010527`*^9, {3.478961709433363*^9, 
   3.47896175216029*^9}, {3.478961842569364*^9, 3.478961894377494*^9}, {
   3.4789619830038633`*^9, 3.478961984506156*^9}, {3.4789699280628653`*^9, 
   3.478969982243393*^9}, {3.478970021389124*^9, 3.478970165180615*^9}, {
   3.478970224319232*^9, 3.478970261501657*^9}, {3.4789703108875017`*^9, 
   3.478970348344078*^9}, 3.478970398020482*^9, {3.478970871122594*^9, 
   3.47897087265033*^9}, {3.478971414854863*^9, 3.4789714317583723`*^9}, {
   3.4789723334965277`*^9, 3.4789723911200447`*^9}, {3.478973525233735*^9, 
   3.47897352833882*^9}, {3.479495227181163*^9, 3.4794952662789087`*^9}, {
   3.4794954131043873`*^9, 3.4794954161349077`*^9}, {3.479497883443406*^9, 
   3.479497887306903*^9}, {3.4794980354692507`*^9, 3.479498036795588*^9}, 
   3.4794982488155937`*^9, {3.479662131489229*^9, 3.479662133377276*^9}, 
   3.479665540471899*^9, {3.4802459792714577`*^9, 3.480245981573744*^9}, {
   3.4802525542284737`*^9, 3.4802525884311867`*^9}, {3.48194087775911*^9, 
   3.481940886937986*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nk4Fe0bB3BR2ZckS5EoKiolhMo3RKVCSrRQka1EQjjOOXOOLR3SqkWb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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"z (m)\"", TraditionalForm], 
    FormBox["\"F (N/A)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  PlotRange->{{0, 0.013}, {0., 0.3925374150688015}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.478970312655707*^9, 3.478970349956621*^9}, 
   3.4789703994875298`*^9, 3.478971607584939*^9, 3.4789719008193083`*^9, {
   3.478972321794873*^9, 3.4789723915815496`*^9}, 3.47897462857933*^9, 
   3.479491375853756*^9, {3.479495240008403*^9, 3.479495266824088*^9}, 
   3.479495416841895*^9, 3.479497903792444*^9, 3.4794980383520308`*^9, 
   3.4794982508041973`*^9, 3.479665430756591*^9, 3.47966555437061*^9, 
   3.4796655952965937`*^9, 3.479665767861109*^9, 3.479665800596849*^9, 
   3.479666123343511*^9, 3.480085442474633*^9, 3.480085476792396*^9, 
   3.480244564663542*^9, {3.480245967281913*^9, 3.4802459841655083`*^9}, 
   3.480252591260969*^9, 3.480252685939891*^9, 3.480692325467414*^9, 
   3.481940897619549*^9, 3.481940954553793*^9, 3.4819414042893677`*^9, 
   3.481941630662005*^9, 3.4819421034795094`*^9}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"cases", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"BO5", ",", "BO10", ",", "BM5", ",", " ", "BM", ",", "BOTT"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.479668457935833*^9, 3.479668481450539*^9}, {
  3.479668587715115*^9, 3.4796685878908243`*^9}, {3.4819414768722143`*^9, 
  3.481941481456056*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Join", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "cases", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Transpose", "[", "\[IndentingNewLine]", 
     RowBox[{"Table", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fmax", "[", 
          RowBox[{"cases", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
         RowBox[{"1000", "*", 
          RowBox[{"zmax", "[", 
           RowBox[{"cases", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
         RowBox[{"1000", "*", 
          RowBox[{"zmaxq", "[", 
           RowBox[{"cases", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
         RowBox[{"delta", "[", 
          RowBox[{"cases", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
         RowBox[{"coupling", "[", 
          RowBox[{"cases", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "cases", "]"}]}], "}"}]}], 
      "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", "]"}]}], 
   "\[IndentingNewLine]", "]"}], "//", "TableForm"}]], "Input",
 CellChangeTimes->{{3.479668483217331*^9, 3.479668563563539*^9}, {
  3.4796686215578623`*^9, 3.479668666780747*^9}, {3.479668701726816*^9, 
  3.479668747295388*^9}, {3.481942141220706*^9, 3.481942165968225*^9}, {
  3.481942240350567*^9, 3.481942242583256*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"BO5", "BO10", "BM5", "BM", "BOTT"},
    {"0.9628352953498257`", "1.694858202857608`", "0.6371543615438662`", 
     "1.084332204665714`", "0.3925374169455943`"},
    {"6.180957231200814`", "7.195850469335957`", "5.090030272462407`", 
     "6.361536563952735`", "7.59707468312686`"},
    {"6.141132328792631`", "7.352611334002001`", 
     RowBox[{"1000", " ", 
      RowBox[{"zmaxq", "[", "BM5", "]"}]}], 
     RowBox[{"1000", " ", 
      RowBox[{"zmaxq", "[", "BM", "]"}]}], 
     RowBox[{"1000", " ", 
      RowBox[{"zmaxq", "[", "BOTT", "]"}]}]},
    {
     RowBox[{"-", "0.000039824902408183704`"}], "0.0001567608646660442`", 
     RowBox[{"delta", "[", "BM5", "]"}], 
     RowBox[{"delta", "[", "BM", "]"}], 
     RowBox[{"delta", "[", "BOTT", "]"}]},
    {"87.56908556907709`", "150.76737498024153`", "62.73689995259677`", 
     "105.12281621120579`", "33.880059861057546`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.479668564704335*^9, 3.479668590873575*^9}, 
   3.4796686679295673`*^9, {3.479668724514228*^9, 3.479668747827025*^9}, 
   3.480244564877256*^9, 3.480245967399906*^9, 3.480245998712572*^9, 
   3.480252760111574*^9, 3.4806923267132607`*^9, 3.481941485393458*^9, 
   3.4819416307948303`*^9, 3.4819421035619698`*^9, 3.48194216744412*^9, 
   3.4819422448464603`*^9}]
}, Open  ]],

Cell["Combinations with opposed magnets", "Section",
 CellChangeTimes->{{3.4802635577614393`*^9, 3.480263564378763*^9}}],

Cell[CellGroupData[{

Cell["\<\
10x10 magnets 5 mm apart with hybrid OSEM coil - historical interest only.\
\>", "Subsection",
 CellChangeTimes->{{3.480700103981674*^9, 3.4807001348451366`*^9}, {
  3.481565209358251*^9, 3.48156521929447*^9}, {3.481565959348879*^9, 
  3.48156595959684*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot2", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"fz", "[", 
      RowBox[{"BM", ",", "z"}], "]"}], "-", 
     RowBox[{"fz", "[", 
      RowBox[{"BM", ",", 
       RowBox[{"z", "+", "0.015"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.010"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", "Black", "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.480263490827755*^9, 3.4802634980091763`*^9}, {
   3.4802639392440853`*^9, 3.480263973553187*^9}, 3.480264058574482*^9, 
   3.480264152546308*^9, {3.480264362832872*^9, 3.480264366942833*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV13k4VdsbB3CRUkhKopCQkiZS/Eq+biE0KUmGaBIhkvGcvXHo6BpSV12i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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.480263609670712*^9, 3.480264091847402*^9, 
  3.480264219397868*^9, 3.480692381982799*^9, 3.481568304979225*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata2", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.9124418416937872`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.0068007634327481815`"}], "}"}]}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fz", "[", 
            RowBox[{"BM", ",", "z"}], "]"}], "-", 
           RowBox[{"fz", "[", 
            RowBox[{"BM", ",", 
             RowBox[{"z", "+", "0.015"}]}], "]"}]}], ")"}]}], ",", " ", 
        RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, {
   3.4789735053303223`*^9, 3.478973506356164*^9}, 3.478974572010633*^9, {
   3.478974602170628*^9, 3.4789746026573887`*^9}, 3.479661922162386*^9, {
   3.480244453457839*^9, 3.480244472141658*^9}, {3.480244801803609*^9, 
   3.4802448024252663`*^9}, {3.480264669104636*^9, 3.480264684559224*^9}, 
   3.480264725697961*^9, {3.480264827573757*^9, 3.480264835420212*^9}, 
   3.480265037916628*^9, 3.480693722607716*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.9124418416937872`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.0068007634327481815`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.480264812348777*^9, 3.480265632924423*^9, 
  3.480693092309564*^9, 3.481568926418055*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax2", "[", "BM", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata2", "[", "BM", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.4802646918142347`*^9, 
   3.480264705945876*^9}}],

Cell[BoxData["0.0068007634327481815`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.480085256476678*^9, 
  3.480244563873888*^9, 3.480244811221223*^9, 3.4802459142441196`*^9, 
  3.480265633025037*^9, 3.480693092364389*^9, 3.481568926517033*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax2", "[", "BM", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata2", "[", "BM", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.4802646945892344`*^9, 
   3.4802647077937603`*^9}}],

Cell[BoxData["0.9124418416937872`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.480085460576848*^9, 
  3.480244563919486*^9, 3.480245914361339*^9, 3.480265633047605*^9, 
  3.4806930923900967`*^9, 3.481568926569429*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling2", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{"-", 
   RowBox[{"ND", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"fz", "[", 
        RowBox[{"BM", ",", "z"}], "]"}], "-", 
       RowBox[{"fz", "[", 
        RowBox[{"BM", ",", 
         RowBox[{"z", "+", "0.015"}]}], "]"}]}], ")"}], ",", "z", ",", 
     RowBox[{"zmax", "[", "BM", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.480263450999733*^9, 3.48026346168337*^9}, {
   3.480263914415457*^9, 3.480263919822134*^9}, {3.4802639904904423`*^9, 
   3.480263992225717*^9}, 3.4802641618848267`*^9}],

Cell[BoxData["88.22366474445113`"], "Output",
 CellChangeTimes->{3.480263610201136*^9, 3.480263993085375*^9, 
  3.480265633453446*^9, 3.4806930928601418`*^9, 3.481568926898951*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"coupling", "[", "BM", "]"}], ",", 
      RowBox[{"zmax", "[", "BM", "]"}], ",", 
      RowBox[{"fmax", "[", "BM", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"coupling2", "[", "BM", "]"}], ",", 
      RowBox[{"zmax2", "[", "BM", "]"}], ",", 
      RowBox[{"fmax2", "[", "BM", "]"}]}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.481567608225747*^9, 3.481567635059455*^9}, {
  3.4815676689801073`*^9, 3.481567724116664*^9}, {3.481567816726468*^9, 
  3.481567818793173*^9}, {3.4815681797948217`*^9, 3.48156818542627*^9}},
 FormatType->"InputForm"],

Cell[BoxData[
 TagBox[GridBox[{
    {"105.12281621120579`", "0.006361536563952735`", "1.084332204665714`"},
    {"88.22366474445113`", "0.0068007634327481815`", "0.9124418416937872`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4815677247383738`*^9, 3.48156775513408*^9, 
  3.481567825373666*^9, 3.481568186322205*^9, 3.4815689269394617`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
10x10 magnets 20 mm apart with BOSEM coil per pitch magnets on top mass and \
UIM of quad\
\>", "Subsection",
 CellChangeTimes->{{3.480700103981674*^9, 3.480700176213991*^9}, {
  3.481565949718953*^9, 3.481565983045248*^9}, {3.481566089551104*^9, 
  3.48156609404573*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot2", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV13k8Vc0fB3ASiSRlS7ZKSkmJ0sZHRaEIJUkUZQlJC3HvPede3FK2HipR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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{All, All},
     PlotRangeClipping->True,
     PlotRangePadding->{Automatic, Automatic}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"fz", "[", 
         RowBox[{"BO10", ",", "z"}], "]"}], "-", 
        RowBox[{"fz", "[", 
         RowBox[{"BO10", ",", 
          RowBox[{"z", "+", "0.030"}]}], "]"}]}], ")"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0", ",", "0.010"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.480263490827755*^9, 3.4802634980091763`*^9}, {
   3.480263536719996*^9, 3.480263537125444*^9}, {3.480263833591049*^9, 
   3.480263861642727*^9}, {3.48026393264508*^9, 3.48026393627591*^9}, {
   3.480264005377029*^9, 3.4802640754825783`*^9}, {3.4802641643969183`*^9, 
   3.480264165325192*^9}, {3.4806937485908546`*^9, 3.480693765401557*^9}, {
   3.481566119159527*^9, 3.481566119550919*^9}, 3.4815661573148108`*^9, 
   3.4815682113946342`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV13k8Vc0fB3ASiSRlS7ZKSkmJ0sZHRaEIJUkUZQlJC3HvPede3FK2HipR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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.480263682317749*^9, 3.4802639921266336`*^9, 
  3.480264150342636*^9, 3.480265704722389*^9, 3.480693170005075*^9, 
  3.481566223913733*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata2", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1.6263677836045267`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.007300967534849954`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fz", "[", 
            RowBox[{"BO10", ",", "z"}], "]"}], "-", 
           RowBox[{"fz", "[", 
            RowBox[{"BO10", ",", 
             RowBox[{"z", "+", "0.030"}]}], "]"}]}], ")"}]}], ",", " ", 
        RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, {
   3.4789735053303223`*^9, 3.478973506356164*^9}, 3.478974572010633*^9, {
   3.478974602170628*^9, 3.4789746026573887`*^9}, 3.479661922162386*^9, {
   3.480244453457839*^9, 3.480244472141658*^9}, {3.480244801803609*^9, 
   3.4802448024252663`*^9}, {3.480264669104636*^9, 3.480264684559224*^9}, 
   3.480264725697961*^9, {3.480264796714196*^9, 3.4802647976619177`*^9}, {
   3.480264858240645*^9, 3.4802648706070433`*^9}, 3.480265044282831*^9, 
   3.48069378671309*^9, {3.48156613564054*^9, 3.4815661608653307`*^9}, 
   3.481568221803894*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.6263677836045267`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.007300967534849954`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.480266848202059*^9, 3.4806936239876947`*^9, 
  3.4815667132643127`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax2", "[", "BO10", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata2", "[", "BO10", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.4802646918142347`*^9, 
   3.480264705945876*^9}, {3.4802647989584846`*^9, 3.480264799487084*^9}}],

Cell[BoxData["0.007300967534849954`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.480085256476678*^9, 
  3.480244563873888*^9, 3.480244811221223*^9, 3.4802459142441196`*^9, 
  3.480266848415159*^9, 3.480693624043004*^9, 3.481566713311575*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax2", "[", "BO10", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata2", "[", "BO10", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.4802646945892344`*^9, 
   3.4802647077937603`*^9}, {3.480264800442628*^9, 3.480264800914262*^9}}],

Cell[BoxData["1.6263677836045267`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.480085460576848*^9, 
  3.480244563919486*^9, 3.480245914361339*^9, 3.480266848444786*^9, 
  3.4806936240713797`*^9, 3.481566713335513*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling2", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"-", 
   RowBox[{"ND", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"fz", "[", 
        RowBox[{"BO10", ",", "z"}], "]"}], "-", 
       RowBox[{"fz", "[", 
        RowBox[{"BO10", ",", 
         RowBox[{"z", "+", "0.030"}]}], "]"}]}], ")"}], ",", "z", ",", 
     RowBox[{"zmax", "[", "BO10", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.480263450999733*^9, 3.48026346168337*^9}, {
  3.48026353726007*^9, 3.480263538098238*^9}, {3.4802641844695673`*^9, 
  3.480264189899138*^9}, {3.481567765046813*^9, 3.481567765918151*^9}}],

Cell[BoxData["145.49861375885502`"], "Output",
 CellChangeTimes->{3.480263683138138*^9, 3.480266848935244*^9, 
  3.480693624518203*^9, 3.481566713724019*^9, 3.481567767707713*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"coupling", "[", "BO10", "]"}], ",", 
      RowBox[{"zmax", "[", "BO10", "]"}], ",", 
      RowBox[{"fmax", "[", "BO10", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"coupling2", "[", "BO10", "]"}], ",", 
      RowBox[{"zmax2", "[", "BO10", "]"}], ",", 
      RowBox[{"fmax2", "[", "BO10", "]"}]}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.481567608225747*^9, 3.481567635059455*^9}, {
  3.4815676689801073`*^9, 3.481567724116664*^9}, {3.481567816726468*^9, 
  3.481567818793173*^9}},
 FormatType->"InputForm"],

Cell[BoxData[
 TagBox[GridBox[{
    {"150.76737498024153`", "0.0071958504693359565`", "1.694858202857608`"},
    {"145.49861375885502`", "0.007300967534849954`", "1.6263677836045267`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4815677247383738`*^9, 3.48156775513408*^9, 
  3.481567825373666*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
6x2 magnets 24 mm apart with AOSEM coil per pitch magnets on top mass and UIM \
of quad\
\>", "Subsection",
 CellChangeTimes->{{3.480700103981674*^9, 3.480700176213991*^9}, {
   3.481565949718953*^9, 3.481565983045248*^9}, {3.481566089551104*^9, 
   3.48156609404573*^9}, 3.4815663420577517`*^9, {3.4815664004646187`*^9, 
   3.4815664245209103`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot2", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nlUjG8UB/CKIqKQtEhRSEjCL5S+lqKylHZp06oSLTPzzjRpM0VlSRhK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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{All, All},
     PlotRangeClipping->True,
     PlotRangePadding->{Automatic, Automatic}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"fz", "[", 
         RowBox[{"AODL", ",", "z"}], "]"}], "-", 
        RowBox[{"fz", "[", 
         RowBox[{"AODL", ",", 
          RowBox[{"z", "+", "0.030"}]}], "]"}]}], ")"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0", ",", "0.010"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.480263490827755*^9, 3.4802634980091763`*^9}, {
   3.480263536719996*^9, 3.480263537125444*^9}, {3.480263833591049*^9, 
   3.480263861642727*^9}, {3.48026393264508*^9, 3.48026393627591*^9}, {
   3.480264005377029*^9, 3.4802640754825783`*^9}, {3.4802641643969183`*^9, 
   3.480264165325192*^9}, {3.4806937485908546`*^9, 3.480693765401557*^9}, {
   3.481566119159527*^9, 3.481566119550919*^9}, 3.4815661573148108`*^9, {
   3.481566453354445*^9, 3.481566453404786*^9}, 3.481568229036901*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nlUjG8UB/CKIqKQtEhRSEjCL5S+lqKylHZp06oSLTPzzjRpM0VlSRhK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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.480263682317749*^9, 3.4802639921266336`*^9, 
  3.480264150342636*^9, 3.480265704722389*^9, 3.480693170005075*^9, 
  3.481566223913733*^9, 3.48156671551313*^9, 3.4815668538117313`*^9, 
  3.481567024102026*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata2", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.030257769468565232`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.005750794119386763`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fz", "[", 
            RowBox[{"AODL", ",", "z"}], "]"}], "-", 
           RowBox[{"fz", "[", 
            RowBox[{"AODL", ",", 
             RowBox[{"z", "+", "0.030"}]}], "]"}]}], ")"}]}], ",", " ", 
        RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, {
   3.4789735053303223`*^9, 3.478973506356164*^9}, 3.478974572010633*^9, {
   3.478974602170628*^9, 3.4789746026573887`*^9}, 3.479661922162386*^9, {
   3.480244453457839*^9, 3.480244472141658*^9}, {3.480244801803609*^9, 
   3.4802448024252663`*^9}, {3.480264669104636*^9, 3.480264684559224*^9}, 
   3.480264725697961*^9, {3.480264796714196*^9, 3.4802647976619177`*^9}, {
   3.480264858240645*^9, 3.4802648706070433`*^9}, 3.480265044282831*^9, 
   3.48069378671309*^9, {3.48156613564054*^9, 3.4815661608653307`*^9}, {
   3.481566453424974*^9, 3.481566453476396*^9}, 3.481568237964075*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.030257769468565232`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.005750794119386763`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.480266848202059*^9, 3.4806936239876947`*^9, 
  3.481566715791988*^9, 3.481566854139357*^9, 3.481567149415079*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax2", "[", "AODL", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata2", "[", "AODL", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.4802646918142347`*^9, 
   3.480264705945876*^9}, {3.4802647989584846`*^9, 3.480264799487084*^9}, {
   3.4815664535103188`*^9, 3.481566453543878*^9}}],

Cell[BoxData["0.005750794119386763`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.480085256476678*^9, 
  3.480244563873888*^9, 3.480244811221223*^9, 3.4802459142441196`*^9, 
  3.480266848415159*^9, 3.480693624043004*^9, 3.481566716026739*^9, 
  3.481566854410817*^9, 3.481567149455831*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax2", "[", "AODL", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata2", "[", "AODL", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.4802646945892344`*^9, 
   3.4802647077937603`*^9}, {3.480264800442628*^9, 3.480264800914262*^9}, {
   3.481566453577557*^9, 3.4815664536106653`*^9}}],

Cell[BoxData["0.030257769468565232`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.480085460576848*^9, 
  3.480244563919486*^9, 3.480245914361339*^9, 3.480266848444786*^9, 
  3.4806936240713797`*^9, 3.481566716286377*^9, 3.481566854706884*^9, 
  3.481567149468693*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling2", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{"-", 
   RowBox[{"ND", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"fz", "[", 
        RowBox[{"AODL", ",", "z"}], "]"}], "-", 
       RowBox[{"fz", "[", 
        RowBox[{"AODL", ",", 
         RowBox[{"z", "+", "0.030"}]}], "]"}]}], ")"}], ",", "z", ",", 
     RowBox[{"zmax", "[", "AODL", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.480263450999733*^9, 3.48026346168337*^9}, {
  3.48026353726007*^9, 3.480263538098238*^9}, {3.4802641844695673`*^9, 
  3.480264189899138*^9}, {3.4815664536441*^9, 3.481566453744608*^9}, {
  3.481567750494437*^9, 3.481567751428978*^9}}],

Cell[BoxData["3.0826402898342558`"], "Output",
 CellChangeTimes->{3.480263683138138*^9, 3.480266848935244*^9, 
  3.480693624518203*^9, 3.481566716349246*^9, 3.481566854757926*^9, 
  3.481567149600642*^9, 3.481567752245166*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"coupling", "[", "AODL", "]"}], ",", 
      RowBox[{"zmax", "[", "AODL", "]"}], ",", 
      RowBox[{"fmax", "[", "AODL", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"coupling2", "[", "AODL", "]"}], ",", 
      RowBox[{"zmax2", "[", "AODL", "]"}], ",", 
      RowBox[{"fmax2", "[", "AODL", "]"}]}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.481567608225747*^9, 3.481567635059455*^9}, {
  3.4815676689801073`*^9, 3.481567724116664*^9}},
 FormatType->"InputForm"],

Cell[BoxData[
 TagBox[GridBox[{
    {"3.1372173465909605`", "0.005708650395783029`", "0.03093422318713475`"},
    {"3.0826402898342558`", "0.005750794119386763`", "0.030257769468565232`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4815677247383738`*^9, 3.48156775513408*^9}]
}, Open  ]]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{943, 1078},
WindowMargins->{{Automatic, 167}, {Automatic, 0}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "CompatibilityToolbar"],
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 56, 0, 76, "Title"],
Cell[626, 24, 491, 11, 27, "Input"],
Cell[CellGroupData[{
Cell[1142, 39, 31, 0, 67, "Section"],
Cell[1176, 41, 636, 11, 101, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1849, 57, 78, 2, 67, "Section",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1952, 63, 34, 0, 34, "Subsection"],
Cell[CellGroupData[{
Cell[2011, 67, 197, 4, 37, "Subsubsection"],
Cell[2211, 73, 1713, 42, 148, "Input"],
Cell[3927, 117, 34, 0, 27, "Input"]
}, Open  ]]
}, Open  ]],
Cell[3988, 121, 83, 1, 27, "Input"],
Cell[CellGroupData[{
Cell[4096, 126, 44, 0, 34, "Subsection"],
Cell[4143, 128, 150, 4, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4330, 137, 71, 0, 34, "Subsection"],
Cell[CellGroupData[{
Cell[4426, 141, 54, 0, 24, "Subsubsection"],
Cell[4483, 143, 552, 16, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5072, 164, 168, 4, 24, "Subsubsection"],
Cell[5243, 170, 122, 4, 40, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5402, 179, 97, 1, 24, "Subsubsection"],
Cell[5502, 182, 166, 5, 40, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5717, 193, 65, 0, 34, "Subsection"],
Cell[CellGroupData[{
Cell[5807, 197, 151, 13, 170, "Input"],
Cell[5961, 212, 925, 24, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6923, 241, 84, 2, 27, "Input"],
Cell[7010, 245, 628, 14, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7675, 264, 155, 12, 157, "Input"],
Cell[7833, 278, 900, 23, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8770, 306, 113, 3, 27, "Input"],
Cell[8886, 311, 565, 11, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9488, 327, 412, 13, 27, "Input"],
Cell[9903, 342, 459, 7, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[10411, 355, 83, 2, 26, "Subsection",
 Evaluatable->False],
Cell[10497, 359, 887, 24, 274, "Input"],
Cell[11387, 385, 209, 8, 105, "Input"],
Cell[11599, 395, 691, 21, 261, "Input"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12339, 422, 112, 1, 67, "Section"],
Cell[12454, 425, 104, 3, 27, "Input"],
Cell[CellGroupData[{
Cell[12583, 432, 56, 0, 34, "Subsection"],
Cell[CellGroupData[{
Cell[12664, 436, 153, 3, 26, "Text"],
Cell[12820, 441, 438, 17, 209, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[13295, 463, 43, 0, 23, "Text"],
Cell[CellGroupData[{
Cell[13363, 467, 34, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[13422, 471, 44689, 946, 1963, "Input"],
Cell[58114, 1419, 44329, 933, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[102492, 2358, 34, 0, 23, "Text"],
Cell[102529, 2360, 422, 10, 43, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[103000, 2376, 43, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[103068, 2380, 44, 0, 26, "Text"],
Cell[103115, 2382, 1760518, 38380, 130430, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1863670, 40767, 34, 0, 26, "Text"],
Cell[1863707, 40769, 529, 14, 43, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1864285, 40789, 170, 3, 26, "Text"],
Cell[CellGroupData[{
Cell[1864480, 40796, 275, 7, 27, "Input"],
Cell[1864758, 40805, 20807, 522, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1885626, 41334, 135, 1, 23, "Text"],
Cell[1885764, 41337, 1380, 34, 103, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[1887183, 41376, 96, 2, 27, "Input"],
Cell[CellGroupData[{
Cell[1887304, 41382, 116, 1, 67, "Section"],
Cell[CellGroupData[{
Cell[1887445, 41387, 1727, 44, 521, "Input"],
Cell[1889175, 41433, 2804, 53, 70, "Output"]
}, Open  ]],
Cell[1891994, 41489, 192, 5, 27, "Input"],
Cell[1892189, 41496, 1016, 25, 88, "Input"],
Cell[1893208, 41523, 6560, 117, 167, "Input"],
Cell[CellGroupData[{
Cell[1899793, 41644, 500, 10, 27, "Input"],
Cell[1900296, 41656, 398, 5, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1900731, 41666, 494, 10, 27, "Input"],
Cell[1901228, 41678, 388, 5, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1901653, 41688, 437, 11, 27, "Input"],
Cell[1902093, 41701, 252, 3, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1902382, 41709, 757, 15, 27, "Input"],
Cell[1903142, 41726, 255, 3, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1903434, 41734, 168, 4, 27, "Input"],
Cell[1903605, 41740, 437, 7, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1904079, 41752, 380, 9, 27, "Input"],
Cell[1904462, 41763, 396, 7, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1904895, 41775, 242, 5, 27, "Input"],
Cell[1905140, 41782, 378, 7, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1905555, 41794, 164, 3, 26, "Text"],
Cell[CellGroupData[{
Cell[1905744, 41801, 8055, 146, 159, "Input"],
Cell[1913802, 41949, 5888, 102, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1919727, 42056, 306, 9, 79, "Input"],
Cell[1920036, 42067, 423, 10, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1920520, 42084, 159, 2, 37, "Section"],
Cell[CellGroupData[{
Cell[1920704, 42090, 1717, 41, 456, "Input"],
Cell[1922424, 42133, 3162, 58, 70, "Output"]
}, Open  ]],
Cell[1925601, 42194, 283, 7, 27, "Input"],
Cell[CellGroupData[{
Cell[1925909, 42205, 216, 5, 27, "Input"],
Cell[1926128, 42212, 548, 9, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1926713, 42226, 380, 9, 27, "Input"],
Cell[1927096, 42237, 449, 7, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1927582, 42249, 314, 6, 27, "Input"],
Cell[1927899, 42257, 428, 8, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1928364, 42270, 251, 6, 27, "Input"],
Cell[1928618, 42278, 456, 8, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1929111, 42291, 251, 6, 27, "Input"],
Cell[1929365, 42299, 461, 8, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1929863, 42312, 118, 1, 26, "Text"],
Cell[CellGroupData[{
Cell[1930006, 42317, 390, 10, 27, "Input"],
Cell[1930399, 42329, 9462, 160, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1939898, 42494, 412, 9, 27, "Input"],
Cell[1940313, 42505, 5945, 103, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1946295, 42613, 701, 15, 27, "Input"],
Cell[1946999, 42630, 681, 14, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1947741, 42651, 323, 8, 21, "Input"],
Cell[1948067, 42661, 239, 3, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1948343, 42669, 316, 8, 27, "Input"],
Cell[1948662, 42679, 185, 2, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1948884, 42686, 227, 3, 67, "Section"],
Cell[CellGroupData[{
Cell[1949136, 42693, 2271, 52, 547, "Input"],
Cell[1951410, 42747, 2973, 56, 70, "Output"]
}, Open  ]],
Cell[1954398, 42806, 331, 7, 27, "Input"],
Cell[1954732, 42815, 1040, 25, 88, "Input"],
Cell[1955775, 42842, 6771, 121, 159, "Input"],
Cell[CellGroupData[{
Cell[1962571, 42967, 495, 10, 27, "Input"],
Cell[1963069, 42979, 369, 5, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1963475, 42989, 494, 10, 27, "Input"],
Cell[1963972, 43001, 372, 5, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1964381, 43011, 437, 11, 27, "Input"],
Cell[1964821, 43024, 228, 3, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1965086, 43032, 1377, 22, 73, "Input"],
Cell[1966466, 43056, 5928, 105, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1972431, 43166, 246, 5, 27, "Input"],
Cell[1972680, 43173, 503, 7, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1973220, 43185, 380, 9, 27, "Input"],
Cell[1973603, 43196, 403, 7, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1974043, 43208, 336, 6, 27, "Input"],
Cell[1974382, 43216, 387, 7, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1974806, 43228, 273, 6, 27, "Input"],
Cell[1975082, 43236, 405, 7, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1975524, 43248, 273, 6, 27, "Input"],
Cell[1975800, 43256, 410, 7, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1976247, 43268, 118, 1, 26, "Text"],
Cell[CellGroupData[{
Cell[1976390, 43273, 412, 10, 27, "Input"],
Cell[1976805, 43285, 9469, 162, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1986311, 43452, 438, 10, 27, "Input"],
Cell[1986752, 43464, 5903, 103, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1992716, 43574, 750, 16, 21, "Input"],
Cell[1993469, 43592, 698, 14, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1994204, 43611, 371, 9, 27, "Input"],
Cell[1994578, 43622, 261, 3, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1994876, 43630, 367, 9, 27, "Input"],
Cell[1995246, 43641, 212, 3, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1995495, 43649, 285, 3, 67, "Section"],
Cell[CellGroupData[{
Cell[1995805, 43656, 2494, 55, 547, "Input"],
Cell[1998302, 43713, 2913, 54, 70, "Output"]
}, Open  ]],
Cell[2001230, 43770, 411, 8, 27, "Input"],
Cell[CellGroupData[{
Cell[2001666, 43782, 118, 1, 26, "Text"],
Cell[CellGroupData[{
Cell[2001809, 43787, 435, 10, 27, "Input"],
Cell[2002247, 43799, 9745, 166, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2012029, 43970, 461, 10, 27, "Input"],
Cell[2012493, 43982, 5978, 104, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2018508, 44091, 578, 12, 27, "Input"],
Cell[2019089, 44105, 598, 13, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2019748, 44125, 183, 4, 21, "Input"],
Cell[2019934, 44131, 157, 2, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2020128, 44138, 339, 4, 67, "Section"],
Cell[CellGroupData[{
Cell[2020492, 44146, 2414, 54, 521, "Input"],
Cell[2022909, 44202, 2809, 52, 70, "Output"]
}, Open  ]],
Cell[2025733, 44257, 459, 9, 27, "Input"],
Cell[2026195, 44268, 1115, 26, 88, "Input"],
Cell[2027313, 44296, 6680, 119, 162, "Input"],
Cell[CellGroupData[{
Cell[2034018, 44419, 496, 10, 27, "Input"],
Cell[2034517, 44431, 374, 5, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2034928, 44441, 492, 10, 27, "Input"],
Cell[2035423, 44453, 373, 5, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2035833, 44463, 439, 11, 27, "Input"],
Cell[2036275, 44476, 227, 3, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2036539, 44484, 118, 1, 26, "Text"],
Cell[CellGroupData[{
Cell[2036682, 44489, 462, 11, 27, "Input"],
Cell[2037147, 44502, 9459, 161, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2046643, 44668, 482, 10, 27, "Input"],
Cell[2047128, 44680, 5970, 104, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2053135, 44789, 603, 13, 27, "Input"],
Cell[2053741, 44804, 596, 13, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2054398, 44824, 505, 9, 37, "Section"],
Cell[CellGroupData[{
Cell[2054928, 44837, 2538, 55, 521, "Input"],
Cell[2057469, 44894, 2873, 53, 70, "Output"]
}, Open  ]],
Cell[2060357, 44950, 515, 10, 27, "Input"],
Cell[CellGroupData[{
Cell[2060897, 44964, 1181, 26, 88, "Input"],
Cell[2062081, 44992, 328, 8, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2062446, 45005, 6632, 117, 155, "Input"],
Cell[2069081, 45124, 5645, 98, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2074763, 45227, 549, 11, 27, "Input"],
Cell[2075315, 45240, 440, 6, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2075792, 45251, 548, 11, 27, "Input"],
Cell[2076343, 45264, 441, 6, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2076821, 45275, 491, 11, 27, "Input"],
Cell[2077315, 45288, 298, 4, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2077650, 45297, 118, 1, 26, "Text"],
Cell[CellGroupData[{
Cell[2077793, 45302, 485, 11, 27, "Input"],
Cell[2078281, 45315, 9526, 163, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2087844, 45483, 510, 11, 27, "Input"],
Cell[2088357, 45496, 6068, 105, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2094462, 45606, 629, 13, 27, "Input"],
Cell[2095094, 45621, 671, 14, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2095826, 45642, 639, 10, 59, "Section"],
Cell[CellGroupData[{
Cell[2096490, 45656, 2536, 55, 521, "Input"],
Cell[2099029, 45713, 2872, 53, 70, "Output"]
}, Open  ]],
Cell[2101916, 45769, 561, 10, 27, "Input"],
Cell[CellGroupData[{
Cell[2102502, 45783, 1208, 27, 88, "Input"],
Cell[2103713, 45812, 302, 8, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2104052, 45825, 6771, 120, 162, "Input"],
Cell[2110826, 45947, 5734, 100, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2116597, 46052, 601, 12, 27, "Input"],
Cell[2117201, 46066, 443, 6, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2117681, 46077, 600, 12, 27, "Input"],
Cell[2118284, 46091, 442, 6, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2118763, 46102, 540, 12, 27, "Input"],
Cell[2119306, 46116, 295, 4, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2119638, 46125, 118, 1, 26, "Text"],
Cell[CellGroupData[{
Cell[2119781, 46130, 506, 11, 27, "Input"],
Cell[2120290, 46143, 9553, 162, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2129880, 46310, 532, 11, 27, "Input"],
Cell[2130415, 46323, 5980, 104, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2136432, 46432, 653, 13, 27, "Input"],
Cell[2137088, 46447, 670, 14, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2137819, 46468, 143, 2, 37, "Section"],
Cell[CellGroupData[{
Cell[2137987, 46474, 1787, 45, 521, "Input"],
Cell[2139777, 46521, 2786, 53, 70, "Output"]
}, Open  ]],
Cell[2142578, 46577, 242, 6, 27, "Input"],
Cell[2142823, 46585, 970, 24, 88, "Input"],
Cell[2143796, 46611, 6559, 118, 168, "Input"],
Cell[CellGroupData[{
Cell[2150380, 46733, 452, 10, 27, "Input"],
Cell[2150835, 46745, 377, 5, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2151249, 46755, 448, 10, 27, "Input"],
Cell[2151700, 46767, 372, 5, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2152109, 46777, 391, 10, 27, "Input"],
Cell[2152503, 46789, 225, 3, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2152765, 46797, 1356, 22, 67, "Input"],
Cell[2154124, 46821, 6340, 110, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2160513, 46937, 249, 3, 37, "Section"],
Cell[2160765, 46942, 2014, 47, 521, "Input"],
Cell[2162782, 46991, 364, 8, 27, "Input"],
Cell[2163149, 47001, 917, 23, 88, "Input"],
Cell[2164069, 47026, 6502, 116, 166, "Input"],
Cell[CellGroupData[{
Cell[2170596, 47146, 358, 8, 27, "Input"],
Cell[2170957, 47156, 324, 4, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2171318, 47165, 352, 8, 27, "Input"],
Cell[2171673, 47175, 318, 4, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2172028, 47184, 665, 14, 27, "Input"],
Cell[2172696, 47200, 477, 7, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2173210, 47212, 1091, 25, 27, "Input"],
Cell[2174304, 47239, 386, 5, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2174727, 47249, 1089, 24, 27, "Input"],
Cell[2175819, 47275, 379, 6, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2176235, 47286, 102, 1, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[2176362, 47291, 1870, 37, 133, "Input"],
Cell[2178235, 47330, 620, 12, 70, "Output"]
}, Open  ]],
Cell[2178870, 47345, 1264, 20, 118, "Input"],
Cell[2180137, 47367, 1423, 22, 103, "Input"],
Cell[2181563, 47391, 519, 15, 27, "Input"],
Cell[2182085, 47408, 1433, 24, 133, "Input"],
Cell[2183521, 47434, 1486, 23, 133, "Input"],
Cell[2185010, 47459, 569, 15, 27, "Input"],
Cell[CellGroupData[{
Cell[2185604, 47478, 980, 19, 27, "Input"],
Cell[2186587, 47499, 1618, 30, 70, "Output"]
}, Open  ]],
Cell[2188220, 47532, 1192, 27, 27, "Input"],
Cell[CellGroupData[{
Cell[2189437, 47563, 236, 4, 27, "Input"],
Cell[2189676, 47569, 1273, 22, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2190986, 47596, 549, 13, 27, "Input"],
Cell[2191538, 47611, 657, 11, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2192232, 47627, 729, 16, 27, "Input"],
Cell[2192964, 47645, 6547, 110, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2199560, 47761, 712, 18, 21, "Input"],
Cell[2200275, 47781, 376, 5, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2200688, 47791, 402, 8, 27, "Input"],
Cell[2201093, 47801, 365, 5, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2201495, 47811, 481, 9, 27, "Input"],
Cell[2201979, 47822, 357, 5, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2202373, 47832, 160, 3, 26, "Text"],
Cell[CellGroupData[{
Cell[2202558, 47839, 700, 12, 27, "Input"],
Cell[2203261, 47853, 597, 9, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2203907, 47868, 2172, 43, 103, "Input"],
Cell[2206082, 47913, 12931, 220, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2219062, 48139, 244, 3, 37, "Section"],
Cell[2219309, 48144, 2090, 48, 521, "Input"],
Cell[2221402, 48194, 408, 8, 27, "Input"],
Cell[2221813, 48204, 1096, 26, 88, "Input"],
Cell[2222912, 48232, 6373, 115, 166, "Input"],
Cell[CellGroupData[{
Cell[2229310, 48351, 402, 9, 27, "Input"],
Cell[2229715, 48362, 395, 5, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2230147, 48372, 398, 9, 27, "Input"],
Cell[2230548, 48383, 372, 5, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2230957, 48393, 342, 9, 27, "Input"],
Cell[2231302, 48404, 229, 3, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2231568, 48412, 102, 1, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[2231695, 48417, 1744, 35, 133, "Input"],
Cell[2233442, 48454, 689, 13, 70, "Output"]
}, Open  ]],
Cell[2234146, 48470, 176, 4, 27, "Input"],
Cell[2234325, 48476, 711, 13, 118, "Input"],
Cell[2235039, 48491, 1264, 24, 118, "Input"],
Cell[2236306, 48517, 491, 14, 27, "Input"],
Cell[2236800, 48533, 914, 15, 118, "Input"],
Cell[2237717, 48550, 978, 16, 118, "Input"],
Cell[2238698, 48568, 540, 14, 27, "Input"],
Cell[CellGroupData[{
Cell[2239263, 48586, 216, 5, 27, "Input"],
Cell[2239482, 48593, 1196, 24, 70, "Output"]
}, Open  ]],
Cell[2240693, 48620, 918, 23, 27, "Input"],
Cell[2241614, 48645, 1023, 25, 27, "Input"],
Cell[CellGroupData[{
Cell[2242662, 48674, 155, 3, 27, "Input"],
Cell[2242820, 48679, 1290, 23, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2244147, 48707, 431, 11, 27, "Input"],
Cell[2244581, 48720, 681, 11, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2245299, 48736, 597, 14, 27, "Input"],
Cell[2245899, 48752, 6588, 112, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2252524, 48869, 657, 17, 27, "Input"],
Cell[2253184, 48888, 352, 5, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2253573, 48898, 353, 8, 27, "Input"],
Cell[2253929, 48908, 343, 5, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2254321, 48919, 432, 9, 27, "Input"],
Cell[2254756, 48930, 348, 5, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2255141, 48940, 160, 3, 26, "Text"],
Cell[CellGroupData[{
Cell[2255326, 48947, 649, 12, 27, "Input"],
Cell[2255978, 48961, 569, 8, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2256596, 48975, 2112, 42, 103, "Input"],
Cell[2258711, 49019, 12771, 218, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2271531, 49243, 328, 6, 37, "Section"],
Cell[2271862, 49251, 2047, 48, 521, "Input"],
Cell[2273912, 49301, 412, 8, 27, "Input"],
Cell[2274327, 49311, 1066, 25, 88, "Input"],
Cell[2275396, 49338, 6785, 120, 173, "Input"],
Cell[CellGroupData[{
Cell[2282206, 49462, 407, 9, 27, "Input"],
Cell[2282616, 49473, 391, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2283044, 49483, 402, 9, 27, "Input"],
Cell[2283449, 49494, 387, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2283873, 49504, 710, 14, 27, "Input"],
Cell[2284586, 49520, 549, 8, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2285172, 49533, 1143, 26, 27, "Input"],
Cell[2286318, 49561, 456, 6, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2286811, 49572, 1139, 25, 27, "Input"],
Cell[2287953, 49599, 451, 7, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2288441, 49611, 1510, 24, 73, "Input"],
Cell[2289954, 49637, 6578, 113, 241, "Output"]
}, Open  ]]
}, Open  ]],
Cell[2296559, 49754, 349, 8, 27, "Input"],
Cell[CellGroupData[{
Cell[2296933, 49766, 1522, 36, 148, "Input"],
Cell[2298458, 49804, 1755, 39, 121, "Output"]
}, Open  ]],
Cell[2300228, 49846, 120, 1, 67, "Section"],
Cell[CellGroupData[{
Cell[2300373, 49851, 268, 5, 26, "Subsection"],
Cell[CellGroupData[{
Cell[2300666, 49860, 733, 18, 27, "Input"],
Cell[2301402, 49880, 5800, 100, 226, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2307239, 49985, 1397, 32, 88, "Input"],
Cell[2308639, 50019, 300, 8, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2308976, 50032, 454, 10, 27, "Input"],
Cell[2309433, 50044, 395, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2309865, 50054, 452, 10, 27, "Input"],
Cell[2310320, 50066, 370, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2310727, 50076, 620, 16, 27, "Input"],
Cell[2311350, 50094, 180, 2, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2311567, 50101, 697, 17, 27, "Input"],
Cell[2312267, 50120, 775, 18, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2313091, 50144, 282, 6, 34, "Subsection"],
Cell[CellGroupData[{
Cell[2313398, 50154, 6875, 123, 159, "Input"],
Cell[2320276, 50279, 5814, 100, 230, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2326127, 50384, 1528, 34, 88, "Input"],
Cell[2327658, 50420, 281, 8, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2327976, 50433, 506, 10, 27, "Input"],
Cell[2328485, 50445, 394, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2328916, 50455, 502, 10, 27, "Input"],
Cell[2329421, 50467, 370, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2329828, 50477, 647, 16, 27, "Input"],
Cell[2330478, 50495, 179, 2, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2330694, 50502, 662, 17, 27, "Input"],
Cell[2331359, 50521, 730, 18, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2332138, 50545, 360, 7, 34, "Subsection"],
Cell[CellGroupData[{
Cell[2332523, 50556, 6838, 122, 157, "Input"],
Cell[2339364, 50680, 5803, 100, 223, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2345204, 50785, 1576, 34, 88, "Input"],
Cell[2346783, 50821, 325, 8, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2347145, 50834, 558, 11, 27, "Input"],
Cell[2347706, 50847, 441, 6, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2348184, 50858, 554, 11, 27, "Input"],
Cell[2348741, 50871, 419, 6, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2349197, 50882, 694, 17, 27, "Input"],
Cell[2349894, 50901, 226, 3, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2350157, 50909, 613, 16, 27, "Input"],
Cell[2350773, 50927, 708, 17, 57, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
